@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: defs.h,v 1.64 2006/01/12 10:18:53 roland Exp $
+ *	$Id: defs.h,v 1.73 2007/01/11 23:19:55 ldv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -340,6 +340,8 @@ struct tcb {
 #   define __NR_exit_group 405
 #  elif defined I386
 #   define __NR_exit_group 252
+#  elif defined X86_64
+#   define __NR_exit_group 231
 #  elif defined IA64
 #   define __NR_exit_group 1236
 #  elif defined POWERPC
@@ -407,9 +409,8 @@ struct xlat {
 extern struct tcb **tcbtab;
 extern int *qual_flags;
 extern int debug, followfork, followvfork;
-extern int rflag, tflag, dtime, cflag, xflag, qflag;
+extern int dtime, cflag, xflag, qflag;
 extern int acolumn;
-extern char *outfname;
 extern unsigned int nprocs, tcbtabsize;
 extern int max_strlen;
 extern struct tcb *tcp_last;
@@ -420,20 +421,24 @@ extern struct tcb *tcp_last;
 #define P(args) ()
 #endif
 
+enum bitness_t { BITNESS_CURRENT = 0, BITNESS_32 };
+
 extern int set_personality P((int personality));
-extern char *xlookup P((const struct xlat *, int));
-extern struct tcb *alloctcb P((int));
+extern const char *xlookup P((const struct xlat *, int));
+extern struct tcb *alloc_tcb P((int, int));
 extern struct tcb *pid2tcb P((int));
 extern void droptcb P((struct tcb *));
 extern int expand_tcbtab P((void));
 
+#define alloctcb(pid)	alloc_tcb((pid), 1)
+
 extern void set_sortby P((char *));
 extern void set_overhead P((int));
 extern void qualify P((char *));
-extern void newoutf P((struct tcb *));
 extern int get_scno P((struct tcb *));
 extern long known_scno P((struct tcb *));
 extern int trace_syscall P((struct tcb *));
+extern int count_syscall P((struct tcb *, struct timeval *));
 extern void printxval P((const struct xlat *, int, const char *));
 extern int printargs P((struct tcb *));
 extern int addflags P((const struct xlat *, int));
@@ -448,7 +453,8 @@ extern void printnum P((struct tcb *, long, char *));
 extern void printnum_int P((struct tcb *, long, char *));
 extern void printpath P((struct tcb *, long));
 extern void printpathn P((struct tcb *, long, int));
-extern void printtv P((struct tcb *, long));
+extern void printtv_bitness P((struct tcb *, long, enum bitness_t));
+extern void sprinttv P((struct tcb *, long, enum bitness_t, char *));
 #ifdef HAVE_SIGINFO_T
 extern void printsiginfo P((siginfo_t *, int));
 #endif
@@ -461,13 +467,14 @@ extern int setbpt P((struct tcb *));
 extern int sigishandled P((struct tcb *, int));
 extern void printcall P((struct tcb *));
 extern const char *signame P((int));
+extern void print_sigset P((struct tcb *, long, int));
 extern void printsignal P((int));
 extern void printleader P((struct tcb *));
 extern void printtrailer P((struct tcb *));
 extern void tabto P((int));
 extern void call_summary P((FILE *));
-extern void printtv32 P((struct tcb*, long));
 extern void tprint_iov P((struct tcb *, unsigned long, unsigned long));
+extern void tprint_open_modes P((struct tcb *, mode_t));
 
 #ifdef LINUX
 extern int internal_clone P((struct tcb *));
@@ -510,6 +517,9 @@ extern int proc_open P((struct tcb *tcp, int attaching));
 #define umove(pid, addr, objp)	\
 	umoven((pid), (addr), sizeof *(objp), (char *) (objp))
 
+#define printtv(tcp, addr)	\
+	printtv_bitness((tcp), (addr), BITNESS_CURRENT)
+
 #ifdef __STDC__
 #ifdef __GNUC__
 extern void tprintf(const char *fmt, ...)
@@ -529,6 +539,7 @@ const char *strsignal P((int));
 #endif
 
 extern int current_personality;
+extern const int personality_wordsize[];
 
 struct sysent {
 	int	nargs;
