@@ -28,7 +28,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: file.c,v 1.75 2005/06/08 20:45:28 roland Exp $
+ *	$Id: file.c,v 1.81 2007/01/11 23:19:55 ldv Exp $
  */
 
 #include "defs.h"
@@ -168,6 +168,15 @@ struct stat_sparc64 {
 #include <sys/stat.h>
 #endif
 
+#if _LFS64_LARGEFILE && (defined(LINUX) || defined(SVR4))
+# ifdef HAVE_INTTYPES_H
+#  include <inttypes.h>
+# else
+#  define PRId64 "lld"
+#  define PRIu64 "llu"
+# endif
+#endif
+
 #if HAVE_LONG_LONG_OFF_T
 /*
  * Ugly hacks for systems that have typedef long long off_t
@@ -200,21 +209,23 @@ struct stat_sparc64 {
 #include <ustat.h>
 #endif
 
-/*
- * This is a really dirty trick but it should always work.  Traditional
- * Unix says r/w/rw are 0/1/2, so we make them true flags 1/2/3 by
- * adding 1.  Just remember to add 1 to any arg decoded with openmodes.
- */
-const struct xlat openmodes[] = {
-	{ O_RDWR+1,	"O_RDWR"	},
-	{ O_RDONLY+1,	"O_RDONLY"	},
-	{ O_WRONLY+1,	"O_WRONLY"	},
-	{ O_NONBLOCK,	"O_NONBLOCK"	},
-	{ O_APPEND,	"O_APPEND"	},
+const struct xlat open_access_modes[] = {
+	{ O_RDONLY,	"O_RDONLY"	},
+	{ O_WRONLY,	"O_WRONLY"	},
+	{ O_RDWR,	"O_RDWR"	},
+#ifdef O_ACCMODE
+	{ O_ACCMODE,	"O_ACCMODE"	},
+#endif
+	{ 0,		NULL		},
+};
+
+const struct xlat open_mode_flags[] = {
 	{ O_CREAT,	"O_CREAT"	},
-	{ O_TRUNC,	"O_TRUNC"	},
 	{ O_EXCL,	"O_EXCL"	},
 	{ O_NOCTTY,	"O_NOCTTY"	},
+	{ O_TRUNC,	"O_TRUNC"	},
+	{ O_APPEND,	"O_APPEND"	},
+	{ O_NONBLOCK,	"O_NONBLOCK"	},
 #ifdef O_SYNC
 	{ O_SYNC,	"O_SYNC"	},
 #endif
@@ -307,23 +318,74 @@ const struct xlat openmodes[] = {
 	{ 0,		NULL		},
 };
 
-int
-sys_open(tcp)
-struct tcb *tcp;
+#ifdef LINUX
+
+#ifndef AT_FDCWD
+# define AT_FDCWD                -100
+#endif
+
+static void
+print_dirfd(long fd)
+{
+	if (fd == AT_FDCWD)
+		tprintf("AT_FDCWD, ");
+	else
+		tprintf("%ld, ", fd);
+}
+#endif
+
+/*
+ * low bits of the open(2) flags define access mode,
+ * other bits are real flags.
+ */
+void
+tprint_open_modes(struct tcb *tcp, mode_t flags)
+{
+	const char *str = xlookup(open_access_modes, flags & 3);
+
+	if (str)
+	{
+		tprintf("%s", str);
+		flags &= ~3;
+		if (!flags)
+			return;
+		tprintf("|");
+	}
+	printflags(open_mode_flags, flags, "O_???");
+}
+
+static int
+decode_open(struct tcb *tcp, int offset)
 {
 	if (entering(tcp)) {
-		printpath(tcp, tcp->u_arg[0]);
+		printpath(tcp, tcp->u_arg[offset]);
 		tprintf(", ");
 		/* flags */
-		printflags(openmodes, tcp->u_arg[1] + 1, "O_???");
-		if (tcp->u_arg[1] & O_CREAT) {
+		tprint_open_modes(tcp, tcp->u_arg[offset + 1]);
+		if (tcp->u_arg[offset + 1] & O_CREAT) {
 			/* mode */
-			tprintf(", %#lo", tcp->u_arg[2]);
+			tprintf(", %#lo", tcp->u_arg[offset + 2]);
 		}
 	}
 	return 0;
 }
 
+int
+sys_open(struct tcb *tcp)
+{
+	return decode_open(tcp, 0);
+}
+
+#ifdef LINUX
+int
+sys_openat(struct tcb *tcp)
+{
+	if (entering(tcp))
+		print_dirfd(tcp->u_arg[0]);
+	return decode_open(tcp, 1);
+}
+#endif
+
 #ifdef LINUXSPARC
 static const struct xlat openmodessol[] = {
 	{ 0,		"O_RDWR"	},
@@ -387,18 +449,33 @@ static const struct xlat access_flags[] = {
 	{ 0,		NULL		},
 };
 
-int
-sys_access(tcp)
-struct tcb *tcp;
+static int
+decode_access(struct tcb *tcp, int offset)
 {
 	if (entering(tcp)) {
-		printpath(tcp, tcp->u_arg[0]);
+		printpath(tcp, tcp->u_arg[offset]);
 		tprintf(", ");
-		printflags(access_flags, tcp->u_arg[1], "?_OK");
+		printflags(access_flags, tcp->u_arg[offset + 1], "?_OK");
 	}
 	return 0;
 }
 
+int
+sys_access(struct tcb *tcp)
+{
+	return decode_access(tcp, 0);
+}
+
+#ifdef LINUX
+int
+sys_faccessat(struct tcb *tcp)
+{
+	if (entering(tcp))
+		print_dirfd(tcp->u_arg[0]);
+	return decode_access(tcp, 1);
+}
+#endif
+
 int
 sys_umask(tcp)
 struct tcb *tcp;
@@ -1099,6 +1176,35 @@ struct tcb *tcp;
 #endif
 }
 
+#ifdef LINUX
+static const struct xlat fstatatflags[] = {
+#ifndef AT_SYMLINK_NOFOLLOW
+# define AT_SYMLINK_NOFOLLOW     0x100
+#endif
+	{ AT_SYMLINK_NOFOLLOW,	"AT_SYMLINK_NOFOLLOW"	},
+	{ 0,			NULL			},
+};
+
+int
+sys_newfstatat(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		print_dirfd(tcp->u_arg[0]);
+		printpath(tcp, tcp->u_arg[1]);
+		tprintf(", ");
+	} else {
+#ifdef HAVE_STAT64
+		printstat64(tcp, tcp->u_arg[2]);
+#else
+		printstat(tcp, tcp->u_arg[2]);
+#endif
+		tprintf(", ");
+		printflags(fstatatflags, tcp->u_arg[3], "AT_???");
+	}
+	return 0;
+}
+#endif
+
 #if defined(LINUX) && defined(HAVE_STRUCT___OLD_KERNEL_STAT)
 int
 sys_oldstat(tcp)
@@ -1684,17 +1790,32 @@ struct tcb *tcp;
 	return 0;
 }
 
-int
-sys_mkdir(tcp)
-struct tcb *tcp;
+static int
+decode_mkdir(struct tcb *tcp, int offset)
 {
 	if (entering(tcp)) {
-		printpath(tcp, tcp->u_arg[0]);
-		tprintf(", %#lo", tcp->u_arg[1]);
+		printpath(tcp, tcp->u_arg[offset]);
+		tprintf(", %#lo", tcp->u_arg[offset + 1]);
 	}
 	return 0;
 }
 
+int
+sys_mkdir(struct tcb *tcp)
+{
+	return decode_mkdir(tcp, 0);
+}
+
+#ifdef LINUX
+int
+sys_mkdirat(struct tcb *tcp)
+{
+	if (entering(tcp))
+		print_dirfd(tcp->u_arg[0]);
+	return decode_mkdir(tcp, 1);
+}
+#endif
+
 int
 sys_rmdir(tcp)
 struct tcb *tcp;
@@ -1725,6 +1846,7 @@ struct tcb *tcp;
 	return 0;
 }
 
+#if defined(SUNOS4) || defined(SVR4)
 int
 sys_fchroot(tcp)
 struct tcb *tcp;
@@ -1734,6 +1856,7 @@ struct tcb *tcp;
 	}
 	return 0;
 }
+#endif /* SUNOS4 || SVR4 */
 
 int
 sys_link(tcp)
@@ -1747,6 +1870,22 @@ struct tcb *tcp;
 	return 0;
 }
 
+#ifdef LINUX
+int
+sys_linkat(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		print_dirfd(tcp->u_arg[0]);
+		printpath(tcp, tcp->u_arg[1]);
+		tprintf(", ");
+		print_dirfd(tcp->u_arg[2]);
+		printpath(tcp, tcp->u_arg[3]);
+		tprintf(", %ld", tcp->u_arg[4]);
+	}
+	return 0;
+}
+#endif
+
 int
 sys_unlink(tcp)
 struct tcb *tcp;
@@ -1757,6 +1896,28 @@ struct tcb *tcp;
 	return 0;
 }
 
+#ifdef LINUX
+static const struct xlat unlinkatflags[] = {
+#ifndef AT_REMOVEDIR
+# define AT_REMOVEDIR            0x200
+#endif
+	{ AT_REMOVEDIR,	"AT_REMOVEDIR"	},
+	{ 0,		NULL		},
+};
+
+int
+sys_unlinkat(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		print_dirfd(tcp->u_arg[0]);
+		printpath(tcp, tcp->u_arg[1]);
+		tprintf(", ");
+		printflags(unlinkatflags, tcp->u_arg[2], "AT_???");
+	}
+	return 0;
+}
+#endif
+
 int
 sys_symlink(tcp)
 struct tcb *tcp;
@@ -1769,22 +1930,51 @@ struct tcb *tcp;
 	return 0;
 }
 
+#ifdef LINUX
 int
-sys_readlink(tcp)
-struct tcb *tcp;
+sys_symlinkat(struct tcb *tcp)
 {
 	if (entering(tcp)) {
 		printpath(tcp, tcp->u_arg[0]);
 		tprintf(", ");
-	} else {
-		if (syserror(tcp))
-			tprintf("%#lx", tcp->u_arg[1]);
-		else
-			printpathn(tcp, tcp->u_arg[1], tcp->u_rval);
-		tprintf(", %lu", tcp->u_arg[2]);
+		print_dirfd(tcp->u_arg[1]);
+		printpath(tcp, tcp->u_arg[2]);
 	}
 	return 0;
 }
+#endif
+
+static int
+decode_readlink(struct tcb *tcp, int offset)
+{
+	if (entering(tcp)) {
+		printpath(tcp, tcp->u_arg[offset]);
+		tprintf(", ");
+	} else {
+		if (syserror(tcp))
+			tprintf("%#lx", tcp->u_arg[offset + 1]);
+		else
+			printpathn(tcp, tcp->u_arg[offset + 1], tcp->u_rval);
+		tprintf(", %lu", tcp->u_arg[offset + 2]);
+	}
+	return 0;
+}
+
+int
+sys_readlink(struct tcb *tcp)
+{
+	return decode_readlink(tcp, 0);
+}
+
+#ifdef LINUX
+int
+sys_readlinkat(struct tcb *tcp)
+{
+	if (entering(tcp))
+		print_dirfd(tcp->u_arg[0]);
+	return decode_readlink(tcp, 1);
+}
+#endif
 
 int
 sys_rename(tcp)
@@ -1798,6 +1988,21 @@ struct tcb *tcp;
 	return 0;
 }
 
+#ifdef LINUX
+int
+sys_renameat(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		print_dirfd(tcp->u_arg[0]);
+		printpath(tcp, tcp->u_arg[1]);
+		tprintf(", ");
+		print_dirfd(tcp->u_arg[2]);
+		printpath(tcp, tcp->u_arg[3]);
+	}
+	return 0;
+}
+#endif
+
 int
 sys_chown(tcp)
 struct tcb *tcp;
@@ -1810,6 +2015,22 @@ struct tcb *tcp;
 	return 0;
 }
 
+#ifdef LINUX
+int
+sys_fchownat(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		print_dirfd(tcp->u_arg[0]);
+		printpath(tcp, tcp->u_arg[1]);
+		printuid(", ", tcp->u_arg[2]);
+		printuid(", ", tcp->u_arg[3]);
+		tprintf(", ");
+		printflags(fstatatflags, tcp->u_arg[4], "AT_???");
+	}
+	return 0;
+}
+#endif
+
 int
 sys_fchown(tcp)
 struct tcb *tcp;
@@ -1822,17 +2043,32 @@ struct tcb *tcp;
 	return 0;
 }
 
-int
-sys_chmod(tcp)
-struct tcb *tcp;
+static int
+decode_chmod(struct tcb *tcp, int offset)
 {
 	if (entering(tcp)) {
-		printpath(tcp, tcp->u_arg[0]);
-		tprintf(", %#lo", tcp->u_arg[1]);
+		printpath(tcp, tcp->u_arg[offset]);
+		tprintf(", %#lo", tcp->u_arg[offset + 1]);
 	}
 	return 0;
 }
 
+int
+sys_chmod(struct tcb *tcp)
+{
+	return decode_chmod(tcp, 0);
+}
+
+#ifdef LINUX
+int
+sys_fchmodat(struct tcb *tcp)
+{
+	if (entering(tcp))
+		print_dirfd(tcp->u_arg[0]);
+	return decode_chmod(tcp, 1);
+}
+#endif
+
 int
 sys_fchmod(tcp)
 struct tcb *tcp;
@@ -1851,24 +2087,39 @@ struct tcb *tcp;
     if (entering(tcp)) {
 	printpath(tcp, tcp->u_arg[0]);
 	tprintf(", ");
-	printtv32(tcp, tcp->u_arg[1]);
+	printtv_bitness(tcp, tcp->u_arg[1], BITNESS_32);
     }
     return 0;
 }
 #endif
 
-int
-sys_utimes(tcp)
-struct tcb *tcp;
+static int
+decode_utimes(struct tcb *tcp, int offset)
 {
 	if (entering(tcp)) {
-		printpath(tcp, tcp->u_arg[0]);
+		printpath(tcp, tcp->u_arg[offset]);
 		tprintf(", ");
-		printtv(tcp, tcp->u_arg[1]);
+		printtv(tcp, tcp->u_arg[offset + 1]);
 	}
 	return 0;
 }
 
+int
+sys_utimes(struct tcb *tcp)
+{
+	return decode_utimes(tcp, 0);
+}
+
+#ifdef LINUX
+int
+sys_futimesat(struct tcb *tcp)
+{
+	if (entering(tcp))
+		print_dirfd(tcp->u_arg[0]);
+	return decode_utimes(tcp, 1);
+}
+#endif
+
 int
 sys_utime(tcp)
 struct tcb *tcp;
@@ -1893,27 +2144,26 @@ struct tcb *tcp;
 	return 0;
 }
 
-int
-sys_mknod(tcp)
-struct tcb *tcp;
+static int
+decode_mknod(struct tcb *tcp, int offset)
 {
-	int mode = tcp->u_arg[1];
+	int mode = tcp->u_arg[offset + 1];
 
 	if (entering(tcp)) {
-		printpath(tcp, tcp->u_arg[0]);
+		printpath(tcp, tcp->u_arg[offset]);
 		tprintf(", %s", sprintmode(mode));
 		switch (mode & S_IFMT) {
 		case S_IFCHR: case S_IFBLK:
 #ifdef LINUXSPARC
 			if (current_personality == 1)
 			tprintf(", makedev(%lu, %lu)",
-				(unsigned long) ((tcp->u_arg[2] >> 18) & 0x3fff),
-				(unsigned long) (tcp->u_arg[2] & 0x3ffff));
+				(unsigned long) ((tcp->u_arg[offset + 2] >> 18) & 0x3fff),
+				(unsigned long) (tcp->u_arg[offset + 2] & 0x3ffff));
 			else
 #endif
 			tprintf(", makedev(%lu, %lu)",
-				(unsigned long) major(tcp->u_arg[2]),
-				(unsigned long) minor(tcp->u_arg[2]));
+				(unsigned long) major(tcp->u_arg[offset + 2]),
+				(unsigned long) minor(tcp->u_arg[offset + 2]));
 			break;
 		default:
 			break;
@@ -1922,6 +2172,23 @@ struct tcb *tcp;
 	return 0;
 }
 
+int
+sys_mknod(struct tcb *tcp)
+{
+	return decode_mknod(tcp, 0);
+}
+
+#ifdef LINUX
+int
+sys_mknodat(struct tcb *tcp)
+{
+	if (entering(tcp))
+		print_dirfd(tcp->u_arg[0]);
+	return decode_mknod(tcp, 1);
+}
+#endif
+
+#ifdef FREEBSD
 int
 sys_mkfifo(tcp)
 struct tcb *tcp;
@@ -1932,6 +2199,7 @@ struct tcb *tcp;
 	}
 	return 0;
 }
+#endif /* FREEBSD */
 
 int
 sys_fsync(tcp)
@@ -2118,7 +2386,7 @@ struct tcb *tcp;
 		struct dirent64 *d = (struct dirent64 *) &buf[i];
 #if defined(LINUX) || defined(SVR4)
 		if (!abbrev(tcp)) {
-			tprintf("%s{d_ino=%llu, d_off=%llu, ",
+			tprintf("%s{d_ino=%" PRIu64 ", d_off=%" PRId64 ", ",
 				i ? " " : "",
 				d->d_ino,
 				d->d_off);
@@ -2360,7 +2628,7 @@ unsigned long insize, size;
 		    *out++ = tohex(in[i] % 16);
 		}
 	    /* Don't print terminating NUL if there is one.  */
-	    if (in[i - 1] == '\0')
+	    if (i > 0 && in[i - 1] == '\0')
 		out -= 4;
 	    *out = '\0';
 	    tprintf(", \"%s\", %ld", buf, insize);
@@ -2529,3 +2797,49 @@ struct tcb *tcp;
     }
     return 0;
 }
+
+#ifdef LINUX
+static const struct xlat inotify_modes[] = {
+	{ 0x00000001, "IN_ACCESS" },
+	{ 0x00000002, "IN_MODIFY" },
+	{ 0x00000004, "IN_ATTRIB" },
+	{ 0x00000008, "IN_CLOSE_WRITE" },
+	{ 0x00000010, "IN_CLOSE_NOWRITE" },
+	{ 0x00000020, "IN_OPEN" },
+	{ 0x00000040, "IN_MOVED_FROM" },
+	{ 0x00000080, "IN_MOVED_TO" },
+	{ 0x00000100, "IN_CREATE" },
+	{ 0x00000200, "IN_DELETE" },
+	{ 0x00000400, "IN_DELETE_SELF" },
+	{ 0x00000800, "IN_MOVE_SELF" },
+	{ 0x00002000, "IN_UNMOUNT" },
+	{ 0x00004000, "IN_Q_OVERFLOW" },
+	{ 0x00008000, "IN_IGNORED" },
+	{ 0x01000000, "IN_ONLYDIR" },
+	{ 0x02000000, "IN_DONT_FOLLOW" },
+	{ 0x20000000, "IN_MASK_ADD" },
+	{ 0x40000000, "IN_ISDIR" },
+	{ 0x80000000, "IN_ONESHOT" }
+};
+
+int
+sys_inotify_add_watch(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		tprintf("%ld, ", tcp->u_arg[0]);
+		printpath(tcp, tcp->u_arg[1]);
+		tprintf(", ");
+		printflags(inotify_modes, tcp->u_arg[2], "IN_???");
+	}
+	return 0;
+}
+
+int
+sys_inotify_rm_watch(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		tprintf("%ld, %ld", tcp->u_arg[0], tcp->u_arg[1]);
+	}
+	return 0;
+}
+#endif
