@@ -25,11 +25,11 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.4 2006/01/12 22:34:50 roland Exp $
+ *	$Id: syscallent.h,v 1.6 2006/08/22 06:06:12 roland Exp $
  */
 
 	{ 0,	0,	sys_restart_syscall,	"restart_syscall"}, /* 0 */
-	{ 1,	TP,	sys_exit,		"_exit"		}, /* 1 */
+	{ 1,	TP,	sys_exit,		"exit"		}, /* 1 */
 	{ 0,	TP,	sys_fork,		"fork"		}, /* 2 */
 	{ 3,	0,	sys_read,		"read"		}, /* 3 */
 	{ 3,	0,	sys_write,		"write"		}, /* 4 */
@@ -44,11 +44,7 @@
 	{ 1,	0,	sys_time,		"time"		}, /* 13 */
 	{ 3,	TF,	sys_mknod,		"mknod"		}, /* 14 */
 	{ 2,	TF,	sys_chmod,		"chmod"		}, /* 15 */
-#ifdef M68K
-	{ 3,	TF,	sys_chown,		"chown"		}, /* 16 */
-#else
 	{ 3,	TF,	sys_chown,		"lchown"	}, /* 16 */
-#endif
 	{ 0,	0,	sys_break,		"break"		}, /* 17 */
 	{ 2,	TF,	sys_oldstat,		"oldstat"	}, /* 18 */
 	{ 3,	0,	sys_lseek,		"lseek"		}, /* 19 */
@@ -155,11 +151,7 @@
 	{ 5,	TP,	sys_clone,		"clone"		}, /* 120 */
 	{ 2,	0,	sys_setdomainname,	"setdomainname"	}, /* 121 */
 	{ 1,	0,	sys_uname,		"uname"		}, /* 122 */
-#ifdef M68K
-	{ 4,	0,	sys_cacheflush,		"cacheflush"	}, /* 123 */
-#else
 	{ 3,	0,	sys_modify_ldt,		"modify_ldt"	}, /* 123 */
-#endif
 	{ 1,	0,	sys_adjtimex,		"adjtimex"	}, /* 124 */
 	{ 3,	0,	sys_mprotect,		"mprotect"	}, /* 125 */
 	{ 3,	TS,	sys_sigprocmask,	"sigprocmask"	}, /* 126 */
@@ -202,11 +194,7 @@
 	{ 4,	0,	sys_mremap,		"mremap"	}, /* 163 */
 	{ 3,	0,	sys_setresuid,		"setresuid"	}, /* 164 */
 	{ 3,	0,	sys_getresuid,		"getresuid"	}, /* 165 */
-#ifdef M68K
-	{ 5,	0,	printargs,		"SYS_166"	}, /* 166 */
-#else
 	{ 5,	0,	printargs,		"vm86"		}, /* 166 */
-#endif
 	{ 5,	0,	sys_query_module,	"query_module"	}, /* 167 */
 	{ 3,	0,	sys_poll,		"poll"		}, /* 168 */
 	{ 3,	0,	printargs,		"nfsservctl"	}, /* 169 */
@@ -223,11 +211,7 @@
 
 	{ 5,	TF,	sys_pread,		"pread"		}, /* 180 */
 	{ 5,	TF,	sys_pwrite,		"pwrite"	}, /* 181 */
-#ifdef M68K
-	{ 3,	TF,	sys_chown,		"lchown"	}, /* 182 */
-#else
 	{ 3,	TF,	sys_chown,		"chown"		}, /* 182 */
-#endif
 	{ 2,	TF,	sys_getcwd,		"getcwd"	}, /* 183 */
 	{ 2,	0,	sys_capget,		"capget"	}, /* 184 */
 	{ 2,	0,	sys_capset,		"capset"	}, /* 185 */
@@ -268,8 +252,8 @@
 	{ 3,	0,	printargs,		"mincore"	}, /* 219 */
 	{ 3,	0,	sys_madvise,		"madvise"	}, /* 220 */
 	{ 3,	0,	sys_fcntl,		"fcntl64"	}, /* 221 */
-	{ 4,	0,	printargs,		"SYS_222"	}, /* 222 */
-/*TODO*/{ 5,	0,	printargs,		"security"	}, /* 223 */
+	{ 5,	0,	printargs,		"SYS_222"	}, /* 222 */
+	{ 5,	0,	printargs,		"SYS_223"	}, /* 223 */
 	{ 0,	0,	printargs,		"gettid"	}, /* 224 */
 	{ 4,	0,	sys_readahead,		"readahead"	}, /* 225 */
 	{ 5,	TF,	sys_setxattr,		"setxattr"	}, /* 226 */
@@ -289,46 +273,46 @@
 	{ 5,	0,	sys_futex,		"futex"		}, /* 240 */
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity" },/* 241 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity" },/* 242 */
-	{ 1,	0,	sys_set_thread_area,	"set_thread_area" }, /* 243 */
-	{ 1,	0,	sys_get_thread_area,	"get_thread_area" }, /* 244 */
-	{ 2,	0,	printargs,		"io_setup"	}, /* 245 */
-	{ 1,	0,	printargs,		"io_destroy"	}, /* 246 */
-	{ 5,	0,	printargs,		"io_getevents"	}, /* 247 */
-	{ 3,	0,	printargs,		"io_submit"	}, /* 248 */
-	{ 3,	0,	printargs,		"io_cancel"	}, /* 249 */
-	{ 5,	0,	printargs,		"SYS_250"	}, /* 250 */
-	{ 5,	0,	printargs,		"SYS_251"	}, /* 251 */
-	{ 1,	TP,	sys_exit,		"exit_group"	}, /* 252 */
-	{ 4,	0,	printargs,		"lookup_dcookie"}, /* 253 */
-	{ 1,	0,	printargs,		"epoll_create"	}, /* 254 */
-	{ 4,	0,	printargs,		"epoll_ctl"	}, /* 255 */
-	{ 4,	0,	printargs,		"epoll_wait"	}, /* 256 */
-	{ 5,	0,	sys_remap_file_pages,	"remap_file_pages"}, /* 257 */
-	{ 1,	0,	printargs,		"set_tid_address"}, /* 258 */
-	{ 3,	0,	sys_timer_create,	"timer_create"	}, /* 259 */
-	{ 4,	0,	sys_timer_settime,	"timer_settime"	}, /* 260 */
-	{ 2,	0,	sys_timer_gettime,	"timer_gettime"	}, /* 261 */
-	{ 1,	0,	sys_timer_getoverrun,	"timer_getoverrun"}, /* 262 */
-	{ 1,	0,	sys_timer_delete,	"timer_delete"	}, /* 263 */
-	{ 2,	0,	sys_clock_settime,	"clock_settime"	}, /* 264 */
-	{ 2,	0,	sys_clock_gettime,	"clock_gettime"	}, /* 265 */
-	{ 2,	0,	sys_clock_getres,	"clock_getres"	}, /* 266 */
-	{ 4,	0,	sys_clock_nanosleep,	"clock_nanosleep"}, /* 267 */
-	{ 3,	TF,	sys_statfs64,		"statfs64"	}, /* 268 */
-	{ 3,	0,	sys_fstatfs64,		"fstatfs64"	}, /* 269 */
-	{ 3,	TS,	sys_tgkill,		"tgkill"	}, /* 270 */
-	{ 2,	TF,	sys_utimes,		"utimes"	}, /* 271 */
-	{ 5,	0,	printargs,		"SYS_272"	}, /* 272 */
-	{ 5,	0,	printargs,		"SYS_273"	}, /* 273 */
-	{ 5,	0,	printargs,		"SYS_274"	}, /* 274 */
-	{ 5,	0,	printargs,		"SYS_275"	}, /* 275 */
-	{ 5,	0,	printargs,		"SYS_276"	}, /* 276 */
-	{ 4,	0,	sys_mq_open,		"mq_open"	}, /* 277 */
-	{ 1,	0,	sys_mq_unlink,		"mq_unlink"	}, /* 278 */
-	{ 5,	0,	sys_mq_timedsend,	"mq_timedsend"	}, /* 279 */
-	{ 5,	0,	sys_mq_timedreceive,	"mq_timedreceive" }, /* 280 */
-	{ 2,	0,	sys_mq_notify,		"mq_notify"	}, /* 281 */
-	{ 3,	0,	sys_mq_getsetattr,	"mq_getsetattr"	}, /* 282 */
+	{ 2,	0,	printargs,		"io_setup"	}, /* 243 */
+	{ 1,	0,	printargs,		"io_destroy"	}, /* 244 */
+	{ 5,	0,	printargs,		"io_getevents"	}, /* 245 */
+	{ 3,	0,	printargs,		"io_submit"	}, /* 246 */
+	{ 3,	0,	printargs,		"io_cancel"	}, /* 247 */
+	{ 1,	TP,	sys_exit,		"exit_group"	}, /* 248 */
+	{ 4,	0,	printargs,		"lookup_dcookie"}, /* 249 */
+	{ 1,	0,	printargs,		"epoll_create"	}, /* 250 */
+	{ 4,	0,	printargs,		"epoll_ctl"	}, /* 251 */
+	{ 4,	0,	printargs,		"epoll_wait"	}, /* 252 */
+	{ 5,	0,	sys_remap_file_pages,	"remap_file_pages"}, /* 253 */
+	{ 5,	0,	printargs,		"SYS_254"	}, /* 254 */
+	{ 5,	0,	printargs,		"SYS_255"	}, /* 255 */
+	{ 1,	0,	printargs,		"set_tid_address"}, /* 256 */
+	{ 3,	0,	sys_timer_create,	"timer_create"	}, /* 257 */
+	{ 4,	0,	sys_timer_settime,	"timer_settime"	}, /* 258 */
+	{ 2,	0,	sys_timer_gettime,	"timer_gettime"	}, /* 259 */
+	{ 1,	0,	sys_timer_getoverrun,	"timer_getoverrun"}, /* 260 */
+	{ 1,	0,	sys_timer_delete,	"timer_delete"	}, /* 261 */
+	{ 2,	0,	sys_clock_settime,	"clock_settime"	}, /* 262 */
+	{ 2,	0,	sys_clock_gettime,	"clock_gettime"	}, /* 263 */
+	{ 2,	0,	sys_clock_getres,	"clock_getres"	}, /* 264 */
+	{ 4,	0,	sys_clock_nanosleep,	"clock_nanosleep"}, /* 265 */
+	{ 3,	TF,	sys_statfs64,		"statfs64"	}, /* 266 */
+	{ 3,	0,	sys_fstatfs64,		"fstatfs64"	}, /* 267 */
+	{ 3,	TS,	sys_tgkill,		"tgkill"	}, /* 268 */
+	{ 2,	TF,	sys_utimes,		"utimes"	}, /* 269 */
+	{ 6,	0,	sys_fadvise64_64,	"fadvise64_64"	}, /* 270 */
+	{ 5,	0,	printargs,		"pciconfig_iobase"	}, /* 271 */
+	{ 5,	0,	printargs,		"pciconfig_read"	}, /* 272 */
+	{ 5,	0,	printargs,		"pciconfig_write"	}, /* 273 */
+	{ 4,	0,	sys_mq_open,		"mq_open"	}, /* 274 */
+	{ 1,	0,	sys_mq_unlink,		"mq_unlink"	}, /* 275 */
+	{ 5,	0,	sys_mq_timedsend,	"mq_timedsend"	}, /* 276 */
+	{ 5,	0,	sys_mq_timedreceive,	"mq_timedreceive" }, /* 277 */
+	{ 2,	0,	sys_mq_notify,		"mq_notify"	}, /* 278 */
+	{ 3,	0,	sys_mq_getsetattr,	"mq_getsetattr"	}, /* 279 */
+	{ 5,	TP,	sys_waitid,		"waitid"	}, /* 280 */
+	{ 5,	0,	printargs,		"SYS_281"	}, /* 281 */
+	{ 5,	0,	printargs,		"SYS_282"	}, /* 282 */
 	{ 5,	0,	printargs,		"SYS_283"	}, /* 283 */
 	{ 5,	0,	printargs,		"SYS_284"	}, /* 284 */
 	{ 5,	0,	printargs,		"SYS_285"	}, /* 285 */
@@ -346,54 +330,154 @@
 	{ 5,	0,	printargs,		"SYS_297"	}, /* 297 */
 	{ 5,	0,	printargs,		"SYS_298"	}, /* 298 */
 	{ 5,	0,	printargs,		"SYS_299"	}, /* 299 */
+	{ 5,	0,	printargs,		"SYS_300"	}, /* 300 */
+	{ 5,	0,	printargs,		"SYS_301"	}, /* 301 */
+	{ 5,	0,	printargs,		"SYS_302"	}, /* 302 */
+	{ 5,	0,	printargs,		"SYS_303"	}, /* 303 */
+	{ 5,	0,	printargs,		"SYS_304"	}, /* 304 */
+	{ 5,	0,	printargs,		"SYS_305"	}, /* 305 */
+	{ 5,	0,	printargs,		"SYS_306"	}, /* 306 */
+	{ 5,	0,	printargs,		"SYS_307"	}, /* 307 */
+	{ 5,	0,	printargs,		"SYS_308"	}, /* 308 */
+	{ 5,	0,	printargs,		"SYS_309"	}, /* 309 */
+	{ 5,	0,	printargs,		"SYS_310"	}, /* 310 */
+	{ 5,	0,	printargs,		"SYS_311"	}, /* 311 */
+	{ 5,	0,	printargs,		"SYS_312"	}, /* 312 */
+	{ 5,	0,	printargs,		"SYS_313"	}, /* 313 */
+	{ 5,	0,	printargs,		"SYS_314"	}, /* 314 */
+	{ 5,	0,	printargs,		"SYS_315"	}, /* 315 */
+	{ 5,	0,	printargs,		"SYS_316"	}, /* 316 */
+	{ 5,	0,	printargs,		"SYS_317"	}, /* 317 */
+	{ 5,	0,	printargs,		"SYS_318"	}, /* 318 */
+	{ 5,	0,	printargs,		"SYS_319"	}, /* 319 */
+	{ 5,	0,	printargs,		"SYS_320"	}, /* 320 */
+	{ 5,	0,	printargs,		"SYS_321"	}, /* 321 */
+	{ 5,	0,	printargs,		"SYS_322"	}, /* 322 */
+	{ 5,	0,	printargs,		"SYS_323"	}, /* 323 */
+	{ 5,	0,	printargs,		"SYS_324"	}, /* 324 */
+	{ 5,	0,	printargs,		"SYS_325"	}, /* 325 */
+	{ 5,	0,	printargs,		"SYS_326"	}, /* 326 */
+	{ 5,	0,	printargs,		"SYS_327"	}, /* 327 */
+	{ 5,	0,	printargs,		"SYS_328"	}, /* 328 */
+	{ 5,	0,	printargs,		"SYS_329"	}, /* 329 */
+	{ 5,	0,	printargs,		"SYS_330"	}, /* 330 */
+	{ 5,	0,	printargs,		"SYS_331"	}, /* 331 */
+	{ 5,	0,	printargs,		"SYS_332"	}, /* 332 */
+	{ 5,	0,	printargs,		"SYS_333"	}, /* 333 */
+	{ 5,	0,	printargs,		"SYS_334"	}, /* 334 */
+	{ 5,	0,	printargs,		"SYS_335"	}, /* 335 */
+	{ 5,	0,	printargs,		"SYS_336"	}, /* 336 */
+	{ 5,	0,	printargs,		"SYS_337"	}, /* 337 */
+	{ 5,	0,	printargs,		"SYS_338"	}, /* 338 */
+	{ 5,	0,	printargs,		"SYS_339"	}, /* 339 */
+	{ 5,	0,	printargs,		"SYS_340"	}, /* 340 */
+	{ 5,	0,	printargs,		"SYS_341"	}, /* 341 */
+	{ 5,	0,	printargs,		"SYS_342"	}, /* 342 */
+	{ 5,	0,	printargs,		"SYS_343"	}, /* 343 */
+	{ 5,	0,	printargs,		"SYS_344"	}, /* 344 */
+	{ 5,	0,	printargs,		"SYS_345"	}, /* 345 */
+	{ 5,	0,	printargs,		"SYS_346"	}, /* 346 */
+	{ 5,	0,	printargs,		"SYS_347"	}, /* 347 */
+	{ 5,	0,	printargs,		"SYS_348"	}, /* 348 */
+	{ 5,	0,	printargs,		"SYS_349"	}, /* 349 */
+	{ 5,	0,	printargs,		"SYS_350"	}, /* 350 */
+	{ 5,	0,	printargs,		"SYS_351"	}, /* 351 */
+	{ 5,	0,	printargs,		"SYS_352"	}, /* 352 */
+	{ 5,	0,	printargs,		"SYS_353"	}, /* 353 */
+	{ 5,	0,	printargs,		"SYS_354"	}, /* 354 */
+	{ 5,	0,	printargs,		"SYS_355"	}, /* 355 */
+	{ 5,	0,	printargs,		"SYS_356"	}, /* 356 */
+	{ 5,	0,	printargs,		"SYS_357"	}, /* 357 */
+	{ 5,	0,	printargs,		"SYS_358"	}, /* 358 */
+	{ 5,	0,	printargs,		"SYS_359"	}, /* 359 */
+	{ 5,	0,	printargs,		"SYS_360"	}, /* 360 */
+	{ 5,	0,	printargs,		"SYS_361"	}, /* 361 */
+	{ 5,	0,	printargs,		"SYS_362"	}, /* 362 */
+	{ 5,	0,	printargs,		"SYS_363"	}, /* 363 */
+	{ 5,	0,	printargs,		"SYS_364"	}, /* 364 */
+	{ 5,	0,	printargs,		"SYS_365"	}, /* 365 */
+	{ 5,	0,	printargs,		"SYS_366"	}, /* 366 */
+	{ 5,	0,	printargs,		"SYS_367"	}, /* 367 */
+	{ 5,	0,	printargs,		"SYS_368"	}, /* 368 */
+	{ 5,	0,	printargs,		"SYS_369"	}, /* 369 */
+	{ 5,	0,	printargs,		"SYS_370"	}, /* 370 */
+	{ 5,	0,	printargs,		"SYS_371"	}, /* 371 */
+	{ 5,	0,	printargs,		"SYS_372"	}, /* 372 */
+	{ 5,	0,	printargs,		"SYS_373"	}, /* 373 */
+	{ 5,	0,	printargs,		"SYS_374"	}, /* 374 */
+	{ 5,	0,	printargs,		"SYS_375"	}, /* 375 */
+	{ 5,	0,	printargs,		"SYS_376"	}, /* 376 */
+	{ 5,	0,	printargs,		"SYS_377"	}, /* 377 */
+	{ 5,	0,	printargs,		"SYS_378"	}, /* 378 */
+	{ 5,	0,	printargs,		"SYS_379"	}, /* 379 */
+	{ 5,	0,	printargs,		"SYS_380"	}, /* 380 */
+	{ 5,	0,	printargs,		"SYS_381"	}, /* 381 */
+	{ 5,	0,	printargs,		"SYS_382"	}, /* 382 */
+	{ 5,	0,	printargs,		"SYS_383"	}, /* 383 */
+	{ 5,	0,	printargs,		"SYS_384"	}, /* 384 */
+	{ 5,	0,	printargs,		"SYS_385"	}, /* 385 */
+	{ 5,	0,	printargs,		"SYS_386"	}, /* 386 */
+	{ 5,	0,	printargs,		"SYS_387"	}, /* 387 */
+	{ 5,	0,	printargs,		"SYS_388"	}, /* 388 */
+	{ 5,	0,	printargs,		"SYS_389"	}, /* 389 */
+	{ 5,	0,	printargs,		"SYS_390"	}, /* 390 */
+	{ 5,	0,	printargs,		"SYS_391"	}, /* 391 */
+	{ 5,	0,	printargs,		"SYS_392"	}, /* 392 */
+	{ 5,	0,	printargs,		"SYS_393"	}, /* 393 */
+	{ 5,	0,	printargs,		"SYS_394"	}, /* 394 */
+	{ 5,	0,	printargs,		"SYS_395"	}, /* 395 */
+	{ 5,	0,	printargs,		"SYS_396"	}, /* 396 */
+	{ 5,	0,	printargs,		"SYS_397"	}, /* 397 */
+	{ 5,	0,	printargs,		"SYS_398"	}, /* 398 */
+	{ 5,	0,	printargs,		"SYS_399"	}, /* 399 */
 
-#if SYS_socket_subcall != 300 && !defined X86_64 /* pers1 broken on x86-64 */
+#if SYS_socket_subcall != 400
  #error fix me
 #endif
-	{ 8,	0,	printargs,		"socket_subcall"}, /* 300 */
-	{ 3,	TN,	sys_socket,		"socket"	}, /* 301 */
-	{ 3,	TN,	sys_bind,		"bind"		}, /* 302 */
-	{ 3,	TN,	sys_connect,		"connect"	}, /* 303 */
-	{ 2,	TN,	sys_listen,		"listen"	}, /* 304 */
-	{ 3,	TN,	sys_accept,		"accept"	}, /* 305 */
-	{ 3,	TN,	sys_getsockname,	"getsockname"	}, /* 306 */
-	{ 3,	TN,	sys_getpeername,	"getpeername"	}, /* 307 */
-	{ 4,	TN,	sys_socketpair,		"socketpair"	}, /* 308 */
-	{ 4,	TN,	sys_send,		"send"		}, /* 309 */
-	{ 4,	TN,	sys_recv,		"recv"		}, /* 310 */
-	{ 6,	TN,	sys_sendto,		"sendto"	}, /* 311 */
-	{ 6,	TN,	sys_recvfrom,		"recvfrom"	}, /* 312 */
-	{ 2,	TN,	sys_shutdown,		"shutdown"	}, /* 313 */
-	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 314 */
-	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 315 */
-	{ 5,	TN,	sys_sendmsg,		"sendmsg"	}, /* 316 */
-	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 317 */
+	{ 8,	0,	printargs,		"socket_subcall"}, /* 400 */
+	{ 3,	TN,	sys_socket,		"socket"	}, /* 401 */
+	{ 3,	TN,	sys_bind,		"bind"		}, /* 402 */
+	{ 3,	TN,	sys_connect,		"connect"	}, /* 403 */
+	{ 2,	TN,	sys_listen,		"listen"	}, /* 404 */
+	{ 3,	TN,	sys_accept,		"accept"	}, /* 405 */
+	{ 3,	TN,	sys_getsockname,	"getsockname"	}, /* 406 */
+	{ 3,	TN,	sys_getpeername,	"getpeername"	}, /* 407 */
+	{ 4,	TN,	sys_socketpair,		"socketpair"	}, /* 408 */
+	{ 4,	TN,	sys_send,		"send"		}, /* 409 */
+	{ 4,	TN,	sys_recv,		"recv"		}, /* 410 */
+	{ 6,	TN,	sys_sendto,		"sendto"	}, /* 411 */
+	{ 6,	TN,	sys_recvfrom,		"recvfrom"	}, /* 412 */
+	{ 2,	TN,	sys_shutdown,		"shutdown"	}, /* 413 */
+	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 414 */
+	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 415 */
+	{ 5,	TN,	sys_sendmsg,		"sendmsg"	}, /* 416 */
+	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 417 */
 
-#if SYS_ipc_subcall != 318 && !defined X86_64 /* pers1 broken on x86-64 */
+#if SYS_ipc_subcall != 418
  #error fix me
 #endif
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 318 */
-	{ 4,	TI,	sys_semop,		"semop"		}, /* 319 */
-	{ 4,	TI,	sys_semget,		"semget"	}, /* 320 */
-	{ 4,	TI,	sys_semctl,		"semctl"	}, /* 321 */
-	{ 5,	TI,	sys_semtimedop,		"semtimedop"	}, /* 322 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 323 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 324 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 325 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 326 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 327 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 328 */
-	{ 4,	TI,	sys_msgsnd,		"msgsnd"	}, /* 329 */
-	{ 4,	TI,	sys_msgrcv,		"msgrcv"	}, /* 330 */
-	{ 4,	TI,	sys_msgget,		"msgget"	}, /* 331 */
-	{ 4,	TI,	sys_msgctl,		"msgctl"	}, /* 332 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 333 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 334 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 335 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 336 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 337 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 338 */
-	{ 4,	TI,	sys_shmat,		"shmat"		}, /* 339 */
-	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 340 */
-	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 341 */
-	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 342 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 418 */
+	{ 4,	TI,	sys_semop,		"semop"		}, /* 419 */
+	{ 4,	TI,	sys_semget,		"semget"	}, /* 420 */
+	{ 4,	TI,	sys_semctl,		"semctl"	}, /* 421 */
+	{ 5,	TI,	sys_semtimedop,		"semtimedop"	}, /* 422 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 423 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 424 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 425 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 426 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 427 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 428 */
+	{ 4,	TI,	sys_msgsnd,		"msgsnd"	}, /* 429 */
+	{ 4,	TI,	sys_msgrcv,		"msgrcv"	}, /* 430 */
+	{ 4,	TI,	sys_msgget,		"msgget"	}, /* 431 */
+	{ 4,	TI,	sys_msgctl,		"msgctl"	}, /* 432 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 433 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 434 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 435 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 436 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 437 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 438 */
+	{ 4,	TI,	sys_shmat,		"shmat"		}, /* 439 */
+	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 440 */
+	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 441 */
+	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 442 */
