@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.15 2003/07/17 09:07:41 roland Exp $
+ *	$Id: syscallent.h,v 1.24 2006/12/04 13:46:28 ldv Exp $
  */
 
 /*
@@ -245,107 +245,10 @@
 /* You must be careful to check ../syscallent.h so that this table
    starts where that one leaves off.
 */
+#if SYS_ipc_subcall + SYS_ipc_nsubcalls != 443
+# error fix me
+#endif
 
-	{ 8,	0,	printargs,		"SYS_343"	}, /* 343 */
-	{ 8,	0,	printargs,		"SYS_344"	}, /* 344 */
-	{ 8,	0,	printargs,		"SYS_345"	}, /* 345 */
-	{ 8,	0,	printargs,		"SYS_346"	}, /* 346 */
-	{ 8,	0,	printargs,		"SYS_347"	}, /* 347 */
-	{ 8,	0,	printargs,		"SYS_348"	}, /* 348 */
-	{ 8,	0,	printargs,		"SYS_349"	}, /* 349 */
-	{ 8,	0,	printargs,		"SYS_350"	}, /* 350 */
-	{ 8,	0,	printargs,		"SYS_351"	}, /* 351 */
-	{ 8,	0,	printargs,		"SYS_352"	}, /* 352 */
-	{ 8,	0,	printargs,		"SYS_353"	}, /* 353 */
-	{ 8,	0,	printargs,		"SYS_354"	}, /* 354 */
-	{ 8,	0,	printargs,		"SYS_355"	}, /* 355 */
-	{ 8,	0,	printargs,		"SYS_356"	}, /* 356 */
-	{ 8,	0,	printargs,		"SYS_357"	}, /* 357 */
-	{ 8,	0,	printargs,		"SYS_358"	}, /* 358 */
-	{ 8,	0,	printargs,		"SYS_359"	}, /* 359 */
-	{ 8,	0,	printargs,		"SYS_360"	}, /* 360 */
-	{ 8,	0,	printargs,		"SYS_361"	}, /* 361 */
-	{ 8,	0,	printargs,		"SYS_362"	}, /* 362 */
-	{ 8,	0,	printargs,		"SYS_363"	}, /* 363 */
-	{ 8,	0,	printargs,		"SYS_364"	}, /* 364 */
-	{ 8,	0,	printargs,		"SYS_365"	}, /* 365 */
-	{ 8,	0,	printargs,		"SYS_366"	}, /* 366 */
-	{ 8,	0,	printargs,		"SYS_367"	}, /* 367 */
-	{ 8,	0,	printargs,		"SYS_368"	}, /* 368 */
-	{ 8,	0,	printargs,		"SYS_369"	}, /* 369 */
-	{ 8,	0,	printargs,		"SYS_370"	}, /* 370 */
-	{ 8,	0,	printargs,		"SYS_371"	}, /* 371 */
-	{ 8,	0,	printargs,		"SYS_372"	}, /* 372 */
-	{ 8,	0,	printargs,		"SYS_373"	}, /* 373 */
-	{ 8,	0,	printargs,		"SYS_374"	}, /* 374 */
-	{ 8,	0,	printargs,		"SYS_375"	}, /* 375 */
-	{ 8,	0,	printargs,		"SYS_376"	}, /* 376 */
-	{ 8,	0,	printargs,		"SYS_377"	}, /* 377 */
-	{ 8,	0,	printargs,		"SYS_378"	}, /* 378 */
-	{ 8,	0,	printargs,		"SYS_379"	}, /* 379 */
-	{ 8,	0,	printargs,		"SYS_380"	}, /* 380 */
-	{ 8,	0,	printargs,		"SYS_381"	}, /* 381 */
-	{ 8,	0,	printargs,		"SYS_382"	}, /* 382 */
-	{ 8,	0,	printargs,		"SYS_383"	}, /* 383 */
-	{ 8,	0,	printargs,		"SYS_384"	}, /* 384 */
-	{ 8,	0,	printargs,		"SYS_385"	}, /* 385 */
-	{ 8,	0,	printargs,		"SYS_386"	}, /* 386 */
-	{ 8,	0,	printargs,		"SYS_387"	}, /* 387 */
-	{ 8,	0,	printargs,		"SYS_388"	}, /* 388 */
-	{ 8,	0,	printargs,		"SYS_389"	}, /* 389 */
-	{ 8,	0,	printargs,		"SYS_390"	}, /* 390 */
-	{ 8,	0,	printargs,		"SYS_391"	}, /* 391 */
-	{ 8,	0,	printargs,		"SYS_392"	}, /* 392 */
-	{ 8,	0,	printargs,		"SYS_393"	}, /* 393 */
-	{ 8,	0,	printargs,		"SYS_394"	}, /* 394 */
-	{ 8,	0,	printargs,		"SYS_395"	}, /* 395 */
-	{ 8,	0,	printargs,		"SYS_396"	}, /* 396 */
-	{ 8,	0,	printargs,		"SYS_397"	}, /* 397 */
-	{ 8,	0,	printargs,		"SYS_398"	}, /* 398 */
-	{ 8,	0,	printargs,		"SYS_399"	}, /* 399 */
-	{ 8,	0,	printargs,		"SYS_400"	}, /* 400 */
-	{ 8,	0,	printargs,		"SYS_401"	}, /* 401 */
-	{ 8,	0,	printargs,		"SYS_402"	}, /* 402 */
-	{ 8,	0,	printargs,		"SYS_403"	}, /* 403 */
-	{ 8,	0,	printargs,		"SYS_404"	}, /* 404 */
-	{ 8,	0,	printargs,		"SYS_405"	}, /* 405 */
-	{ 8,	0,	printargs,		"SYS_406"	}, /* 406 */
-	{ 8,	0,	printargs,		"SYS_407"	}, /* 407 */
-	{ 8,	0,	printargs,		"SYS_408"	}, /* 408 */
-	{ 8,	0,	printargs,		"SYS_409"	}, /* 409 */
-	{ 8,	0,	printargs,		"SYS_410"	}, /* 410 */
-	{ 8,	0,	printargs,		"SYS_411"	}, /* 411 */
-	{ 8,	0,	printargs,		"SYS_412"	}, /* 412 */
-	{ 8,	0,	printargs,		"SYS_413"	}, /* 413 */
-	{ 8,	0,	printargs,		"SYS_414"	}, /* 414 */
-	{ 8,	0,	printargs,		"SYS_415"	}, /* 415 */
-	{ 8,	0,	printargs,		"SYS_416"	}, /* 416 */
-	{ 8,	0,	printargs,		"SYS_417"	}, /* 417 */
-	{ 8,	0,	printargs,		"SYS_418"	}, /* 418 */
-	{ 8,	0,	printargs,		"SYS_419"	}, /* 419 */
-	{ 8,	0,	printargs,		"SYS_420"	}, /* 420 */
-	{ 8,	0,	printargs,		"SYS_421"	}, /* 421 */
-	{ 8,	0,	printargs,		"SYS_422"	}, /* 422 */
-	{ 8,	0,	printargs,		"SYS_423"	}, /* 423 */
-	{ 8,	0,	printargs,		"SYS_424"	}, /* 424 */
-	{ 8,	0,	printargs,		"SYS_425"	}, /* 425 */
-	{ 8,	0,	printargs,		"SYS_426"	}, /* 426 */
-	{ 8,	0,	printargs,		"SYS_427"	}, /* 427 */
-	{ 8,	0,	printargs,		"SYS_428"	}, /* 428 */
-	{ 8,	0,	printargs,		"SYS_429"	}, /* 429 */
-	{ 8,	0,	printargs,		"SYS_430"	}, /* 430 */
-	{ 8,	0,	printargs,		"SYS_431"	}, /* 431 */
-	{ 8,	0,	printargs,		"SYS_432"	}, /* 432 */
-	{ 8,	0,	printargs,		"SYS_433"	}, /* 433 */
-	{ 8,	0,	printargs,		"SYS_434"	}, /* 434 */
-	{ 8,	0,	printargs,		"SYS_435"	}, /* 435 */
-	{ 8,	0,	printargs,		"SYS_436"	}, /* 436 */
-	{ 8,	0,	printargs,		"SYS_437"	}, /* 437 */
-	{ 8,	0,	printargs,		"SYS_438"	}, /* 438 */
-	{ 8,	0,	printargs,		"SYS_439"	}, /* 439 */
-	{ 8,	0,	printargs,		"SYS_440"	}, /* 440 */
-	{ 8,	0,	printargs,		"SYS_441"	}, /* 441 */
-	{ 8,	0,	printargs,		"SYS_442"	}, /* 442 */
 	{ 8,	0,	printargs,		"SYS_443"	}, /* 443 */
 	{ 8,	0,	printargs,		"SYS_444"	}, /* 444 */
 	{ 8,	0,	printargs,		"SYS_445"	}, /* 445 */
@@ -929,10 +832,10 @@
 	{ 8,	0,	printargs,		"SYS_1023"	}, /* 1023 */
 	{ 0,	0,	printargs,		"ni_syscall"	}, /* 1024 */
 	{ 1,	TP,	sys_exit,		"exit"		}, /* 1025 */
-	{ 3,	TF,	sys_read,		"read"		}, /* 1026 */
-	{ 3,	TF,	sys_write,		"write"		}, /* 1027 */
-	{ 3,	TF,	sys_open,		"open"		}, /* 1028 */
-	{ 1,	0,	sys_close,		"close"		}, /* 1029 */
+	{ 3,	TD,	sys_read,		"read"		}, /* 1026 */
+	{ 3,	TD,	sys_write,		"write"		}, /* 1027 */
+	{ 3,	TD|TF,	sys_open,		"open"		}, /* 1028 */
+	{ 1,	TD,	sys_close,		"close"		}, /* 1029 */
 	{ 2,	0,	sys_creat,		"creat"		}, /* 1030 */
 	{ 2,	TF,	sys_link,		"link"		}, /* 1031 */
 	{ 1,	TF,	sys_unlink,		"unlink"	}, /* 1032 */
@@ -954,26 +857,26 @@
 	{ 4,	0,	sys_ptrace,		"ptrace"	}, /* 1048 */
 	{ 2,	TF,	sys_access,		"access"	}, /* 1049 */
 	{ 0,	0,	sys_sync,		"sync"		}, /* 1050 */
-	{ 1,	0,	sys_fsync,		"fsync"		}, /* 1051 */
-	{ 1,	0,	sys_fdatasync,		"fdatasync"	}, /* 1052 */
+	{ 1,	TD,	sys_fsync,		"fsync"		}, /* 1051 */
+	{ 1,	TD,	sys_fdatasync,		"fdatasync"	}, /* 1052 */
 	{ 2,	TS,	sys_kill,		"kill"		}, /* 1053 */
 	{ 2,	TF,	sys_rename,		"rename"	}, /* 1054 */
 	{ 2,	TF,	sys_mkdir,		"mkdir"		}, /* 1055 */
 	{ 1,	TF,	sys_rmdir,		"rmdir"		}, /* 1056 */
-	{ 1,	0,	sys_dup,		"dup"		}, /* 1057 */
-	{ 1,	0,	sys_pipe,		"pipe"		}, /* 1058 */
+	{ 1,	TD,	sys_dup,		"dup"		}, /* 1057 */
+	{ 1,	TD,	sys_pipe,		"pipe"		}, /* 1058 */
 	{ 1,	0,	sys_times,		"times"		}, /* 1059 */
 	{ 1,	0,	sys_brk,		"brk"		}, /* 1060 */
 	{ 1,	0,	sys_setgid,		"setgid"	}, /* 1061 */
 	{ 0,	0,	sys_getgid,		"getgid"	}, /* 1062 */
 	{ 0,	0,	sys_getegid,		"getegid"	}, /* 1063 */
 	{ 1,	TF,	sys_acct,		"acct"		}, /* 1064 */
-	{ 3,	0,	sys_ioctl,		"ioctl"		}, /* 1065 */
-	{ 3,	0,	sys_fcntl,		"fcntl"		}, /* 1066 */
+	{ 3,	TD,	sys_ioctl,		"ioctl"		}, /* 1065 */
+	{ 3,	TD,	sys_fcntl,		"fcntl"		}, /* 1066 */
 	{ 1,	0,	sys_umask,		"umask"		}, /* 1067 */
 	{ 1,	TF,	sys_chroot,		"chroot"	}, /* 1068 */
 	{ 2,	0,	sys_ustat,		"ustat"		}, /* 1069 */
-	{ 2,	0,	sys_dup2,		"dup2"		}, /* 1070 */
+	{ 2,	TD,	sys_dup2,		"dup2"		}, /* 1070 */
 	{ 2,	0,	sys_setreuid,		"setreuid"	}, /* 1071 */
 	{ 2,	0,	sys_setregid,		"setregid"	}, /* 1072 */
 	{ 3,	0,	printargs,		"getresuid"	}, /* 1073 */
@@ -992,8 +895,8 @@
 	{ 2,	0,	sys_getrusage,		"getrusage"	}, /* 1086 */
 	{ 2,	0,	sys_gettimeofday,	"gettimeofday"	}, /* 1087 */
 	{ 2,	0,	sys_settimeofday,	"settimeofday"	}, /* 1088 */
-	{ 5,	0,	sys_select,		"select"	}, /* 1089 */
-	{ 3,	0,	sys_poll,		"poll"		}, /* 1090 */
+	{ 5,	TD,	sys_select,		"select"	}, /* 1089 */
+	{ 3,	TD,	sys_poll,		"poll"		}, /* 1090 */
 	{ 2,	TF,	sys_symlink,		"symlink"	}, /* 1091 */
 	{ 3,	TF,	sys_readlink,		"readlink"	}, /* 1092 */
 	{ 1,	0,	sys_uselib,		"uselib"	}, /* 1093 */
@@ -1001,14 +904,14 @@
 	{ 1,	0,	sys_swapoff,		"swapoff"	}, /* 1095 */
 	{ 3,	0,	sys_reboot,		"reboot"	}, /* 1096 */
 	{ 2,	TF,	sys_truncate,		"truncate"	}, /* 1097 */
-	{ 2,	0,	sys_ftruncate,		"ftruncate"	}, /* 1098 */
-	{ 2,	0,	sys_fchmod,		"fchmod"	}, /* 1099 */
-	{ 3,	0,	sys_fchown,		"fchown"	}, /* 1100 */
+	{ 2,	TD,	sys_ftruncate,		"ftruncate"	}, /* 1098 */
+	{ 2,	TD,	sys_fchmod,		"fchmod"	}, /* 1099 */
+	{ 3,	TD,	sys_fchown,		"fchown"	}, /* 1100 */
 	{ 2,	0,	sys_getpriority,	"getpriority"	}, /* 1101 */
 	{ 3,	0,	sys_setpriority,	"setpriority"	}, /* 1102 */
 	{ 2,	TF,	sys_statfs,		"statfs"	}, /* 1103 */
-	{ 2,	0,	sys_fstatfs,		"fstatfs"	}, /* 1104 */
-	{ 3,	0,	sys_ioperm,		"ioperm"	}, /* 1105 */
+	{ 2,	TD,	sys_fstatfs,		"fstatfs"	}, /* 1104 */
+	{ 3,	0,	printargs,		"gettid"	}, /* 1105 */
 	{ 3,	TI,	sys_semget,		"semget"	}, /* 1106 */
 	{ 3,	TI,	printargs,		"semop"		}, /* 1107 */
 	{ 4,	TI,	sys_semctl,		"semctl"	}, /* 1108 */
@@ -1025,7 +928,7 @@
 	{ 2,	0,	sys_getitimer,		"getitimer"	}, /* 1119 */
 	{ 2,	TF,	sys_stat,		"stat"		}, /* 1120 */
 	{ 2,	TF,	sys_lstat,		"lstat"		}, /* 1121 */
-	{ 2,	0,	sys_fstat,		"fstat"		}, /* 1122 */
+	{ 2,	TD,	sys_fstat,		"fstat"		}, /* 1122 */
 	{ 0,	0,	sys_vhangup,		"vhangup"	}, /* 1123 */
 	{ 3,	TF,	sys_chown,		"lchown"	}, /* 1124 */
 	{ 5,	0,	printargs,		"vm86"		}, /* 1125 */
@@ -1047,12 +950,12 @@
 	{ 5,	0,	sys_afs_syscall,	"afs_syscall"	}, /* 1141 */
 	{ 1,	0,	sys_setfsuid,		"setfsuid"	}, /* 1142 */
 	{ 1,	0,	sys_setfsgid,		"setfsgid"	}, /* 1143 */
-	{ 3,	0,	sys_getdents,		"getdents"	}, /* 1144 */
-	{ 2,	0,	sys_flock,		"flock"		}, /* 1145 */
-	{ 5,	0,	sys_readv,		"readv"		}, /* 1146 */
-	{ 5,	0,	sys_writev,		"writev"	}, /* 1147 */
-	{ 4,	0,	sys_pread,		"pread"		}, /* 1148 */
-	{ 4,	0,	sys_pwrite,		"pwrite"	}, /* 1149 */
+	{ 3,	TD,	sys_getdents,		"getdents"	}, /* 1144 */
+	{ 2,	TD,	sys_flock,		"flock"		}, /* 1145 */
+	{ 5,	TD,	sys_readv,		"readv"		}, /* 1146 */
+	{ 5,	TD,	sys_writev,		"writev"	}, /* 1147 */
+	{ 4,	TD,	sys_pread,		"pread"		}, /* 1148 */
+	{ 4,	TD,	sys_pwrite,		"pwrite"	}, /* 1149 */
 	{ 1,	0,	printargs,		"_sysctl"	}, /* 1150 */
 	{ 6,	0,	sys_mmap,		"mmap"		}, /* 1151 */
 	{ 2,	0,	sys_munmap,		"munmap"	}, /* 1152 */
@@ -1090,7 +993,7 @@
 	{ 2,	TF,	sys_getcwd,		"getcwd"	}, /* 1184 */
 	{ 2,	0,	sys_capget,		"capget"	}, /* 1185 */
 	{ 2,	0,	sys_capset,		"capset"	}, /* 1186 */
-	{ 4,	TF,	sys_sendfile,		"sendfile"	}, /* 1187 */
+	{ 4,	TD,	sys_sendfile,		"sendfile"	}, /* 1187 */
 	{ 5,	TN,	printargs,		"getpmsg"	}, /* 1188 */
 	{ 5,	TN,	printargs,		"putpmsg"	}, /* 1189 */
 	{ 3,	TN,	sys_socket,		"socket"	}, /* 1190 */
@@ -1115,14 +1018,14 @@
 	{ 3,	0,	sys_madvise,		"madvise"	}, /* 1209 */
 	{ 2,	TF,	sys_stat,		"stat"		}, /* 1210 */
 	{ 2,	0,	sys_lstat,		"lstat"		}, /* 1211 */
-	{ 2,	TF,	sys_fstat,		"fstat"		}, /* 1212 */
+	{ 2,	TD,	sys_fstat,		"fstat"		}, /* 1212 */
 	{ 6,	TP,	sys_clone,		"clone2"	}, /* 1213 */
 	{ 3,	0,	printargs,		"getdents64"	}, /* 1214 */
 	{ 2,	0,	printargs,		"getunwind"	}, /* 1215 */
-	{ 4,	0,	sys_readahead,		"readahead"	}, /* 1216 */
+	{ 4,	TD,	sys_readahead,		"readahead"	}, /* 1216 */
 	{ 5,	TF,	sys_setxattr,		"setxattr"	}, /* 1217 */
 	{ 5,	TF,	sys_setxattr,		"lsetxattr"	}, /* 1218 */
-	{ 5,	0,	sys_setxattr,		"fsetxattr"	}, /* 1219 */
+	{ 5,	TD,	sys_setxattr,		"fsetxattr"	}, /* 1219 */
 	{ 4,	TF,	sys_getxattr,		"getxattr"	}, /* 1220 */
 	{ 4,	TF,	sys_getxattr,		"lgetxattr"	}, /* 1221 */
 	{ 4,	0,	sys_getxattr,		"fgetxattr"	}, /* 1222 */
@@ -1137,75 +1040,75 @@
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity"},/* 1231 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity"},/* 1232 */
 	{ 1,	0,	printargs,		"set_tid_address"}, /* 1233 */
-	{ 8,	0,	printargs,		"SYS_1234"	}, /* 1234 */
+	{ 5,	0,	sys_fadvise64,		"fadvise64"	}, /* 1234 */
 	{ 3,	TS,	sys_tgkill,		"tgkill"	}, /* 1235 */
 	{ 1,	TP,	sys_exit,		"exit_group"	}, /* 1236 */
 	{ 4,	0,	printargs,		"lookup_dcookie"}, /* 1237 */
-	{ 2,	0,	printargs,		"io_setup"	}, /* 1238 */
-	{ 1,	0,	printargs,		"io_destroy"	}, /* 1239 */
-	{ 5,	0,	printargs,		"io_getevents"	}, /* 1240 */
-	{ 3,	0,	printargs,		"io_submit"	}, /* 1241 */
-	{ 3,	0,	printargs,		"io_cancel"	}, /* 1242 */
-	{ 1,	0,	printargs,		"epoll_create"	}, /* 1243 */
-	{ 4,	0,	printargs,		"epoll_ctl"	}, /* 1244 */
-	{ 4,	0,	printargs,		"epoll_wait"	}, /* 1245 */
-	{ 8,	0,	printargs,		"SYS_1246"	}, /* 1246 */
-	{ 8,	0,	printargs,		"SYS_1247"	}, /* 1247 */
-	{ 8,	0,	printargs,		"SYS_1248"	}, /* 1248 */
-	{ 8,	0,	printargs,		"SYS_1249"	}, /* 1249 */
-	{ 8,	0,	printargs,		"SYS_1250"	}, /* 1250 */
-	{ 8,	0,	printargs,		"SYS_1251"	}, /* 1251 */
-	{ 8,	0,	printargs,		"SYS_1252"	}, /* 1252 */
-	{ 8,	0,	printargs,		"SYS_1253"	}, /* 1253 */
-	{ 8,	0,	printargs,		"SYS_1254"	}, /* 1254 */
-	{ 8,	0,	printargs,		"SYS_1255"	}, /* 1255 */
-	{ 8,	0,	printargs,		"SYS_1256"	}, /* 1256 */
-	{ 8,	0,	printargs,		"SYS_1257"	}, /* 1257 */
-	{ 8,	0,	printargs,		"SYS_1258"	}, /* 1258 */
-	{ 8,	0,	printargs,		"SYS_1259"	}, /* 1259 */
-	{ 8,	0,	printargs,		"SYS_1260"	}, /* 1260 */
-	{ 8,	0,	printargs,		"SYS_1261"	}, /* 1261 */
-	{ 8,	0,	printargs,		"SYS_1262"	}, /* 1262 */
-	{ 8,	0,	printargs,		"SYS_1263"	}, /* 1263 */
-	{ 8,	0,	printargs,		"SYS_1264"	}, /* 1264 */
-	{ 8,	0,	printargs,		"SYS_1265"	}, /* 1265 */
-	{ 8,	0,	printargs,		"SYS_1266"	}, /* 1266 */
-	{ 8,	0,	printargs,		"SYS_1267"	}, /* 1267 */
-	{ 8,	0,	printargs,		"SYS_1268"	}, /* 1268 */
-	{ 8,	0,	printargs,		"SYS_1269"	}, /* 1269 */
-	{ 8,	0,	printargs,		"SYS_1270"	}, /* 1270 */
-	{ 8,	0,	printargs,		"SYS_1271"	}, /* 1271 */
-	{ 8,	0,	printargs,		"SYS_1272"	}, /* 1272 */
-	{ 8,	0,	printargs,		"SYS_1273"	}, /* 1273 */
-	{ 8,	0,	printargs,		"SYS_1274"	}, /* 1274 */
-	{ 8,	0,	printargs,		"SYS_1275"	}, /* 1275 */
+	{ 2,	0,	sys_io_setup,		"io_setup"	}, /* 1238 */
+	{ 1,	0,	sys_io_destroy,		"io_destroy"	}, /* 1239 */
+	{ 5,	0,	sys_io_getevents,		"io_getevents"	}, /* 1240 */
+	{ 3,	0,	sys_io_submit,		"io_submit"	}, /* 1241 */
+	{ 3,	0,	sys_io_cancel,		"io_cancel"	}, /* 1242 */
+	{ 1,	0,	sys_epoll_create,	"epoll_create"	}, /* 1243 */
+	{ 4,	TD,	sys_epoll_ctl,		"epoll_ctl"	}, /* 1244 */
+	{ 4,	TD,	sys_epoll_wait,		"epoll_wait"	}, /* 1245 */
+	{ 0,	0,	sys_restart_syscall,	"restart_syscall"}, /* 1246 */
+	{ 5,	TI,	sys_semtimedop,		"semtimedop"	}, /* 1247 */
+	{ 3,	0,	sys_timer_create,	"timer_create"	}, /* 1248 */
+	{ 4,	0,	sys_timer_settime,	"timer_settime"	}, /* 1249 */
+	{ 2,	0,	sys_timer_gettime,	"timer_gettime"	}, /* 1250 */
+	{ 1,	0,	sys_timer_getoverrun,	"timer_getoverrun"}, /* 1251 */
+	{ 1,	0,	sys_timer_delete,	"timer_delete"	}, /* 1252 */
+	{ 2,	0,	sys_clock_settime,	"clock_settime"	}, /* 1253 */
+	{ 2,	0,	sys_clock_gettime,	"clock_gettime"	}, /* 1254 */
+	{ 2,	0,	sys_clock_getres,	"clock_getres"	}, /* 1255 */
+	{ 4,	0,	sys_clock_nanosleep,	"clock_nanosleep"}, /* 1256 */
+	{ 8,	0,	printargs,		"fstatfs64"	}, /* 1257 */
+	{ 8,	0,	printargs,		"statfs64"	}, /* 1258 */
+	{ 6,	0,	sys_mbind,		"mbind"		}, /* 1259 */
+	{ 5,	0,	sys_get_mempolicy,	"get_mempolicy"	}, /* 1260 */
+	{ 3,	0,	sys_set_mempolicy,	"set_mempolicy"	}, /* 1261 */
+	{ 4,	0,	sys_mq_open,		"mq_open"	}, /* 1262 */
+	{ 1,	0,	sys_mq_unlink,		"mq_unlink"	}, /* 1263 */
+	{ 5,	0,	sys_mq_timedsend,	"mq_timedsend"	}, /* 1264 */
+	{ 5,	0,	sys_mq_timedreceive,	"mq_timedreceive" }, /* 1265 */
+	{ 2,	0,	sys_mq_notify,		"mq_notify"	}, /* 1266 */
+	{ 3,	0,	sys_mq_getsetattr,	"mq_getsetattr"	}, /* 1267 */
+	{ 5,	0,	printargs,		"sys_kexec_load" }, /* 1268 */
+	{ 5,	0,	printargs,		"vserver"	}, /* 1269 */
+	{ 5,	TP,	sys_waitid,		"waitid"	}, /* 1270 */
+	{ 5,	0,	printargs,		"add_key"	}, /* 1271 */
+	{ 4,	0,	printargs,		"request_key"	}, /* 1272 */
+	{ 5,	0,	printargs,		"keyctl"	}, /* 1273 */
+	{ 3,	0,	printargs,		"ioprio_set"	}, /* 1274 */
+	{ 2,	0,	printargs,		"ioprio_get"	}, /* 1275 */
 	{ 8,	0,	printargs,		"SYS_1276"	}, /* 1276 */
-	{ 8,	0,	printargs,		"SYS_1277"	}, /* 1277 */
-	{ 8,	0,	printargs,		"SYS_1278"	}, /* 1278 */
-	{ 8,	0,	printargs,		"SYS_1279"	}, /* 1279 */
-	{ 8,	0,	printargs,		"SYS_1280"	}, /* 1280 */
-	{ 8,	0,	printargs,		"SYS_1281"	}, /* 1281 */
-	{ 8,	0,	printargs,		"SYS_1282"	}, /* 1282 */
-	{ 8,	0,	printargs,		"SYS_1283"	}, /* 1283 */
-	{ 8,	0,	printargs,		"SYS_1284"	}, /* 1284 */
-	{ 8,	0,	printargs,		"SYS_1285"	}, /* 1285 */
-	{ 8,	0,	printargs,		"SYS_1286"	}, /* 1286 */
-	{ 8,	0,	printargs,		"SYS_1287"	}, /* 1287 */
-	{ 8,	0,	printargs,		"SYS_1288"	}, /* 1288 */
-	{ 8,	0,	printargs,		"SYS_1289"	}, /* 1289 */
-	{ 8,	0,	printargs,		"SYS_1290"	}, /* 1290 */
-	{ 8,	0,	printargs,		"SYS_1291"	}, /* 1291 */
-	{ 8,	0,	printargs,		"SYS_1292"	}, /* 1292 */
-	{ 8,	0,	printargs,		"SYS_1293"	}, /* 1293 */
-	{ 8,	0,	printargs,		"SYS_1294"	}, /* 1294 */
-	{ 8,	0,	printargs,		"SYS_1295"	}, /* 1295 */
-	{ 8,	0,	printargs,		"SYS_1296"	}, /* 1296 */
-	{ 8,	0,	printargs,		"SYS_1297"	}, /* 1297 */
-	{ 8,	0,	printargs,		"SYS_1298"	}, /* 1298 */
-	{ 8,	0,	printargs,		"SYS_1299"	}, /* 1299 */
-	{ 8,	0,	printargs,		"SYS_1300"	}, /* 1300 */
-	{ 8,	0,	printargs,		"SYS_1301"	}, /* 1301 */
-	{ 8,	0,	printargs,		"SYS_1302"	}, /* 1302 */
+	{ 0,	TD,	printargs,		"inotify_init"	}, /* 1277 */
+	{ 3,	TD,	sys_inotify_add_watch,	"inotify_add_watch" }, /* 1278 */
+	{ 2,	TD,	sys_inotify_rm_watch,	"inotify_rm_watch" }, /* 1279 */
+	{ 4,	0,	printargs,		"migrate_pages"	}, /* 1280 */
+	{ 4,	TD|TF,	sys_openat,		"openat"	}, /* 1281 */
+	{ 3,	TD|TF,	sys_mkdirat,		"mkdirat"	}, /* 1282 */
+	{ 4,	TD|TF,	sys_mknodat,		"mknodat"	}, /* 1283 */
+	{ 5,	TD|TF,	sys_fchownat,		"fchownat"	}, /* 1284 */
+	{ 3,	TD|TF,	sys_futimesat,		"futimesat"	}, /* 1285 */
+	{ 4,	TD|TD,	sys_newfstatat,		"newfstatat"	}, /* 1286 */
+	{ 3,	TD|TF,	sys_unlinkat,		"unlinkat"	}, /* 1287 */
+	{ 4,	TD|TF,	sys_renameat,		"renameat"	}, /* 1288 */
+	{ 5,	TD|TF,	sys_linkat,		"linkat"	}, /* 1289 */
+	{ 3,	TD|TF,	sys_symlinkat,		"symlinkat"	}, /* 1290 */
+	{ 4,	TD|TF,	sys_readlinkat,		"readlinkat"	}, /* 1291 */
+	{ 3,	TD|TF,	sys_fchmodat,		"fchmodat"	}, /* 1292 */
+	{ 3,	TD|TF,	sys_faccessat,		"faccessat"	}, /* 1293 */
+	{ 6,	TD,	sys_pselect6,		"pselect6"	}, /* 1294 */
+	{ 5,	TD,	sys_ppoll,		"ppoll"		}, /* 1295 */
+	{ 1,	TP,	sys_unshare,		"unshare"	}, /* 1296 */
+	{ 2,	0,	printargs,		"set_robust_list" }, /* 1297 */
+	{ 3,	0,	printargs,		"get_robust_list" }, /* 1298 */
+	{ 6,	TD,	printargs,		"splice"	}, /* 1299 */
+	{ 4,	TD,	printargs,		"sync_file_range" }, /* 1300 */
+	{ 4,	TD,	printargs,		"tee"		}, /* 1301 */
+	{ 4,	TD,	printargs,		"vmsplice"	}, /* 1302 */
 	{ 8,	0,	printargs,		"SYS_1303"	}, /* 1303 */
 	{ 8,	0,	printargs,		"SYS_1304"	}, /* 1304 */
 	{ 8,	0,	printargs,		"SYS_1305"	}, /* 1305 */
