@@ -311,71 +311,171 @@
 	{ 5,	TP,	sys_waitid,		"waitid"	}, /* 281 */
 	{ 3,	0,	printargs,		"ioprio_set"	}, /* 282 */
 	{ 2,	0,	printargs,		"ioprio_get"	}, /* 283 */
-	{ 0,	0,	printargs,		"inotify_init"	}, /* 284 */
-	{ 3,	0,	printargs,		"inotify_add_watch" }, /* 285 */
-	{ 2,	0,	printargs,		"inotify_rm_watch" }, /* 286 */
+	{ 0,	TD,	printargs,		"inotify_init"	}, /* 284 */
+	{ 3,	TD,	sys_inotify_add_watch,	"inotify_add_watch" }, /* 285 */
+	{ 2,	TD,	sys_inotify_rm_watch,	"inotify_rm_watch" }, /* 286 */
+	{ 4,	0,	printargs,		"migrate_pages"	}, /* 287 */
+	{ 4,	TD|TF,	sys_openat,		"openat"	}, /* 288 */
+	{ 3,	TD|TF,	sys_mkdirat,		"mkdirat"	}, /* 289 */
+	{ 4,	TD|TF,	sys_mknodat,		"mknodat"	}, /* 290 */
+	{ 5,	TD|TF,	sys_fchownat,		"fchownat"	}, /* 291 */
+	{ 3,	TD|TF,	sys_futimesat,		"futimesat"	}, /* 292 */
+	{ 4,	TD|TD,	sys_newfstatat,		"newfstatat"	}, /* 293 */
+	{ 3,	TD|TF,	sys_unlinkat,		"unlinkat"	}, /* 294 */
+	{ 4,	TD|TF,	sys_renameat,		"renameat"	}, /* 295 */
+	{ 5,	TD|TF,	sys_linkat,		"linkat"	}, /* 296 */
+	{ 3,	TD|TF,	sys_symlinkat,		"symlinkat"	}, /* 297 */
+	{ 4,	TD|TF,	sys_readlinkat,		"readlinkat"	}, /* 298 */
+	{ 3,	TD|TF,	sys_fchmodat,		"fchmodat"	}, /* 299 */
+	{ 3,	TD|TF,	sys_faccessat,		"faccessat"	}, /* 300 */
+	{ 6,	TD,	sys_pselect6,		"pselect6"	}, /* 301 */
+	{ 5,	TD,	sys_ppoll,		"ppoll"		}, /* 302 */
+	{ 1,	TP,	sys_unshare,		"unshare"	}, /* 303 */
+	{ 2,	0,	printargs,		"set_robust_list" }, /* 304 */
+	{ 3,	0,	printargs,		"get_robust_list" }, /* 305 */
+	{ 6,	TD,	printargs,		"splice"	}, /* 306 */
+	{ 4,	TD,	printargs,		"sync_file_range" }, /* 307 */
+	{ 4,	TD,	printargs,		"tee"		}, /* 308 */
+	{ 4,	TD,	printargs,		"vmsplice"	}, /* 309 */
 
-	{ 5,	0,	printargs,		"SYS_287"	}, /* 287 */
-	{ 5,	0,	printargs,		"SYS_288"	}, /* 288 */
-	{ 5,	0,	printargs,		"SYS_289"	}, /* 289 */
-	{ 5,	0,	printargs,		"SYS_290"	}, /* 290 */
-	{ 5,	0,	printargs,		"SYS_291"	}, /* 291 */
-	{ 5,	0,	printargs,		"SYS_292"	}, /* 292 */
-	{ 5,	0,	printargs,		"SYS_293"	}, /* 293 */
-	{ 5,	0,	printargs,		"SYS_294"	}, /* 294 */
-	{ 5,	0,	printargs,		"SYS_295"	}, /* 295 */
-	{ 5,	0,	printargs,		"SYS_296"	}, /* 296 */
-	{ 5,	0,	printargs,		"SYS_297"	}, /* 297 */
-	{ 5,	0,	printargs,		"SYS_298"	}, /* 298 */
-	{ 5,	0,	printargs,		"SYS_299"	}, /* 299 */
+	{ 5,	0,	printargs,		"SYS_310"	}, /* 310 */
+	{ 5,	0,	printargs,		"SYS_311"	}, /* 311 */
+	{ 5,	0,	printargs,		"SYS_312"	}, /* 312 */
+	{ 5,	0,	printargs,		"SYS_313"	}, /* 313 */
+	{ 5,	0,	printargs,		"SYS_314"	}, /* 314 */
+	{ 5,	0,	printargs,		"SYS_315"	}, /* 315 */
+	{ 5,	0,	printargs,		"SYS_316"	}, /* 316 */
+	{ 5,	0,	printargs,		"SYS_317"	}, /* 317 */
+	{ 5,	0,	printargs,		"SYS_318"	}, /* 318 */
+	{ 5,	0,	printargs,		"SYS_319"	}, /* 319 */
+	{ 5,	0,	printargs,		"SYS_320"	}, /* 320 */
+	{ 5,	0,	printargs,		"SYS_321"	}, /* 321 */
+	{ 5,	0,	printargs,		"SYS_322"	}, /* 322 */
+	{ 5,	0,	printargs,		"SYS_323"	}, /* 323 */
+	{ 5,	0,	printargs,		"SYS_324"	}, /* 324 */
+	{ 5,	0,	printargs,		"SYS_325"	}, /* 325 */
+	{ 5,	0,	printargs,		"SYS_326"	}, /* 326 */
+	{ 5,	0,	printargs,		"SYS_327"	}, /* 327 */
+	{ 5,	0,	printargs,		"SYS_328"	}, /* 328 */
+	{ 5,	0,	printargs,		"SYS_329"	}, /* 329 */
+	{ 5,	0,	printargs,		"SYS_330"	}, /* 330 */
+	{ 5,	0,	printargs,		"SYS_331"	}, /* 331 */
+	{ 5,	0,	printargs,		"SYS_332"	}, /* 332 */
+	{ 5,	0,	printargs,		"SYS_333"	}, /* 333 */
+	{ 5,	0,	printargs,		"SYS_334"	}, /* 334 */
+	{ 5,	0,	printargs,		"SYS_335"	}, /* 335 */
+	{ 5,	0,	printargs,		"SYS_336"	}, /* 336 */
+	{ 5,	0,	printargs,		"SYS_337"	}, /* 337 */
+	{ 5,	0,	printargs,		"SYS_338"	}, /* 338 */
+	{ 5,	0,	printargs,		"SYS_339"	}, /* 339 */
+	{ 5,	0,	printargs,		"SYS_340"	}, /* 340 */
+	{ 5,	0,	printargs,		"SYS_341"	}, /* 341 */
+	{ 5,	0,	printargs,		"SYS_342"	}, /* 342 */
+	{ 5,	0,	printargs,		"SYS_343"	}, /* 343 */
+	{ 5,	0,	printargs,		"SYS_344"	}, /* 344 */
+	{ 5,	0,	printargs,		"SYS_345"	}, /* 345 */
+	{ 5,	0,	printargs,		"SYS_346"	}, /* 346 */
+	{ 5,	0,	printargs,		"SYS_347"	}, /* 347 */
+	{ 5,	0,	printargs,		"SYS_348"	}, /* 348 */
+	{ 5,	0,	printargs,		"SYS_349"	}, /* 349 */
+	{ 5,	0,	printargs,		"SYS_350"	}, /* 350 */
+	{ 5,	0,	printargs,		"SYS_351"	}, /* 351 */
+	{ 5,	0,	printargs,		"SYS_352"	}, /* 352 */
+	{ 5,	0,	printargs,		"SYS_353"	}, /* 353 */
+	{ 5,	0,	printargs,		"SYS_354"	}, /* 354 */
+	{ 5,	0,	printargs,		"SYS_355"	}, /* 355 */
+	{ 5,	0,	printargs,		"SYS_356"	}, /* 356 */
+	{ 5,	0,	printargs,		"SYS_357"	}, /* 357 */
+	{ 5,	0,	printargs,		"SYS_358"	}, /* 358 */
+	{ 5,	0,	printargs,		"SYS_359"	}, /* 359 */
+	{ 5,	0,	printargs,		"SYS_360"	}, /* 360 */
+	{ 5,	0,	printargs,		"SYS_361"	}, /* 361 */
+	{ 5,	0,	printargs,		"SYS_362"	}, /* 362 */
+	{ 5,	0,	printargs,		"SYS_363"	}, /* 363 */
+	{ 5,	0,	printargs,		"SYS_364"	}, /* 364 */
+	{ 5,	0,	printargs,		"SYS_365"	}, /* 365 */
+	{ 5,	0,	printargs,		"SYS_366"	}, /* 366 */
+	{ 5,	0,	printargs,		"SYS_367"	}, /* 367 */
+	{ 5,	0,	printargs,		"SYS_368"	}, /* 368 */
+	{ 5,	0,	printargs,		"SYS_369"	}, /* 369 */
+	{ 5,	0,	printargs,		"SYS_370"	}, /* 370 */
+	{ 5,	0,	printargs,		"SYS_371"	}, /* 371 */
+	{ 5,	0,	printargs,		"SYS_372"	}, /* 372 */
+	{ 5,	0,	printargs,		"SYS_373"	}, /* 373 */
+	{ 5,	0,	printargs,		"SYS_374"	}, /* 374 */
+	{ 5,	0,	printargs,		"SYS_375"	}, /* 375 */
+	{ 5,	0,	printargs,		"SYS_376"	}, /* 376 */
+	{ 5,	0,	printargs,		"SYS_377"	}, /* 377 */
+	{ 5,	0,	printargs,		"SYS_378"	}, /* 378 */
+	{ 5,	0,	printargs,		"SYS_379"	}, /* 379 */
+	{ 5,	0,	printargs,		"SYS_380"	}, /* 380 */
+	{ 5,	0,	printargs,		"SYS_381"	}, /* 381 */
+	{ 5,	0,	printargs,		"SYS_382"	}, /* 382 */
+	{ 5,	0,	printargs,		"SYS_383"	}, /* 383 */
+	{ 5,	0,	printargs,		"SYS_384"	}, /* 384 */
+	{ 5,	0,	printargs,		"SYS_385"	}, /* 385 */
+	{ 5,	0,	printargs,		"SYS_386"	}, /* 386 */
+	{ 5,	0,	printargs,		"SYS_387"	}, /* 387 */
+	{ 5,	0,	printargs,		"SYS_388"	}, /* 388 */
+	{ 5,	0,	printargs,		"SYS_389"	}, /* 389 */
+	{ 5,	0,	printargs,		"SYS_390"	}, /* 390 */
+	{ 5,	0,	printargs,		"SYS_391"	}, /* 391 */
+	{ 5,	0,	printargs,		"SYS_392"	}, /* 392 */
+	{ 5,	0,	printargs,		"SYS_393"	}, /* 393 */
+	{ 5,	0,	printargs,		"SYS_394"	}, /* 394 */
+	{ 5,	0,	printargs,		"SYS_395"	}, /* 395 */
+	{ 5,	0,	printargs,		"SYS_396"	}, /* 396 */
+	{ 5,	0,	printargs,		"SYS_397"	}, /* 397 */
+	{ 5,	0,	printargs,		"SYS_398"	}, /* 398 */
+	{ 5,	0,	printargs,		"SYS_399"	}, /* 399 */
 
-#if SYS_socket_subcall != 300
+#if SYS_socket_subcall != 400
  #error fix me
 #endif
-	{ 8,	0,	printargs,		"socket_subcall"}, /* 300 */
-	{ 3,	TN,	sys_socket,		"socket"	}, /* 301 */
-	{ 3,	TN,	sys_bind,		"bind"		}, /* 302 */
-	{ 3,	TN,	sys_connect,		"connect"	}, /* 303 */
-	{ 2,	TN,	sys_listen,		"listen"	}, /* 304 */
-	{ 3,	TN,	sys_accept,		"accept"	}, /* 305 */
-	{ 3,	TN,	sys_getsockname,	"getsockname"	}, /* 306 */
-	{ 3,	TN,	sys_getpeername,	"getpeername"	}, /* 307 */
-	{ 4,	TN,	sys_socketpair,		"socketpair"	}, /* 308 */
-	{ 4,	TN,	sys_send,		"send"		}, /* 309 */
-	{ 4,	TN,	sys_recv,		"recv"		}, /* 310 */
-	{ 6,	TN,	sys_sendto,		"sendto"	}, /* 311 */
-	{ 6,	TN,	sys_recvfrom,		"recvfrom"	}, /* 312 */
-	{ 2,	TN,	sys_shutdown,		"shutdown"	}, /* 313 */
-	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 314 */
-	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 315 */
-	{ 5,	TN,	sys_sendmsg,		"sendmsg"	}, /* 316 */
-	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 317 */
+	{ 8,	0,	printargs,		"socket_subcall"}, /* 400 */
+	{ 3,	TN,	sys_socket,		"socket"	}, /* 401 */
+	{ 3,	TN,	sys_bind,		"bind"		}, /* 402 */
+	{ 3,	TN,	sys_connect,		"connect"	}, /* 403 */
+	{ 2,	TN,	sys_listen,		"listen"	}, /* 404 */
+	{ 3,	TN,	sys_accept,		"accept"	}, /* 405 */
+	{ 3,	TN,	sys_getsockname,	"getsockname"	}, /* 406 */
+	{ 3,	TN,	sys_getpeername,	"getpeername"	}, /* 407 */
+	{ 4,	TN,	sys_socketpair,		"socketpair"	}, /* 408 */
+	{ 4,	TN,	sys_send,		"send"		}, /* 409 */
+	{ 4,	TN,	sys_recv,		"recv"		}, /* 410 */
+	{ 6,	TN,	sys_sendto,		"sendto"	}, /* 411 */
+	{ 6,	TN,	sys_recvfrom,		"recvfrom"	}, /* 412 */
+	{ 2,	TN,	sys_shutdown,		"shutdown"	}, /* 413 */
+	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 414 */
+	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 415 */
+	{ 5,	TN,	sys_sendmsg,		"sendmsg"	}, /* 416 */
+	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 417 */
 
-#if SYS_ipc_subcall != 318
+#if SYS_ipc_subcall != 418
  #error fix me
 #endif
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 318 */
-	{ 4,	TI,	sys_semop,		"semop"		}, /* 319 */
-	{ 4,	TI,	sys_semget,		"semget"	}, /* 320 */
-	{ 4,	TI,	sys_semctl,		"semctl"	}, /* 321 */
-	{ 5,	TI,	sys_semtimedop,		"semtimedop"	}, /* 322 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 323 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 324 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 325 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 326 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 327 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 328 */
-	{ 4,	TI,	sys_msgsnd,		"msgsnd"	}, /* 329 */
-	{ 4,	TI,	sys_msgrcv,		"msgrcv"	}, /* 330 */
-	{ 4,	TI,	sys_msgget,		"msgget"	}, /* 331 */
-	{ 4,	TI,	sys_msgctl,		"msgctl"	}, /* 332 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 333 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 334 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 335 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 336 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 337 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 338 */
-	{ 4,	TI,	sys_shmat,		"shmat"		}, /* 339 */
-	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 340 */
-	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 341 */
-	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 342 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 418 */
+	{ 4,	TI,	sys_semop,		"semop"		}, /* 419 */
+	{ 4,	TI,	sys_semget,		"semget"	}, /* 420 */
+	{ 4,	TI,	sys_semctl,		"semctl"	}, /* 421 */
+	{ 5,	TI,	sys_semtimedop,		"semtimedop"	}, /* 422 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 423 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 424 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 425 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 426 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 427 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 428 */
+	{ 4,	TI,	sys_msgsnd,		"msgsnd"	}, /* 429 */
+	{ 4,	TI,	sys_msgrcv,		"msgrcv"	}, /* 430 */
+	{ 4,	TI,	sys_msgget,		"msgget"	}, /* 431 */
+	{ 4,	TI,	sys_msgctl,		"msgctl"	}, /* 432 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 433 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 434 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 435 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 436 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 437 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 438 */
+	{ 4,	TI,	sys_shmat,		"shmat"		}, /* 439 */
+	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 440 */
+	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 441 */
+	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 442 */
