@@ -27,18 +27,18 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.4 2003/11/13 22:32:28 roland Exp $
+ *	$Id: syscallent.h,v 1.9 2006/08/22 06:17:33 roland Exp $
  */
 
-	{ 0,	0,	sys_setup,		"setup"		}, /* 0 */
+	{ 0,	0,	sys_restart_syscall,	"restart_syscall"}, /* 0 */
 	{ 1,	TP,	sys_exit,		"_exit"		}, /* 1 */
 	{ 0,	TP,	sys_fork,		"fork"		}, /* 2 */
-	{ 3,	0,	sys_read,		"read"		}, /* 3 */
-	{ 3,	0,	sys_write,		"write"		}, /* 4 */
-	{ 3,	TF,	sys_open,		"open"		}, /* 5 */
-	{ 1,	0,	sys_close,		"close"		}, /* 6 */
+	{ 3,	TD,	sys_read,		"read"		}, /* 3 */
+	{ 3,	TD,	sys_write,		"write"		}, /* 4 */
+	{ 3,	TD|TF,	sys_open,		"open"		}, /* 5 */
+	{ 1,	TD,	sys_close,		"close"		}, /* 6 */
 	{ 3,	TP,	sys_waitpid,		"waitpid"	}, /* 7 */
-	{ 2,	TF,	sys_creat,		"creat"		}, /* 8 */
+	{ 2,	TD|TF,	sys_creat,		"creat"		}, /* 8 */
 	{ 2,	TF,	sys_link,		"link"		}, /* 9 */
 	{ 1,	TF,	sys_unlink,		"unlink"	}, /* 10 */
 	{ 3,	TF|TP,	sys_execve,		"execve"	}, /* 11 */
@@ -49,7 +49,7 @@
 	{ 3,	TF,	sys_chown,		"lchown"		}, /* 16 */
 	{ 0,	0,	sys_break,		"break"		}, /* 17 */
 	{ 2,	TF,	sys_oldstat,		"oldstat"	}, /* 18 */
-	{ 3,	0,	sys_lseek,		"lseek"		}, /* 19 */
+	{ 3,	TD,	sys_lseek,		"lseek"		}, /* 19 */
 	{ 0,	0,	sys_getpid,		"getpid"	}, /* 20 */
 	{ 5,	TF,	sys_mount,		"mount"		}, /* 21 */
 	{ 1,	TF,	sys_umount,		"oldumount"	}, /* 22 */
@@ -58,7 +58,7 @@
 	{ 1,	0,	sys_stime,		"stime"		}, /* 25 */
 	{ 4,	0,	sys_ptrace,		"ptrace"	}, /* 26 */
 	{ 1,	0,	sys_alarm,		"alarm"		}, /* 27 */
-	{ 2,	0,	sys_oldfstat,		"oldfstat"	}, /* 28 */
+	{ 2,	TD,	sys_oldfstat,		"oldfstat"	}, /* 28 */
 	{ 0,	TS,	sys_pause,		"pause"		}, /* 29 */
 	{ 2,	TF,	sys_utime,		"utime"		}, /* 30 */
 	{ 2,	0,	sys_stty,		"stty"		}, /* 31 */
@@ -71,8 +71,8 @@
 	{ 2,	TF,	sys_rename,		"rename"	}, /* 38 */
 	{ 2,	TF,	sys_mkdir,		"mkdir"		}, /* 39 */
 	{ 1,	TF,	sys_rmdir,		"rmdir"		}, /* 40 */
-	{ 1,	0,	sys_dup,		"dup"		}, /* 41 */
-	{ 1,	0,	sys_pipe,		"pipe"		}, /* 42 */
+	{ 1,	TD,	sys_dup,		"dup"		}, /* 41 */
+	{ 1,	TD,	sys_pipe,		"pipe"		}, /* 42 */
 	{ 1,	0,	sys_times,		"times"		}, /* 43 */
 	{ 0,	0,	sys_prof,		"prof"		}, /* 44 */
 	{ 1,	0,	sys_brk,		"brk"		}, /* 45 */
@@ -84,8 +84,8 @@
 	{ 1,	TF,	sys_acct,		"acct"		}, /* 51 */
 	{ 2,	TF,	sys_umount2,		"umount"	}, /* 52 */
 	{ 0,	0,	sys_lock,		"lock"		}, /* 53 */
-	{ 3,	0,	sys_ioctl,		"ioctl"		}, /* 54 */
-	{ 3,	0,	sys_fcntl,		"fcntl"		}, /* 55 */
+	{ 3,	TD,	sys_ioctl,		"ioctl"		}, /* 54 */
+	{ 3,	TD,	sys_fcntl,		"fcntl"		}, /* 55 */
 	{ 0,	0,	sys_mpx,		"mpx"		}, /* 56 */
 	{ 2,	0,	sys_setpgid,		"setpgid"	}, /* 57 */
 	{ 2,	0,	sys_ulimit,		"ulimit"	}, /* 58 */
@@ -93,7 +93,7 @@
 	{ 1,	0,	sys_umask,		"umask"		}, /* 60 */
 	{ 1,	TF,	sys_chroot,		"chroot"	}, /* 61 */
 	{ 2,	0,	sys_ustat,		"ustat"		}, /* 62 */
-	{ 2,	0,	sys_dup2,		"dup2"		}, /* 63 */
+	{ 2,	TD,	sys_dup2,		"dup2"		}, /* 63 */
 	{ 0,	0,	sys_getppid,		"getppid"	}, /* 64 */
 	{ 0,	0,	sys_getpgrp,		"getpgrp"	}, /* 65 */
 	{ 0,	0,	sys_setsid,		"setsid"	}, /* 66 */
@@ -112,33 +112,33 @@
 	{ 2,	0,	sys_settimeofday,	"settimeofday"	}, /* 79 */
 	{ 2,	0,	sys_getgroups,		"getgroups"	}, /* 80 */
 	{ 2,	0,	sys_setgroups,		"setgroups"	}, /* 81 */
-	{ 1,	0,	sys_oldselect,		"oldselect"	}, /* 82 */
+	{ 1,	TD,	sys_oldselect,		"oldselect"	}, /* 82 */
 	{ 2,	TF,	sys_symlink,		"symlink"	}, /* 83 */
 	{ 2,	TF,	sys_oldlstat,		"oldlstat"	}, /* 84 */
 	{ 3,	TF,	sys_readlink,		"readlink"	}, /* 85 */
 	{ 1,	TF,	sys_uselib,		"uselib"	}, /* 86 */
 	{ 1,	TF,	sys_swapon,		"swapon"	}, /* 87 */
 	{ 3,	0,	sys_reboot,		"reboot"	}, /* 88 */
-	{ 3,	0,	sys_readdir,		"readdir"	}, /* 89 */
-	{ 6,	0,	sys_old_mmap,		"old_mmap"   	}, /* 90 */
+	{ 3,	TD,	sys_readdir,		"readdir"	}, /* 89 */
+	{ 6,	TD,	sys_old_mmap,		"old_mmap"   	}, /* 90 */
 	{ 2,	0,	sys_munmap,		"munmap"	}, /* 91 */
 	{ 2,	TF,	sys_truncate,		"truncate"	}, /* 92 */
-	{ 2,	0,	sys_ftruncate,		"ftruncate"	}, /* 93 */
-	{ 2,	0,	sys_fchmod,		"fchmod"	}, /* 94 */
-	{ 3,	0,	sys_fchown,		"fchown"	}, /* 95 */
+	{ 2,	TD,	sys_ftruncate,		"ftruncate"	}, /* 93 */
+	{ 2,	TD,	sys_fchmod,		"fchmod"	}, /* 94 */
+	{ 3,	TD,	sys_fchown,		"fchown"	}, /* 95 */
 	{ 2,	0,	sys_getpriority,	"getpriority"	}, /* 96 */
 	{ 3,	0,	sys_setpriority,	"setpriority"	}, /* 97 */
 	{ 4,	0,	sys_profil,		"profil"	}, /* 98 */
 	{ 2,	TF,	sys_statfs,		"statfs"	}, /* 99 */
-	{ 2,	0,	sys_fstatfs,		"fstatfs"	}, /* 100 */
+	{ 2,	TD,	sys_fstatfs,		"fstatfs"	}, /* 100 */
 	{ 3,	0,	sys_ioperm,		"ioperm"	}, /* 101 */
-	{ 2,	0,	sys_socketcall,		"socketcall"	}, /* 102 */
+	{ 2,	TD,	sys_socketcall,		"socketcall"	}, /* 102 */
 	{ 3,	0,	sys_syslog,		"syslog"	}, /* 103 */
 	{ 3,	0,	sys_setitimer,		"setitimer"	}, /* 104 */
 	{ 2,	0,	sys_getitimer,		"getitimer"	}, /* 105 */
 	{ 2,	TF,	sys_stat,		"stat"		}, /* 106 */
 	{ 2,	TF,	sys_lstat,		"lstat"		}, /* 107 */
-	{ 2,	0,	sys_fstat,		"fstat"		}, /* 108 */
+	{ 2,	TD,	sys_fstat,		"fstat"		}, /* 108 */
 	{ 1,	0,	sys_olduname,		"olduname"	}, /* 109 */
 	{ 1,	0,	sys_iopl,		"iopl"		}, /* 110 */
 	{ 0,	0,	sys_vhangup,		"vhangup"	}, /* 111 */
@@ -148,7 +148,7 @@
 	{ 1,	0,	sys_swapoff,		"swapoff"	}, /* 115 */
 	{ 1,	0,	sys_sysinfo,		"sysinfo"	}, /* 116 */
 	{ 5,	0,	sys_ipc,		"ipc"		}, /* 117 */
-	{ 1,	0,	sys_fsync,		"fsync"		}, /* 118 */
+	{ 1,	TD,	sys_fsync,		"fsync"		}, /* 118 */
 	{ 1,	TS,	sys_sigreturn,		"sigreturn"	}, /* 119 */
 	{ 5,	TP,	sys_clone,		"clone"		}, /* 120 */
 	{ 2,	0,	sys_setdomainname,	"setdomainname"	}, /* 121 */
@@ -158,27 +158,27 @@
 	{ 3,	0,	sys_mprotect,		"mprotect"	}, /* 125 */
 	{ 3,	TS,	sys_sigprocmask,	"sigprocmask"	}, /* 126 */
 	{ 2,	0,	sys_create_module,	"create_module"	}, /* 127 */
-	{ 2,	0,	sys_init_module,	"init_module"	}, /* 128 */
+	{ 3,	0,	sys_init_module,	"init_module"	}, /* 128 */
 	{ 1,	0,	sys_delete_module,	"delete_module"	}, /* 129 */
 	{ 1,	0,	sys_get_kernel_syms,	"get_kernel_syms"}, /* 130 */
 	{ 4,	0,	sys_quotactl,		"quotactl"	}, /* 131 */
 	{ 1,	0,	sys_getpgid,		"getpgid"	}, /* 132 */
-	{ 1,	0,	sys_fchdir,		"fchdir"	}, /* 133 */
+	{ 1,	TD,	sys_fchdir,		"fchdir"	}, /* 133 */
 	{ 0,	0,	sys_bdflush,		"bdflush"	}, /* 134 */
 	{ 3,	0,	sys_sysfs,		"sysfs"		}, /* 135 */
 	{ 1,	0,	sys_personality,	"personality"	}, /* 136 */
 	{ 5,	0,	sys_afs_syscall,	"afs_syscall"	}, /* 137 */
 	{ 1,	0,	sys_setfsuid,		"setfsuid"	}, /* 138 */
 	{ 1,	0,	sys_setfsgid,		"setfsgid"	}, /* 139 */
-	{ 5,	0,	sys_llseek,		"_llseek"	}, /* 140 */
-	{ 3,	0,	sys_getdents,		"getdents"	}, /* 141 */
-	{ 5,	0,	sys_select,		"select"	}, /* 142 */
-	{ 2,	0,	sys_flock,		"flock"		}, /* 143 */
+	{ 5,	TD,	sys_llseek,		"_llseek"	}, /* 140 */
+	{ 3,	TD,	sys_getdents,		"getdents"	}, /* 141 */
+	{ 5,	TD,	sys_select,		"select"	}, /* 142 */
+	{ 2,	TD,	sys_flock,		"flock"		}, /* 143 */
 	{ 3,	0,	sys_msync,		"msync"		}, /* 144 */
-	{ 3,	0,	sys_readv,		"readv"		}, /* 145 */
-	{ 3,	0,	sys_writev,		"writev"	}, /* 146 */
+	{ 3,	TD,	sys_readv,		"readv"		}, /* 145 */
+	{ 3,	TD,	sys_writev,		"writev"	}, /* 146 */
 	{ 1,	0,	sys_getsid,		"getsid"	}, /* 147 */
-	{ 1,	0,	sys_fdatasync,		"fdatasync"	}, /* 148 */
+	{ 1,	TD,	sys_fdatasync,		"fdatasync"	}, /* 148 */
 	{ 1,	0,	sys_sysctl,		"_sysctl"	}, /* 149 */
 	{ 1,	0,	sys_mlock,		"mlock"		}, /* 150 */
 	{ 2,	0,	sys_munlock,		"munlock"	}, /* 151 */
@@ -198,7 +198,7 @@
 	{ 3,	0,	sys_getresuid,		"getresuid"	}, /* 165 */
 	{ 5,	0,	printargs,		"vm86"		}, /* 166 */
 	{ 5,	0,	sys_query_module,	"query_module"	}, /* 167 */
-	{ 3,	0,	sys_poll,		"poll"		}, /* 168 */
+	{ 3,	TD,	sys_poll,		"poll"		}, /* 168 */
 	{ 3,	0,	printargs,		"nfsservctl"	}, /* 169 */
 	{ 3,	0,	sys_setresgid,		"setresgid"	}, /* 170 */
 	{ 3,	0,	sys_getresgid,		"getresgid"	}, /* 171 */
@@ -211,24 +211,24 @@
 	{ 3,	TS,	sys_rt_sigqueueinfo,    "rt_sigqueueinfo"}, /* 178 */
 	{ 2,	TS,	sys_rt_sigsuspend,	"rt_sigsuspend"	}, /* 179 */
 
-	{ 6,	TF,	sys_pread,		"pread"		}, /* 180 */
-	{ 6,	TF,	sys_pwrite,		"pwrite"	}, /* 181 */
+	{ 6,	TD,	sys_pread,		"pread"		}, /* 180 */
+	{ 6,	TD,	sys_pwrite,		"pwrite"	}, /* 181 */
 	{ 3,	TF,	sys_chown,		"chown"		}, /* 182 */
 	{ 2,	0,	sys_getcwd,		"getcwd"	}, /* 183 */
 	{ 2,	0,	sys_capget,		"capget"	}, /* 184 */
 	{ 2,	0,	sys_capset,		"capset"	}, /* 185 */
 	{ 2,	TS,	sys_sigaltstack,	"sigaltstack"	}, /* 186 */
-	{ 4,	TF,	sys_sendfile,		"sendfile"	}, /* 187 */
+	{ 4,	TD,	sys_sendfile,		"sendfile"	}, /* 187 */
 	{ 5,	0,	printargs,		"SYS_188"	}, /* 188 */
 	{ 5,	0,	printargs,		"SYS_189"	}, /* 189 */
 	{ 0,	TP,	sys_vfork,		"vfork"		}, /* 190 */
 	{ 5,	0,	printargs,		"getrlimit"	}, /* 191 */
 	{ 6,	0,	sys_mmap,		"mmap2"		}, /* 192 */
 	{ 5,	0,	sys_truncate64,		"truncate64"	}, /* 193 */
-	{ 5,	0,	sys_ftruncate64,	"ftruncate64"	}, /* 194 */
+	{ 5,	TD,	sys_ftruncate64,	"ftruncate64"	}, /* 194 */
 	{ 2,	TF,	sys_stat64,		"stat64"	}, /* 195 */
 	{ 2,	TF,	sys_lstat64,		"lstat64"	}, /* 196 */
-	{ 2,	TF,	sys_fstat64,		"fstat64"	}, /* 197 */
+	{ 2,	TD,	sys_fstat64,		"fstat64"	}, /* 197 */
 /*TODO*/{ 3,	TF,	printargs,		"lchown32"	}, /* 198 */
 /*TODO*/{ 0,	0,	printargs,		"getuid32"	}, /* 199 */
 
@@ -253,7 +253,7 @@
 	{ 3,	0,	printargs,		"mincore"	}, /* 218 */
 	{ 3,	0,	sys_madvise,		"madvise"	}, /* 219 */
 	{ 4,	0,	printargs,		"getdents64"	}, /* 220 */
-	{ 3,	0,	sys_fcntl,		"fcntl64"	}, /* 221 */
+	{ 3,	TD,	sys_fcntl,		"fcntl64"	}, /* 221 */
 	{ 4,	0,	printargs,		"SYS_222"	}, /* 222 */
 	{ 4,	0,	printargs,		"SYS_223"	}, /* 223 */
 	{ 4,	0,	printargs,		"SYS_224"	}, /* 224 */
@@ -314,24 +314,150 @@
 	{ 5,	0,	printargs,		"SYS_277"	}, /* 277 */
 	{ 5,	0,	printargs,		"SYS_278"	}, /* 278 */
 	{ 5,	0,	printargs,		"SYS_279"	}, /* 279 */
-
-	{ 8,	0,	printargs,		"socket_subcall"}, /* 280 */
-	{ 3,	TN,	sys_socket,		"socket"	}, /* 281 */
-	{ 3,	TN,	sys_bind,		"bind"		}, /* 282 */
-	{ 3,	TN,	sys_connect,		"connect"	}, /* 283 */
-	{ 2,	TN,	sys_listen,		"listen"	}, /* 284 */
-	{ 3,	TN,	sys_accept,		"accept"	}, /* 285 */
-	{ 3,	TN,	sys_getsockname,	"getsockname"	}, /* 286 */
-	{ 3,	TN,	sys_getpeername,	"getpeername"	}, /* 287 */
-	{ 4,	TN,	sys_socketpair,		"socketpair"	}, /* 288 */
-	{ 4,	TN,	sys_send,		"send"		}, /* 289 */
-	{ 4,	TN,	sys_recv,		"recv"		}, /* 290 */
-	{ 6,	TN,	sys_sendto,		"sendto"	}, /* 291 */
-	{ 6,	TN,	sys_recvfrom,		"recvfrom"	}, /* 292 */
-	{ 2,	TN,	sys_shutdown,		"shutdown"	}, /* 293 */
-	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 294 */
-	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 295 */
-	{ 5,	TN,	sys_sendmsg,		"sendmsg"	}, /* 296 */
-	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 297 */
+	{ 5,	0,	printargs,		"SYS_280"	}, /* 280 */
+	{ 5,	0,	printargs,		"SYS_281"	}, /* 281 */
+	{ 5,	0,	printargs,		"SYS_282"	}, /* 282 */
+	{ 5,	0,	printargs,		"SYS_283"	}, /* 283 */
+	{ 5,	0,	printargs,		"SYS_284"	}, /* 284 */
+	{ 5,	0,	printargs,		"SYS_285"	}, /* 285 */
+	{ 5,	0,	printargs,		"SYS_286"	}, /* 286 */
+	{ 5,	0,	printargs,		"SYS_287"	}, /* 287 */
+	{ 5,	0,	printargs,		"SYS_288"	}, /* 288 */
+	{ 5,	0,	printargs,		"SYS_289"	}, /* 289 */
+	{ 5,	0,	printargs,		"SYS_290"	}, /* 290 */
+	{ 5,	0,	printargs,		"SYS_291"	}, /* 291 */
+	{ 5,	0,	printargs,		"SYS_292"	}, /* 292 */
+	{ 5,	0,	printargs,		"SYS_293"	}, /* 293 */
+	{ 5,	0,	printargs,		"SYS_294"	}, /* 294 */
+	{ 5,	0,	printargs,		"SYS_295"	}, /* 295 */
+	{ 5,	0,	printargs,		"SYS_296"	}, /* 296 */
+	{ 5,	0,	printargs,		"SYS_297"	}, /* 297 */
 	{ 5,	0,	printargs,		"SYS_298"	}, /* 298 */
 	{ 5,	0,	printargs,		"SYS_299"	}, /* 299 */
+	{ 5,	0,	printargs,		"SYS_300"	}, /* 300 */
+	{ 5,	0,	printargs,		"SYS_301"	}, /* 301 */
+	{ 5,	0,	printargs,		"SYS_302"	}, /* 302 */
+	{ 5,	0,	printargs,		"SYS_303"	}, /* 303 */
+	{ 5,	0,	printargs,		"SYS_304"	}, /* 304 */
+	{ 5,	0,	printargs,		"SYS_305"	}, /* 305 */
+	{ 5,	0,	printargs,		"SYS_306"	}, /* 306 */
+	{ 5,	0,	printargs,		"SYS_307"	}, /* 307 */
+	{ 5,	0,	printargs,		"SYS_308"	}, /* 308 */
+	{ 5,	0,	printargs,		"SYS_309"	}, /* 309 */
+	{ 5,	0,	printargs,		"SYS_310"	}, /* 310 */
+	{ 5,	0,	printargs,		"SYS_311"	}, /* 311 */
+	{ 5,	0,	printargs,		"SYS_312"	}, /* 312 */
+	{ 5,	0,	printargs,		"SYS_313"	}, /* 313 */
+	{ 5,	0,	printargs,		"SYS_314"	}, /* 314 */
+	{ 5,	0,	printargs,		"SYS_315"	}, /* 315 */
+	{ 5,	0,	printargs,		"SYS_316"	}, /* 316 */
+	{ 5,	0,	printargs,		"SYS_317"	}, /* 317 */
+	{ 5,	0,	printargs,		"SYS_318"	}, /* 318 */
+	{ 5,	0,	printargs,		"SYS_319"	}, /* 319 */
+	{ 5,	0,	printargs,		"SYS_320"	}, /* 320 */
+	{ 5,	0,	printargs,		"SYS_321"	}, /* 321 */
+	{ 5,	0,	printargs,		"SYS_322"	}, /* 322 */
+	{ 5,	0,	printargs,		"SYS_323"	}, /* 323 */
+	{ 5,	0,	printargs,		"SYS_324"	}, /* 324 */
+	{ 5,	0,	printargs,		"SYS_325"	}, /* 325 */
+	{ 5,	0,	printargs,		"SYS_326"	}, /* 326 */
+	{ 5,	0,	printargs,		"SYS_327"	}, /* 327 */
+	{ 5,	0,	printargs,		"SYS_328"	}, /* 328 */
+	{ 5,	0,	printargs,		"SYS_329"	}, /* 329 */
+	{ 5,	0,	printargs,		"SYS_330"	}, /* 330 */
+	{ 5,	0,	printargs,		"SYS_331"	}, /* 331 */
+	{ 5,	0,	printargs,		"SYS_332"	}, /* 332 */
+	{ 5,	0,	printargs,		"SYS_333"	}, /* 333 */
+	{ 5,	0,	printargs,		"SYS_334"	}, /* 334 */
+	{ 5,	0,	printargs,		"SYS_335"	}, /* 335 */
+	{ 5,	0,	printargs,		"SYS_336"	}, /* 336 */
+	{ 5,	0,	printargs,		"SYS_337"	}, /* 337 */
+	{ 5,	0,	printargs,		"SYS_338"	}, /* 338 */
+	{ 5,	0,	printargs,		"SYS_339"	}, /* 339 */
+	{ 5,	0,	printargs,		"SYS_340"	}, /* 340 */
+	{ 5,	0,	printargs,		"SYS_341"	}, /* 341 */
+	{ 5,	0,	printargs,		"SYS_342"	}, /* 342 */
+	{ 5,	0,	printargs,		"SYS_343"	}, /* 343 */
+	{ 5,	0,	printargs,		"SYS_344"	}, /* 344 */
+	{ 5,	0,	printargs,		"SYS_345"	}, /* 345 */
+	{ 5,	0,	printargs,		"SYS_346"	}, /* 346 */
+	{ 5,	0,	printargs,		"SYS_347"	}, /* 347 */
+	{ 5,	0,	printargs,		"SYS_348"	}, /* 348 */
+	{ 5,	0,	printargs,		"SYS_349"	}, /* 349 */
+	{ 5,	0,	printargs,		"SYS_350"	}, /* 350 */
+	{ 5,	0,	printargs,		"SYS_351"	}, /* 351 */
+	{ 5,	0,	printargs,		"SYS_352"	}, /* 352 */
+	{ 5,	0,	printargs,		"SYS_353"	}, /* 353 */
+	{ 5,	0,	printargs,		"SYS_354"	}, /* 354 */
+	{ 5,	0,	printargs,		"SYS_355"	}, /* 355 */
+	{ 5,	0,	printargs,		"SYS_356"	}, /* 356 */
+	{ 5,	0,	printargs,		"SYS_357"	}, /* 357 */
+	{ 5,	0,	printargs,		"SYS_358"	}, /* 358 */
+	{ 5,	0,	printargs,		"SYS_359"	}, /* 359 */
+	{ 5,	0,	printargs,		"SYS_360"	}, /* 360 */
+	{ 5,	0,	printargs,		"SYS_361"	}, /* 361 */
+	{ 5,	0,	printargs,		"SYS_362"	}, /* 362 */
+	{ 5,	0,	printargs,		"SYS_363"	}, /* 363 */
+	{ 5,	0,	printargs,		"SYS_364"	}, /* 364 */
+	{ 5,	0,	printargs,		"SYS_365"	}, /* 365 */
+	{ 5,	0,	printargs,		"SYS_366"	}, /* 366 */
+	{ 5,	0,	printargs,		"SYS_367"	}, /* 367 */
+	{ 5,	0,	printargs,		"SYS_368"	}, /* 368 */
+	{ 5,	0,	printargs,		"SYS_369"	}, /* 369 */
+	{ 5,	0,	printargs,		"SYS_370"	}, /* 370 */
+	{ 5,	0,	printargs,		"SYS_371"	}, /* 371 */
+	{ 5,	0,	printargs,		"SYS_372"	}, /* 372 */
+	{ 5,	0,	printargs,		"SYS_373"	}, /* 373 */
+	{ 5,	0,	printargs,		"SYS_374"	}, /* 374 */
+	{ 5,	0,	printargs,		"SYS_375"	}, /* 375 */
+	{ 5,	0,	printargs,		"SYS_376"	}, /* 376 */
+	{ 5,	0,	printargs,		"SYS_377"	}, /* 377 */
+	{ 5,	0,	printargs,		"SYS_378"	}, /* 378 */
+	{ 5,	0,	printargs,		"SYS_379"	}, /* 379 */
+	{ 5,	0,	printargs,		"SYS_380"	}, /* 380 */
+	{ 5,	0,	printargs,		"SYS_381"	}, /* 381 */
+	{ 5,	0,	printargs,		"SYS_382"	}, /* 382 */
+	{ 5,	0,	printargs,		"SYS_383"	}, /* 383 */
+	{ 5,	0,	printargs,		"SYS_384"	}, /* 384 */
+	{ 5,	0,	printargs,		"SYS_385"	}, /* 385 */
+	{ 5,	0,	printargs,		"SYS_386"	}, /* 386 */
+	{ 5,	0,	printargs,		"SYS_387"	}, /* 387 */
+	{ 5,	0,	printargs,		"SYS_388"	}, /* 388 */
+	{ 5,	0,	printargs,		"SYS_389"	}, /* 389 */
+	{ 5,	0,	printargs,		"SYS_390"	}, /* 390 */
+	{ 5,	0,	printargs,		"SYS_391"	}, /* 391 */
+	{ 5,	0,	printargs,		"SYS_392"	}, /* 392 */
+	{ 5,	0,	printargs,		"SYS_393"	}, /* 393 */
+	{ 5,	0,	printargs,		"SYS_394"	}, /* 394 */
+	{ 5,	0,	printargs,		"SYS_395"	}, /* 395 */
+	{ 5,	0,	printargs,		"SYS_396"	}, /* 396 */
+	{ 5,	0,	printargs,		"SYS_397"	}, /* 397 */
+	{ 5,	0,	printargs,		"SYS_398"	}, /* 398 */
+	{ 5,	0,	printargs,		"SYS_399"	}, /* 399 */
+
+#if SYS_ipc_subcall != 400
+ #error fix me
+#endif
+	{ 8,	0,	printargs,		"socket_subcall"}, /* 400 */
+	{ 3,	TN,	sys_socket,		"socket"	}, /* 401 */
+	{ 3,	TN,	sys_bind,		"bind"		}, /* 402 */
+	{ 3,	TN,	sys_connect,		"connect"	}, /* 403 */
+	{ 2,	TN,	sys_listen,		"listen"	}, /* 404 */
+	{ 3,	TN,	sys_accept,		"accept"	}, /* 405 */
+	{ 3,	TN,	sys_getsockname,	"getsockname"	}, /* 406 */
+	{ 3,	TN,	sys_getpeername,	"getpeername"	}, /* 407 */
+	{ 4,	TN,	sys_socketpair,		"socketpair"	}, /* 408 */
+	{ 4,	TN,	sys_send,		"send"		}, /* 409 */
+	{ 4,	TN,	sys_recv,		"recv"		}, /* 410 */
+	{ 6,	TN,	sys_sendto,		"sendto"	}, /* 411 */
+	{ 6,	TN,	sys_recvfrom,		"recvfrom"	}, /* 412 */
+	{ 2,	TN,	sys_shutdown,		"shutdown"	}, /* 413 */
+	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 414 */
+	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 415 */
+	{ 5,	TN,	sys_sendmsg,		"sendmsg"	}, /* 416 */
+	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 417 */
+
+#if SYS_ipc_subcall != 418
+ #error fix me
+#endif
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 418 */
