@@ -34,7 +34,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: process.c,v 1.98 2005/08/03 11:23:43 roland Exp $
+ *	$Id: process.c,v 1.104 2007/01/11 22:05:05 ldv Exp $
  */
 
 #include "defs.h"
@@ -305,6 +305,7 @@ struct tcb *tcp;
 
 #endif /* HAVE_PRCTL */
 
+#if defined(FREEBSD) || defined(SUNOS4) || defined(SVR4)
 int
 sys_gethostid(tcp)
 struct tcb *tcp;
@@ -313,6 +314,7 @@ struct tcb *tcp;
 		return RVAL_HEX;
 	return 0;
 }
+#endif /* FREEBSD || SUNOS4 || SVR4 */
 
 int
 sys_sethostname(tcp)
@@ -325,6 +327,7 @@ struct tcb *tcp;
 	return 0;
 }
 
+#if defined(ALPHA) || defined(FREEBSD) || defined(SUNOS4) || defined(SVR4)
 int
 sys_gethostname(tcp)
 struct tcb *tcp;
@@ -338,6 +341,7 @@ struct tcb *tcp;
 	}
 	return 0;
 }
+#endif /* ALPHA || FREEBSD || SUNOS4 || SVR4 */
 
 int
 sys_setdomainname(tcp)
@@ -412,7 +416,7 @@ fork_tcb(struct tcb *tcp)
 	if (nprocs == tcbtabsize) {
 		if (expand_tcbtab()) {
 			tcp->flags &= ~TCB_FOLLOWFORK;
-			fprintf(stderr, "sys_fork: tcb table full\n");
+			return 1;
 		}
 	}
 
@@ -474,10 +478,8 @@ struct tcb *tcp;
 			return 0;
 		if (syserror(tcp))
 			return 0;
-		if ((tcpchild = alloctcb(tcp->u_rval)) == NULL) {
-			fprintf(stderr, "sys_fork: tcb table full\n");
+		if ((tcpchild = alloctcb(tcp->u_rval)) == NULL)
 			return 0;
-		}
 		if (proc_open(tcpchild, 2) < 0)
 		  	droptcb(tcpchild);
 	}
@@ -607,6 +609,14 @@ struct tcb *tcp;
 	}
 	return 0;
 }
+
+int
+sys_unshare(struct tcb *tcp)
+{
+	if (entering(tcp))
+		printflags(clone_flags, tcp->u_arg[0], "CLONE_???");
+	return 0;
+}
 #endif
 
 int
@@ -694,6 +704,16 @@ int new;
                                    0x100000 | new) < 0)
                        return -1;
        return 0;
+#elif defined(ARM)
+       /* Some kernels support this, some (pre-2.6.16 or so) don't.  */
+# ifndef PTRACE_SET_SYSCALL
+#  define PTRACE_SET_SYSCALL 23
+# endif
+
+       if (ptrace (PTRACE_SET_SYSCALL, tcp->pid, 0, new) != 0)
+		return -1;
+
+       return 0;
 #else
 #warning Do not know how to handle change_syscall for this architecture
 #endif /* architecture */
@@ -823,10 +843,9 @@ struct tcb *tcp;
 		}
 		else
 #endif
-		if ((tcpchild = alloctcb(pid)) == NULL) {
+		if (fork_tcb(tcp) || (tcpchild = alloctcb(pid)) == NULL) {
 			if (bpt)
 				clearbpt(tcp);
-			fprintf(stderr, " [tcb table full]\n");
 			kill(pid, SIGKILL); /* XXX */
 			return 0;
 		}
@@ -874,7 +893,6 @@ Process %u resumed (parent %d ready)\n",
 					pid, tcp->pid);
 		}
 		else {
-			newoutf(tcpchild);
 			if (!qflag)
 				fprintf(stderr, "Process %d attached\n", pid);
 		}
@@ -960,8 +978,7 @@ struct tcb *tcp;
 			return 0;
 
 		pid = tcp->u_rval;
-		if ((tcpchild = alloctcb(pid)) == NULL) {
-			fprintf(stderr, " [tcb table full]\n");
+		if (fork_tcb(tcp) || (tcpchild = alloctcb(pid)) == NULL) {
 			kill(pid, SIGKILL); /* XXX */
 			return 0;
 		}
@@ -1030,7 +1047,6 @@ struct tcb *tcp;
 			memcpy(tcpchild->inst, tcp->inst,
 				sizeof tcpchild->inst);
 		}
-		newoutf(tcpchild);
 		tcpchild->parent = tcp;
 		tcp->nchildren++;
 		if (!qflag)
@@ -1459,6 +1475,7 @@ struct tcb *tcp;
 }
 #endif /* LINUX */
 
+#if defined(ALPHA) || defined(SUNOS4) || defined(SVR4)
 int
 sys_setpgrp(tcp)
 struct tcb *tcp;
@@ -1470,6 +1487,7 @@ struct tcb *tcp;
 	}
 	return 0;
 }
+#endif /* ALPHA || SUNOS4 || SVR4 */
 
 int
 sys_getpgrp(tcp)
@@ -1578,11 +1596,7 @@ static const struct xlat procpriv_type [] = {
 
 
 static void
-printpriv(tcp, addr, len, opt)
-struct tcb *tcp;
-long addr;
-int len;
-const struct xlat *opt;
+printpriv(struct tcb *tcp, long addr, int len, const struct xlat *opt)
 {
 	priv_t buf [128];
 	int max = verbose (tcp) ? sizeof buf / sizeof buf [0] : 10;
@@ -1601,7 +1615,7 @@ const struct xlat *opt;
 	tprintf ("[");
 
 	for (i = 0; i < len; ++i) {
-		char *t, *p;
+		const char *t, *p;
 
 		if (i) tprintf (", ");
 
@@ -1699,6 +1713,7 @@ long addr;
 	tprintf(fmt, count, count == 1 ? "" : "s");
 }
 
+#if defined(SPARC) || defined(SPARC64) || defined(SUNOS4)
 int
 sys_execv(tcp)
 struct tcb *tcp;
@@ -1719,6 +1734,7 @@ struct tcb *tcp;
 	}
 	return 0;
 }
+#endif /* SPARC || SPARC64 || SUNOS4 */
 
 int
 sys_execve(tcp)
