@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: signal.c,v 1.46 2004/03/01 21:31:02 roland Exp $
+ *	$Id: signal.c,v 1.58 2007/01/11 22:05:06 ldv Exp $
  */
 
 #include "defs.h"
@@ -72,20 +72,27 @@
 #endif /* !IA64 */
 
 #if HAVE_ASM_REG_H
-# ifdef SPARC
+# if defined (SPARC) || defined (SPARC64)
 #  define fpq kernel_fpq
 #  define fq kernel_fq
 #  define fpu kernel_fpu
 # endif
 # include <asm/reg.h>
-# ifdef SPARC
+# if defined (SPARC) || defined (SPARC64)
 #  undef fpq
 #  undef fq
 #  undef fpu
 # endif
+#if defined (LINUX) && defined (SPARC64)
+# define r_pc r_tpc
+# undef PTRACE_GETREGS
+# define PTRACE_GETREGS PTRACE_GETREGS64
+# undef PTRACE_SETREGS
+# define PTRACE_SETREGS PTRACE_SETREGS64
+#endif /* LINUX && SPARC64 */
 #endif /* HAVE_ASM_REG_H */
 
-#ifdef SPARC
+#if defined (SPARC) || defined (SPARC64)
 typedef struct {
 	struct regs		si_regs;
 	int			si_mask;
@@ -146,31 +153,31 @@ struct sigcontext
 #endif
 #endif /* LINUX */
 
-char *signalent0[] = {
+const char *const signalent0[] = {
 #include "signalent.h"
 };
-int nsignals0 = sizeof signalent0 / sizeof signalent0[0];
+const int nsignals0 = sizeof signalent0 / sizeof signalent0[0];
 
 #if SUPPORTED_PERSONALITIES >= 2
-char *signalent1[] = {
+const char *const signalent1[] = {
 #include "signalent1.h"
 };
-int nsignals1 = sizeof signalent1 / sizeof signalent1[0];
+const int nsignals1 = sizeof signalent1 / sizeof signalent1[0];
 #endif /* SUPPORTED_PERSONALITIES >= 2 */
 
 #if SUPPORTED_PERSONALITIES >= 3
-char *signalent2[] = {
+const char *const signalent2[] = {
 #include "signalent2.h"
 };
-int nsignals2 = sizeof signalent2 / sizeof signalent2[0];
+const int nsignals2 = sizeof signalent2 / sizeof signalent2[0];
 #endif /* SUPPORTED_PERSONALITIES >= 3 */
 
-char **signalent;
+const char *const *signalent;
 int nsignals;
 
 #if defined(SUNOS4) || defined(FREEBSD)
 
-static struct xlat sigvec_flags[] = {
+static const struct xlat sigvec_flags[] = {
 	{ SV_ONSTACK,	"SV_ONSTACK"	},
 	{ SV_INTERRUPT,	"SV_INTERRUPT"	},
 	{ SV_RESETHAND,	"SV_RESETHAND"	},
@@ -182,7 +189,7 @@ static struct xlat sigvec_flags[] = {
 
 #ifdef HAVE_SIGACTION
 
-#if defined LINUX && defined I386
+#if defined LINUX && (defined I386 || defined X86_64)
 /* The libc headers do not define this constant since it should only be
    used by the implementation.  So wwe define it here.  */
 # ifndef SA_RESTORER
@@ -190,7 +197,7 @@ static struct xlat sigvec_flags[] = {
 # endif
 #endif
 
-static struct xlat sigact_flags[] = {
+static const struct xlat sigact_flags[] = {
 #ifdef SA_RESTORER
 	{ SA_RESTORER,	"SA_RESTORER"	},
 #endif
@@ -233,7 +240,7 @@ static struct xlat sigact_flags[] = {
 	{ 0,		NULL		},
 };
 
-static struct xlat sigprocmaskcmds[] = {
+static const struct xlat sigprocmaskcmds[] = {
 	{ SIG_BLOCK,	"SIG_BLOCK"	},
 	{ SIG_UNBLOCK,	"SIG_UNBLOCK"	},
 	{ SIG_SETMASK,	"SIG_SETMASK"	},
@@ -255,12 +262,12 @@ static struct xlat sigprocmaskcmds[] = {
 #endif
 #endif
 
-char *
+const char *
 signame(sig)
 int sig;
 {
 	static char buf[30];
-	if (sig < nsignals) {
+	if (sig >= 0 && sig < nsignals) {
 		return signalent[sig];
 #ifdef SIGRTMIN
 	} else if (sig >= __SIGRTMIN && sig <= __SIGRTMAX) {
@@ -306,18 +313,16 @@ int len;
 #define copy_sigset(tcp, addr, s) copy_sigset_len(tcp, addr, s, sizeof(sigset_t))
 #endif
 
-static char *
-sprintsigmask(s, mask, rt)
-char *s;
-sigset_t *mask;
-int rt; /* set might include realtime sigs */
+static const char *
+sprintsigmask(const char *str, sigset_t *mask, int rt)
+/* set might include realtime sigs */
 {
 	int i, nsigs;
 	int maxsigs;
-	char *format;
+	char *format, *s;
 	static char outstr[8 * sizeof(sigset_t) * 8];
 
-	strcpy(outstr, s);
+	strcpy(outstr, str);
 	s = outstr + strlen(outstr);
 	nsigs = 0;
 	maxsigs = nsignals;
@@ -388,6 +393,19 @@ int nr;
 	tprintf(signame(nr));
 }
 
+void
+print_sigset(struct tcb *tcp, long addr, int rt)
+{
+	sigset_t ss;
+
+	if (!addr)
+		tprintf("NULL");
+	else if (copy_sigset(tcp, addr, &ss) < 0)
+		tprintf("%#lx", addr);
+	else
+		printsigmask(&ss, rt);
+}
+
 #ifdef LINUX
 
 #ifndef ILL_ILLOPC
@@ -521,7 +539,7 @@ typedef struct siginfo
 
 #if defined (SVR4) || defined (LINUX)
 
-static struct xlat siginfo_codes[] = {
+static const struct xlat siginfo_codes[] = {
 #ifdef SI_NOINFO
 	{ SI_NOINFO,	"SI_NOINFO"	},
 #endif
@@ -552,7 +570,7 @@ static struct xlat siginfo_codes[] = {
 	{ 0,		NULL		},
 };
 
-static struct xlat sigill_codes[] = {
+static const struct xlat sigill_codes[] = {
 	{ ILL_ILLOPC,	"ILL_ILLOPC"	},
 	{ ILL_ILLOPN,	"ILL_ILLOPN"	},
 	{ ILL_ILLADR,	"ILL_ILLADR"	},
@@ -564,7 +582,7 @@ static struct xlat sigill_codes[] = {
 	{ 0,		NULL		},
 };
 
-static struct xlat sigfpe_codes[] = {
+static const struct xlat sigfpe_codes[] = {
 	{ FPE_INTDIV,	"FPE_INTDIV"	},
 	{ FPE_INTOVF,	"FPE_INTOVF"	},
 	{ FPE_FLTDIV,	"FPE_FLTDIV"	},
@@ -576,13 +594,13 @@ static struct xlat sigfpe_codes[] = {
 	{ 0,		NULL		},
 };
 
-static struct xlat sigtrap_codes[] = {
+static const struct xlat sigtrap_codes[] = {
 	{ TRAP_BRKPT,	"TRAP_BRKPT"	},
 	{ TRAP_TRACE,	"TRAP_TRACE"	},
 	{ 0,		NULL		},
 };
 
-static struct xlat sigchld_codes[] = {
+static const struct xlat sigchld_codes[] = {
 	{ CLD_EXITED,	"CLD_EXITED"	},
 	{ CLD_KILLED,	"CLD_KILLED"	},
 	{ CLD_DUMPED,	"CLD_DUMPED"	},
@@ -592,7 +610,7 @@ static struct xlat sigchld_codes[] = {
 	{ 0,		NULL		},
 };
 
-static struct xlat sigpoll_codes[] = {
+static const struct xlat sigpoll_codes[] = {
 	{ POLL_IN,	"POLL_IN"	},
 	{ POLL_OUT,	"POLL_OUT"	},
 	{ POLL_MSG,	"POLL_MSG"	},
@@ -602,7 +620,7 @@ static struct xlat sigpoll_codes[] = {
 	{ 0,		NULL		},
 };
 
-static struct xlat sigprof_codes[] = {
+static const struct xlat sigprof_codes[] = {
 #ifdef PROF_SIG
 	{ PROF_SIG,	"PROF_SIG"	},
 #endif
@@ -610,7 +628,7 @@ static struct xlat sigprof_codes[] = {
 };
 
 #ifdef SIGEMT
-static struct xlat sigemt_codes[] = {
+static const struct xlat sigemt_codes[] = {
 #ifdef EMT_TAGOVF
 	{ EMT_TAGOVF,	"EMT_TAGOVF"	},
 #endif
@@ -618,13 +636,13 @@ static struct xlat sigemt_codes[] = {
 };
 #endif
 
-static struct xlat sigsegv_codes[] = {
+static const struct xlat sigsegv_codes[] = {
 	{ SEGV_MAPERR,	"SEGV_MAPERR"	},
 	{ SEGV_ACCERR,	"SEGV_ACCERR"	},
 	{ 0,		NULL		},
 };
 
-static struct xlat sigbus_codes[] = {
+static const struct xlat sigbus_codes[] = {
 	{ BUS_ADRALN,	"BUS_ADRALN"	},
 	{ BUS_ADRERR,	"BUS_ADRERR"	},
 	{ BUS_OBJERR,	"BUS_OBJERR"	},
@@ -636,7 +654,7 @@ printsiginfo(sip, verbose)
 siginfo_t *sip;
 int verbose;
 {
-	char *code;
+	const char *code;
 
 	if (sip->si_signo == 0) {
 		tprintf ("{}");
@@ -786,9 +804,9 @@ parse_sigset_t (const char *str, sigset_t *set)
 		if (*p >= '0' && *p <= '9')
 			digit = *p - '0';
 		else if (*p >= 'a' && *p <= 'f')
-			digit = *p - 'a';
+			digit = *p - 'a' + 10;
 		else if (*p >= 'A' && *p <= 'F')
-			digit = *p - 'A';
+			digit = *p - 'A' + 10;
 		else
 			break;
 		if (digit & 1)
@@ -955,8 +973,7 @@ struct tcb *tcp;
 			tprintf("{%#lx, ", (unsigned long) sv.sv_handler);
 			printsigmask(&sv.sv_mask, 0);
 			tprintf(", ");
-			if (!printflags(sigvec_flags, sv.sv_flags))
-				tprintf("0");
+			printflags(sigvec_flags, sv.sv_flags, "SV_???");
 			tprintf("}");
 		}
 	}
@@ -1039,12 +1056,14 @@ struct tcb *tcp;
 	return 0;
 }
 
+#if defined(SUNOS4) || defined(FREEBSD)
 int
 sys_sigblock(tcp)
 struct tcb *tcp;
 {
 	return sys_sigsetmask(tcp);
 }
+#endif /* SUNOS4 || FREEBSD */
 
 #endif /* !SVR4 */
 
@@ -1121,8 +1140,7 @@ struct tcb *tcp;
 			printsigmask(&sigset, 0);
 #endif
 			tprintf(", ");
-			if (!printflags(sigact_flags, sa.sa_flags))
-				tprintf("0");
+			printflags(sigact_flags, sa.sa_flags, "SA_???");
 #ifdef SA_RESTORER
 			if (sa.sa_flags & SA_RESTORER)
 				tprintf(", %p", sa.sa_restorer);
@@ -1188,6 +1206,7 @@ struct tcb *tcp;
 	}
 }
 
+#ifdef SVR4
 int
 sys_sighold(tcp)
 struct tcb *tcp;
@@ -1197,6 +1216,7 @@ struct tcb *tcp;
 	}
 	return 0;
 }
+#endif /* SVR4 */
 
 #endif /* HAVE_SIGACTION */
 
@@ -1375,7 +1395,7 @@ struct tcb *tcp;
 	}
 	return 0;
 #else
-#ifdef SPARC
+#if defined (SPARC) || defined (SPARC64)
 	long i1;
 	struct regs regs;
 	m_siginfo_t si;
@@ -1429,7 +1449,7 @@ struct tcb *tcp;
 #warning         (no problem, just a reminder :-)
 	return 0;
 #endif /* MIPS */
-#endif /* SPARC */
+#endif /* SPARC || SPARC64 */
 #endif /* ALPHA */
 #endif /* !M68K */
 #endif /* !POWERPC */
@@ -1486,7 +1506,7 @@ struct tcb *tcp;
 	return 0;
 }
 #ifndef FREEBSD
-static struct xlat ucontext_flags[] = {
+static const struct xlat ucontext_flags[] = {
 	{ UC_SIGMASK,	"UC_SIGMASK"	},
 	{ UC_STACK,	"UC_STACK"	},
 	{ UC_CPU,	"UC_CPU"	},
@@ -1518,7 +1538,7 @@ typedef struct
 #define stack_t struct sigaltstack
 #endif
 
-static struct xlat sigaltstack_flags[] = {
+static const struct xlat sigaltstack_flags[] = {
 	{ SS_ONSTACK,	"SS_ONSTACK"	},
 	{ SS_DISABLE,	"SS_DISABLE"	},
 	{ 0,		NULL		},
@@ -1534,8 +1554,7 @@ ucontext_t *ucp;
 	tprintf("{");
 	if (!abbrev(tcp)) {
 		tprintf("uc_flags=");
-		if (!printflags(ucontext_flags, ucp->uc_flags))
-			tprintf("0");
+		printflags(ucontext_flags, ucp->uc_flags, "UC_???");
 		tprintf(", uc_link=%#lx, ", (unsigned long) ucp->uc_link);
 	}
 	tprintf("uc_sigmask=");
@@ -1544,8 +1563,7 @@ ucontext_t *ucp;
 		tprintf(", uc_stack={ss_sp=%#lx, ss_size=%d, ss_flags=",
 			(unsigned long) ucp->uc_stack.ss_sp,
 			ucp->uc_stack.ss_size);
-		if (!printflags(sigaltstack_flags, ucp->uc_stack.ss_flags))
-			tprintf("0");
+		printflags(sigaltstack_flags, ucp->uc_stack.ss_flags, "SS_???");
 		tprintf("}");
 	}
 	tprintf(", ...}");
@@ -1606,8 +1624,7 @@ unsigned long addr;
 	if (umove(tcp, addr, &ss) < 0)
 		return -1;
 	tprintf("{ss_sp=%#lx, ss_flags=", (unsigned long) ss.ss_sp);
-	if (!printflags(sigaltstack_flags, ss.ss_flags))
-		tprintf("0");
+	printflags(sigaltstack_flags, ss.ss_flags, "SS_???");
 	tprintf(", ss_size=%lu}", (unsigned long) ss.ss_size);
 	return 0;
 }
@@ -1650,8 +1667,6 @@ struct tcb *tcp;
 		return RVAL_HEX | RVAL_STR;
 	}
 #else /* !ALPHA */
-	sigset_t sigset;
-
 	if (entering(tcp)) {
 #ifdef SVR4
 		if (tcp->u_arg[0] == 0)
@@ -1660,24 +1675,16 @@ struct tcb *tcp;
 #endif /* SVR4 */
 		printxval(sigprocmaskcmds, tcp->u_arg[0], "SIG_???");
 		tprintf(", ");
-		if (!tcp->u_arg[1])
-			tprintf("NULL, ");
-		else if (copy_sigset(tcp, tcp->u_arg[1], &sigset) < 0)
-			tprintf("%#lx, ", tcp->u_arg[1]);
-		else {
-			printsigmask(&sigset, 0);
-			tprintf(", ");
-		}
+		print_sigset(tcp, tcp->u_arg[1], 0);
+		tprintf(", ");
 	}
 	else {
 		if (!tcp->u_arg[2])
 			tprintf("NULL");
 		else if (syserror(tcp))
 			tprintf("%#lx", tcp->u_arg[2]);
-		else if (copy_sigset(tcp, tcp->u_arg[2], &sigset) < 0)
-			tprintf("[?]");
 		else
-			printsigmask(&sigset, 0);
+			print_sigset(tcp, tcp->u_arg[2], 0);
 	}
 #endif /* !ALPHA */
 	return 0;
@@ -1695,12 +1702,14 @@ struct tcb *tcp;
 	return 0;
 }
 
+#if defined(FREEBSD) || defined(SUNOS4)
 int
 sys_killpg(tcp)
 struct tcb *tcp;
 {
 	return sys_kill(tcp);
 }
+#endif /* FREEBSD || SUNOS4 */
 
 #ifdef LINUX
 int
@@ -1732,6 +1741,7 @@ struct tcb *tcp;
 	return 0;
 }
 
+#ifdef SVR4
 int sys_sigwait(tcp)
 struct tcb *tcp;
 {
@@ -1751,6 +1761,7 @@ struct tcb *tcp;
 	}
 	return 0;
 }
+#endif /* SVR4 */
 
 #ifdef LINUX
 
@@ -1850,8 +1861,7 @@ sys_rt_sigaction(tcp)
 					memcpy(&sigset, &sa.sa_mask, sizeof(sigset));
 				printsigmask(&sigset, 1);
 				tprintf(", ");
-				if (!printflags(sigact_flags, sa.sa_flags))
-					tprintf("0");
+				printflags(sigact_flags, sa.sa_flags, "SA_???");
 #ifdef SA_RESTORER
 				if (sa.sa_flags & SA_RESTORER)
 					tprintf(", %p", sa.sa_restorer);
@@ -1949,4 +1959,13 @@ int sys_rt_sigtimedwait(tcp)
 	return 0;
 };
 
+int
+sys_restart_syscall(tcp)
+struct tcb *tcp;
+{
+	if (entering(tcp))
+		tprintf("<... resuming interrupted call ...>");
+	return 0;
+}
+
 #endif /* LINUX */
