@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: stream.c,v 1.21 2004/01/13 10:18:46 roland Exp $
+ *	$Id: stream.c,v 1.26 2006/12/13 16:59:45 ldv Exp $
  */
 
 #include "defs.h"
@@ -70,7 +70,7 @@ struct strbuf {
 #endif /* HAVE_SYS_TIUSER_H */
 
 #ifndef FREEBSD
-static struct xlat msgflags[] = {
+static const struct xlat msgflags[] = {
 	{ RS_HIPRI,	"RS_HIPRI"	},
 	{ 0,		NULL		},
 };
@@ -124,12 +124,12 @@ struct tcb *tcp;
 		for (i = 1; i < 3; i++)
 			printstrbufarg(tcp, tcp->u_arg[i], 0);
 		/* flags */
-		if (!printflags(msgflags, tcp->u_arg[3]))
-			tprintf("0");
+		printflags(msgflags, tcp->u_arg[3], "RS_???");
 	}
 	return 0;
 }
 
+#if defined(SPARC) || defined(SPARC64) || defined(SUNOS4) || defined(SVR4)
 int
 sys_getmsg(tcp)
 struct tcb *tcp;
@@ -155,8 +155,7 @@ struct tcb *tcp;
 			tprintf("[?]");
 		else {
 			tprintf("[");
-			if (!printflags(msgflags, flags))
-				tprintf("0");
+			printflags(msgflags, flags, "RS_???");
 			tprintf("]");
 		}
 		/* decode return value */
@@ -177,9 +176,10 @@ struct tcb *tcp;
 	}
 	return RVAL_HEX | RVAL_STR;
 }
+#endif /* SPARC || SPARC64 || SUNOS4 || SVR4 */
 
 #if defined SYS_putpmsg || defined SYS_getpmsg
-static struct xlat pmsgflags[] = {
+static const struct xlat pmsgflags[] = {
 #ifdef MSG_HIPRI
 	{ MSG_HIPRI,	"MSG_HIPRI"	},
 #endif
@@ -209,8 +209,7 @@ struct tcb *tcp;
 		/* band */
 		tprintf("%ld, ", tcp->u_arg[3]);
 		/* flags */
-		if (!printflags(pmsgflags, tcp->u_arg[4]))
-			tprintf("0");
+		printflags(pmsgflags, tcp->u_arg[4], "MSG_???");
 	}
 	return 0;
 }
@@ -245,8 +244,7 @@ struct tcb *tcp;
 			tprintf("[?]");
 		else {
 			tprintf("[");
-			if (!printflags(pmsgflags, flags))
-				tprintf("0");
+			printflags(pmsgflags, flags, "MSG_???");
 			tprintf("]");
 		}
 		/* decode return value */
@@ -274,7 +272,7 @@ struct tcb *tcp;
 
 #ifdef HAVE_SYS_POLL_H
 
-static struct xlat pollflags[] = {
+static const struct xlat pollflags[] = {
 #ifdef POLLIN
 	{ POLLIN,	"POLLIN"	},
 	{ POLLPRI,	"POLLPRI"	},
@@ -298,66 +296,98 @@ static struct xlat pollflags[] = {
 	{ 0,		NULL		},
 };
 
-int
-sys_poll(tcp)
-struct tcb *tcp;
+static int
+decode_poll(struct tcb *tcp)
 {
-	struct pollfd *pollp;
+	struct pollfd fds;
+	unsigned nfds;
+	unsigned long size, start, cur, end, abbrev_end;
+	int failed = 0;
 
+	if (entering(tcp))
+		return 0;
+
+	nfds = tcp->u_arg[1];
+	size = sizeof(fds) * nfds;
+	start = tcp->u_arg[0];
+	end = start + size;
+	if (nfds == 0 || size / sizeof(fds) != nfds || end < start) {
+		tprintf("%#lx, %d, ",
+			tcp->u_arg[0], nfds);
+		return 0;
+	}
+	if (abbrev(tcp)) {
+		abbrev_end = start + max_strlen * sizeof(fds);
+		if (abbrev_end < start)
+			abbrev_end = end;
+	} else {
+		abbrev_end = end;
+	}
+	tprintf("[");
+	for (cur = start; cur < end; cur += sizeof(fds)) {
+		if (cur > start)
+			tprintf(", ");
+		if (cur >= abbrev_end) {
+			tprintf("...");
+			break;
+		}
+		if (umoven(tcp, cur, sizeof fds, (char *) &fds) < 0) {
+			tprintf("?");
+			failed = 1;
+			break;
+		}
+		if (fds.fd < 0) {
+			tprintf("{fd=%d}", fds.fd);
+			continue;
+		}
+		tprintf("{fd=%d, events=", fds.fd);
+		printflags(pollflags, fds.events, "POLL???");
+		if (!syserror(tcp) && fds.revents) {
+			tprintf(", revents=");
+			printflags(pollflags, fds.revents, "POLL???");
+		}
+		tprintf("}");
+	}
+	tprintf("]");
+	if (failed)
+		tprintf(" %#lx", start);
+	tprintf(", %d, ", nfds);
+	return 0;
+}
+
+int
+sys_poll(struct tcb *tcp)
+{
+	int rc = decode_poll(tcp);
 	if (exiting(tcp)) {
-		int i;
-		int nfds = tcp->u_arg[1];
-
-		if (nfds <= 0) {
-			tprintf("%#lx, %d, %ld\n",
-				tcp->u_arg[0], nfds, tcp->u_arg[2]);
-			return 0;
-		}
-		pollp = (struct pollfd *) malloc(nfds * sizeof(*pollp));
-		if (pollp == NULL) {
-			fprintf(stderr, "sys_poll: no memory\n");
-			tprintf("%#lx, %d, %ld",
-				tcp->u_arg[0], nfds, tcp->u_arg[2]);
-			return 0;
-		}
-		if (umoven(tcp, tcp->u_arg[0],
-			   (nfds * sizeof(*pollp)), (char *) pollp) < 0) {
-			tprintf("%#lx", tcp->u_arg[0]);
-		}
-		else {
-			tprintf("[");
-			for (i = 0; i < nfds; i++) {
-				if (i)
-					tprintf(", ");
-				if (pollp[i].fd < 0) {
-					tprintf("{fd=%d}", pollp[i].fd);
-					continue;
-				}
-				tprintf("{fd=%d, events=", pollp[i].fd);
-				if (!printflags(pollflags, pollp[i].events))
-					tprintf("0");
-				if (!syserror(tcp) && pollp[i].revents) {
-					tprintf(", revents=");
-					if (!printflags(pollflags,
-							pollp[i].revents))
-						tprintf("0");
-				}
-				tprintf("}");
-			}
-			tprintf("]");
-		}
-		tprintf(", %d, ", nfds);
 #ifdef INFTIM
 		if (tcp->u_arg[2] == INFTIM)
 			tprintf("INFTIM");
 		else
 #endif
 			tprintf("%ld", tcp->u_arg[2]);
-		free(pollp);
 	}
-	return 0;
+	return rc;
 }
 
+#ifdef LINUX
+int
+sys_ppoll(struct tcb *tcp)
+{
+	int rc = decode_poll(tcp);
+	if (exiting(tcp)) {
+		struct timespec ts;
+		if (umove(tcp, tcp->u_arg[2], &ts) == 0)
+			tprintf("{%lu, %lu}, ", ts.tv_sec, ts.tv_nsec);
+		else
+			tprintf("{...}, ");
+		print_sigset(tcp, tcp->u_arg[3], 0);
+		tprintf(", %lu", tcp->u_arg[4]);
+	}
+	return rc;
+}
+#endif
+
 #else /* !HAVE_SYS_POLL_H */
 int
 sys_poll(tcp)
@@ -369,7 +399,7 @@ struct tcb *tcp;
 
 #if !defined(LINUX) && !defined(FREEBSD)
 
-static struct xlat stream_flush_options[] = {
+static const struct xlat stream_flush_options[] = {
 	{ FLUSHR,	"FLUSHR"	},
 	{ FLUSHW,	"FLUSHW"	},
 	{ FLUSHRW,	"FLUSHRW"	},
@@ -379,7 +409,7 @@ static struct xlat stream_flush_options[] = {
 	{ 0,		NULL		},
 };
 
-static struct xlat stream_setsig_flags[] = {
+static const struct xlat stream_setsig_flags[] = {
 	{ S_INPUT,	"S_INPUT"	},
 	{ S_HIPRI,	"S_HIPRI"	},
 	{ S_OUTPUT,	"S_OUTPUT"	},
@@ -408,14 +438,14 @@ static struct xlat stream_setsig_flags[] = {
 	{ 0,		NULL		},
 };
 
-static struct xlat stream_read_options[] = {
+static const struct xlat stream_read_options[] = {
 	{ RNORM,	"RNORM"		},
 	{ RMSGD,	"RMSGD"		},
 	{ RMSGN,	"RMSGN"		},
 	{ 0,		NULL		},
 };
 
-static struct xlat stream_read_flags[] = {
+static const struct xlat stream_read_flags[] = {
 #ifdef RPROTDAT
 	{ RPROTDAT,	"RPROTDAT"	},
 #endif
@@ -433,7 +463,7 @@ static struct xlat stream_read_flags[] = {
 #endif
 
 #ifdef I_SWROPT
-static struct xlat stream_write_flags[] = {
+static const struct xlat stream_write_flags[] = {
 	{ SNDZERO,	"SNDZERO"	},
 	{ SNDPIPE,	"SNDPIPE"	},
 	{ 0,		NULL		},
@@ -441,7 +471,7 @@ static struct xlat stream_write_flags[] = {
 #endif /* I_SWROPT */
 
 #ifdef I_ATMARK
-static struct xlat stream_atmark_options[] = {
+static const struct xlat stream_atmark_options[] = {
 	{ ANYMARK,	"ANYMARK"	},
 	{ LASTMARK,	"LASTMARK"	},
 	{ 0,		NULL		},
@@ -449,7 +479,7 @@ static struct xlat stream_atmark_options[] = {
 #endif /* I_ATMARK */
 
 #ifdef TI_BIND
-static struct xlat transport_user_options[] = {
+static const struct xlat transport_user_options[] = {
 	{ T_CONN_REQ,	"T_CONN_REQ"	},
 	{ T_CONN_RES,	"T_CONN_RES"	},
 	{ T_DISCON_REQ,	"T_DISCON_REQ"	},
@@ -464,7 +494,7 @@ static struct xlat transport_user_options[] = {
 	{ 0,		NULL		},
 };
 
-static struct xlat transport_user_flags [] = {
+static const struct xlat transport_user_flags [] = {
 	{ 0,		"0"		},
 	{ T_MORE,	"T_MORE"	},
 	{ T_EXPEDITED,	"T_EXPEDITED"	},
@@ -483,12 +513,12 @@ static struct xlat transport_user_flags [] = {
 
 #ifdef HAVE_STRUCT_T_OPTHDR
 
-static struct xlat xti_level [] = {
+static const struct xlat xti_level [] = {
 	{ XTI_GENERIC,	"XTI_GENERIC"	},
 	{ 0,		NULL		},
 };
 
-static struct xlat xti_generic [] = {
+static const struct xlat xti_generic [] = {
 	{ XTI_DEBUG,	"XTI_DEBUG"	},
 	{ XTI_LINGER,	"XTI_LINGER"	},
 	{ XTI_RCVBUF,	"XTI_RCVBUF"	},
@@ -574,14 +604,14 @@ int len;
 
 
 
-static struct xlat service_type [] = {
+static const struct xlat service_type [] = {
 	{ T_COTS,	"T_COTS"	},
 	{ T_COTS_ORD,	"T_COTS_ORD"	},
 	{ T_CLTS,	"T_CLTS"	},
 	{ 0,		NULL		},
 };
 
-static struct xlat ts_state [] = {
+static const struct xlat ts_state [] = {
 	{ TS_UNBND,	"TS_UNBND"	},
 	{ TS_WACK_BREQ,	"TS_WACK_BREQ"	},
 	{ TS_WACK_UREQ,	"TS_WACK_UREQ"	},
@@ -602,7 +632,7 @@ static struct xlat ts_state [] = {
 	{ 0,		NULL		},
 };
 
-static struct xlat provider_flags [] = {
+static const struct xlat provider_flags [] = {
 	{ 0,		"0"		},
 	{ SENDZERO,	"SENDZERO"	},
 	{ EXPINLINE,	"EXPINLINE"	},
@@ -611,7 +641,7 @@ static struct xlat provider_flags [] = {
 };
 
 
-static struct xlat tli_errors [] = {
+static const struct xlat tli_errors [] = {
 	{ TBADADDR,	"TBADADDR"	},
 	{ TBADOPT,	"TBADOPT"	},
 	{ TACCES,	"TACCES"	},
@@ -774,7 +804,8 @@ int len;
 		GET (T_OPTMGMT_REQ, optmgmt_req);
 		COMMA ();
 		tprintf ("MGMT=");
-		printflags (transport_user_flags, m.optmgmt_req.MGMT_flags);
+		printflags (transport_user_flags, m.optmgmt_req.MGMT_flags,
+			    "T_???");
 		STRUCT (optmgmt_req, OPT, print_optmgmt);
 		break;
 #endif
@@ -834,7 +865,7 @@ int len;
 		tprintf (", CURRENT=");
 		printxval (ts_state, m.info_ack.CURRENT_state, "TS_???");
 		tprintf (", PROVIDER=");
-		printflags (provider_flags, m.info_ack.PROVIDER_flag);
+		printflags (provider_flags, m.info_ack.PROVIDER_flag, "???");
 		break;
 #endif
 #ifdef T_BIND_ACK
@@ -885,7 +916,8 @@ int len;
 		GET (T_OPTMGMT_ACK, optmgmt_ack);
 		COMMA ();
 		tprintf ("MGMT=");
-		printflags (transport_user_flags, m.optmgmt_ack.MGMT_flags);
+		printflags (transport_user_flags, m.optmgmt_ack.MGMT_flags,
+			    "T_???");
 		STRUCT (optmgmt_ack, OPT, print_optmgmt);
 		break;
 #endif
@@ -1127,8 +1159,7 @@ int code, arg;
 			tprintf(", {...}");
 		else {
 			tprintf(", {bi_pri=%d, bi_flag=", bi.bi_pri);
-			if (!printflags(stream_flush_options, bi.bi_flag))
-				tprintf("0");
+			printflags(stream_flush_options, bi.bi_flag, "FLUSH???");
 			tprintf("}");
 		}
 		return 1;
@@ -1136,8 +1167,7 @@ int code, arg;
 	case I_SETSIG:
 		/* argument is a set of flags */
 		tprintf(", ");
-		if (!printflags(stream_setsig_flags, arg))
-			tprintf("0");
+		printflags(stream_setsig_flags, arg, "S_???");
 		return 1;
 	case I_GETSIG:
 		/* argument is a pointer to a set of flags */
@@ -1146,8 +1176,8 @@ int code, arg;
 		tprintf(", [");
 		if (umove(tcp, arg, &val) < 0)
 			tprintf("?");
-		else if (!printflags(stream_setsig_flags, val))
-			tprintf("0");
+		else
+			printflags(stream_setsig_flags, val, "S_???");
 		tprintf("]");
 		return 1;
 	case I_PEEK:
@@ -1163,8 +1193,7 @@ int code, arg;
 		tprintf(", databuf=");
 		printstrbuf(tcp, &sp.databuf, 1);
 		tprintf(", flags=");
-		if (!printflags(msgflags, sp.flags))
-			tprintf("0");
+		printflags(msgflags, sp.flags, "RS_???");
 		tprintf("}");
 		return 1;
 	case I_SRDOPT:
@@ -1216,16 +1245,14 @@ int code, arg;
 		tprintf(", databuf=");
 		printstrbuf(tcp, &sfi.databuf, 1);
 		tprintf(", flags=");
-		if (!printflags(msgflags, sfi.flags))
-			tprintf("0");
+		printflags(msgflags, sfi.flags, "RS_???");
 		tprintf(", filedes=%d, offset=%d}", sfi.fildes, sfi.offset);
 		return 1;
 #ifdef I_SWROPT
 	case I_SWROPT:
 		/* argument is a set of flags */
 		tprintf(", ");
-		if (!printflags(stream_write_flags, arg))
-			tprintf("0");
+		printflags(stream_write_flags, arg, "SND???");
 		return 1;
 #endif /* I_SWROPT */
 #ifdef I_GWROPT
@@ -1236,8 +1263,8 @@ int code, arg;
 		tprintf(", [");
 		if (umove(tcp, arg, &val) < 0)
 			tprintf("?");
-		else if (!printflags(stream_write_flags, arg))
-			tprintf("0");
+		else
+			printflags(stream_write_flags, arg, "SND???");
 		tprintf("]");
 		return 1;
 #endif /* I_GWROPT */
