@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.c,v 1.66 2004/03/02 06:52:01 roland Exp $
+ *	$Id: syscall.c,v 1.88 2006/12/21 21:15:04 ldv Exp $
  */
 
 #include "defs.h"
@@ -43,13 +43,13 @@
 #include <sys/param.h>
 
 #if HAVE_ASM_REG_H
-#ifdef SPARC
+#if defined (SPARC) || defined (SPARC64)
 #  define fpq kernel_fpq
 #  define fq kernel_fq
 #  define fpu kernel_fpu
 #endif
 #include <asm/reg.h>
-#ifdef SPARC
+#if defined (SPARC) || defined (SPARC64)
 #  undef fpq
 #  undef fq
 #  undef fpu
@@ -74,6 +74,14 @@
 # undef pt_all_user_regs
 #endif
 
+#if defined (LINUX) && defined (SPARC64)
+# define r_pc r_tpc
+# undef PTRACE_GETREGS
+# define PTRACE_GETREGS PTRACE_GETREGS64
+# undef PTRACE_SETREGS
+# define PTRACE_SETREGS PTRACE_SETREGS64
+#endif /* LINUX && SPARC64 */
+
 #if defined(LINUX) && defined(IA64)
 # include <asm/ptrace_offsets.h>
 # include <asm/rse.h>
@@ -110,68 +118,86 @@
 #include "syscall.h"
 
 /* Define these shorthand notations to simplify the syscallent files. */
+#define TD TRACE_DESC
 #define TF TRACE_FILE
 #define TI TRACE_IPC
 #define TN TRACE_NETWORK
 #define TP TRACE_PROCESS
 #define TS TRACE_SIGNAL
 
-struct sysent sysent0[] = {
+static const struct sysent sysent0[] = {
 #include "syscallent.h"
 };
-int nsyscalls0 = sizeof sysent0 / sizeof sysent0[0];
+static const int nsyscalls0 = sizeof sysent0 / sizeof sysent0[0];
+int qual_flags0[MAX_QUALS];
 
 #if SUPPORTED_PERSONALITIES >= 2
-struct sysent sysent1[] = {
+static const struct sysent sysent1[] = {
 #include "syscallent1.h"
 };
-int nsyscalls1 = sizeof sysent1 / sizeof sysent1[0];
+static const int nsyscalls1 = sizeof sysent1 / sizeof sysent1[0];
+int qual_flags1[MAX_QUALS];
 #endif /* SUPPORTED_PERSONALITIES >= 2 */
 
 #if SUPPORTED_PERSONALITIES >= 3
-struct sysent sysent2[] = {
+static const struct sysent sysent2[] = {
 #include "syscallent2.h"
 };
-int nsyscalls2 = sizeof sysent2 / sizeof sysent2[0];
+static const int nsyscalls2 = sizeof sysent2 / sizeof sysent2[0];
+int qual_flags2[MAX_QUALS];
 #endif /* SUPPORTED_PERSONALITIES >= 3 */
 
-struct sysent *sysent;
+const struct sysent *sysent;
+int *qual_flags;
 int nsyscalls;
 
 /* Now undef them since short defines cause wicked namespace pollution. */
+#undef TD
 #undef TF
 #undef TI
 #undef TN
 #undef TP
 #undef TS
 
-char *errnoent0[] = {
+static const char *const errnoent0[] = {
 #include "errnoent.h"
 };
-int nerrnos0 = sizeof errnoent0 / sizeof errnoent0[0];
+static const int nerrnos0 = sizeof errnoent0 / sizeof errnoent0[0];
 
 #if SUPPORTED_PERSONALITIES >= 2
-char *errnoent1[] = {
+static const char *const errnoent1[] = {
 #include "errnoent1.h"
 };
-int nerrnos1 = sizeof errnoent1 / sizeof errnoent1[0];
+static const int nerrnos1 = sizeof errnoent1 / sizeof errnoent1[0];
 #endif /* SUPPORTED_PERSONALITIES >= 2 */
 
 #if SUPPORTED_PERSONALITIES >= 3
-char *errnoent2[] = {
+static const char *const errnoent2[] = {
 #include "errnoent2.h"
 };
-int nerrnos2 = sizeof errnoent2 / sizeof errnoent2[0];
+static const int nerrnos2 = sizeof errnoent2 / sizeof errnoent2[0];
 #endif /* SUPPORTED_PERSONALITIES >= 3 */
 
-char **errnoent;
+const char *const *errnoent;
 int nerrnos;
 
 int current_personality;
 
+#ifndef PERSONALITY0_WORDSIZE
+# define PERSONALITY0_WORDSIZE sizeof(long)
+#endif
+const int personality_wordsize[SUPPORTED_PERSONALITIES] = {
+	PERSONALITY0_WORDSIZE,
+#if SUPPORTED_PERSONALITIES > 1
+	PERSONALITY1_WORDSIZE,
+#endif
+#if SUPPORTED_PERSONALITIES > 2
+	PERSONALITY2_WORDSIZE,
+#endif
+};;
+
 int
-set_personality(personality)
-int personality;
+set_personality(int personality)
 {
 	switch (personality) {
 	case 0:
@@ -183,6 +209,7 @@ int personality;
 		nioctlents = nioctlents0;
 		signalent = signalent0;
 		nsignals = nsignals0;
+		qual_flags = qual_flags0;
 		break;
 
 #if SUPPORTED_PERSONALITIES >= 2
@@ -195,6 +222,7 @@ int personality;
 		nioctlents = nioctlents1;
 		signalent = signalent1;
 		nsignals = nsignals1;
+		qual_flags = qual_flags1;
 		break;
 #endif /* SUPPORTED_PERSONALITIES >= 2 */
 
@@ -208,6 +236,7 @@ int personality;
 		nioctlents = nioctlents2;
 		signalent = signalent2;
 		nsignals = nsignals2;
+		qual_flags = qual_flags2;
 		break;
 #endif /* SUPPORTED_PERSONALITIES >= 3 */
 
@@ -219,18 +248,10 @@ int personality;
 	return 0;
 }
 
-int qual_flags[MAX_QUALS];
-
-static int call_count[MAX_QUALS];
-static int error_count[MAX_QUALS];
-static struct timeval tv_count[MAX_QUALS];
-static int sorted_count[MAX_QUALS];
-
-static struct timeval shortest = { 1000000, 0 };
 
 static int qual_syscall(), qual_signal(), qual_fault(), qual_desc();
 
-static struct qual_options {
+static const struct qual_options {
 	int bitflag;
 	char *option_name;
 	int (*qualify)();
@@ -260,50 +281,95 @@ static struct qual_options {
 };
 
 static void
-qualify_one(n, opt, not)
+qualify_one(n, opt, not, pers)
 	int n;
-	struct qual_options *opt;
+	const struct qual_options *opt;
 	int not;
+	int pers;
 {
-	if (not)
-		qual_flags[n] &= ~opt->bitflag;
-	else
-		qual_flags[n] |= opt->bitflag;
+	if (pers == 0 || pers < 0) {
+		if (not)
+			qual_flags0[n] &= ~opt->bitflag;
+		else
+			qual_flags0[n] |= opt->bitflag;
+	}
+
+#if SUPPORTED_PERSONALITIES >= 2
+	if (pers == 1 || pers < 0) {
+		if (not)
+			qual_flags1[n] &= ~opt->bitflag;
+		else
+			qual_flags1[n] |= opt->bitflag;
+	}
+#endif /* SUPPORTED_PERSONALITIES >= 2 */
+
+#if SUPPORTED_PERSONALITIES >= 3
+	if (pers == 2 || pers < 0) {
+		if (not)
+			qual_flags2[n] &= ~opt->bitflag;
+		else
+			qual_flags2[n] |= opt->bitflag;
+	}
+#endif /* SUPPORTED_PERSONALITIES >= 3 */
 }
 
 static int
 qual_syscall(s, opt, not)
 	char *s;
-	struct qual_options *opt;
+	const struct qual_options *opt;
 	int not;
 {
 	int i;
-	int any = 0;
+	int rc = -1;
 
-	for (i = 0; i < nsyscalls; i++) {
-		if (strcmp(s, sysent[i].sys_name) == 0) {
-			qualify_one(i, opt, not);
-			any = 1;
-		}
+  	if (isdigit((unsigned char)*s)) {
+ 		int i = atoi(s);
+ 		if (i < 0 || i >= nsyscalls)
+ 			return -1;
+ 		qualify_one(i, opt, not, -1);
+ 		return 0;
 	}
-	return !any;
+	for (i = 0; i < nsyscalls; i++) {
+		if (strcmp(s, sysent0[i].sys_name) == 0) {
+			qualify_one(i, opt, not, 0);
+			rc = 0;
+		}
+
+#if SUPPORTED_PERSONALITIES >= 2
+		if (strcmp(s, sysent1[i].sys_name) == 0) {
+			qualify_one(i, opt, not, 1);
+			rc = 0;
+		}
+#endif /* SUPPORTED_PERSONALITIES >= 2 */
+
+#if SUPPORTED_PERSONALITIES >= 3
+		if (strcmp(s, sysent2[i].sys_name) == 0) {
+			qualify_one(i, opt, not, 2);
+			rc = 0;
+		}
+#endif /* SUPPORTED_PERSONALITIES >= 3 */
+	}
+	return rc;
 }
 
 static int
 qual_signal(s, opt, not)
 	char *s;
-	struct qual_options *opt;
+	const struct qual_options *opt;
 	int not;
 {
 	int i;
 	char buf[32];
 
-	if (s && *s && isdigit((unsigned char)*s)) {
-		qualify_one(atoi(s), opt, not);
-		return 1;
+  	if (isdigit((unsigned char)*s)) {
+ 		int signo = atoi(s);
+ 		if (signo < 0 || signo >= MAX_QUALS)
+ 			return -1;
+ 		qualify_one(signo, opt, not, -1);
+ 		return 0;
 	}
 	if (strlen(s) >= sizeof buf)
-		return 0;
+		return -1;
 	strcpy(buf, s);
 	s = buf;
 	for (i = 0; s[i]; i++)
@@ -312,16 +378,16 @@ qual_signal(s, opt, not)
 		s += 3;
 	for (i = 0; i <= NSIG; i++)
 		if (strcmp(s, signame(i) + 3) == 0) {
-			qualify_one(atoi(s), opt, not);
-			return 1;
+			qualify_one(i, opt, not, -1);
+			return 0;
 		}
-	return 0;
+	return -1;
 }
 
 static int
 qual_fault(s, opt, not)
 	char *s;
-	struct qual_options *opt;
+	const struct qual_options *opt;
 	int not;
 {
 	return -1;
@@ -330,11 +396,14 @@ qual_fault(s, opt, not)
 static int
 qual_desc(s, opt, not)
 	char *s;
-	struct qual_options *opt;
+	const struct qual_options *opt;
 	int not;
 {
-	if (s && *s && isdigit((unsigned char)*s)) {
-		qualify_one(atoi(s), opt, not);
+	if (isdigit((unsigned char)*s)) {
+		int desc = atoi(s);
+		if (desc < 0 || desc >= MAX_QUALS)
+			return -1;
+		qualify_one(desc, opt, not, -1);
 		return 0;
 	}
 	return -1;
@@ -354,6 +423,8 @@ lookup_class(s)
 		return TRACE_PROCESS;
 	if (strcmp(s, "signal") == 0)
 		return TRACE_SIGNAL;
+	if (strcmp(s, "desc") == 0)
+		return TRACE_DESC;
 	return -1;
 }
 
@@ -361,7 +432,7 @@ void
 qualify(s)
 char *s;
 {
-	struct qual_options *opt;
+	const struct qual_options *opt;
 	int not;
 	char *p;
 	int i, n;
@@ -386,28 +457,28 @@ char *s;
 	}
 	if (strcmp(s, "all") == 0) {
 		for (i = 0; i < MAX_QUALS; i++) {
-			if (not)
-				qual_flags[i] &= ~opt->bitflag;
-			else
-				qual_flags[i] |= opt->bitflag;
+			qualify_one(i, opt, not, -1);
 		}
 		return;
 	}
 	for (i = 0; i < MAX_QUALS; i++) {
-		if (not)
-			qual_flags[i] |= opt->bitflag;
-		else
-			qual_flags[i] &= ~opt->bitflag;
+		qualify_one(i, opt, !not, -1);
 	}
 	for (p = strtok(s, ","); p; p = strtok(NULL, ",")) {
 		if (opt->bitflag == QUAL_TRACE && (n = lookup_class(p)) > 0) {
 			for (i = 0; i < MAX_QUALS; i++) {
-				if (sysent[i].sys_flags & n) {
-					if (not)
-						qual_flags[i] &= ~opt->bitflag;
-					else
-						qual_flags[i] |= opt->bitflag;
-				}
+				if (sysent0[i].sys_flags & n)
+					qualify_one(i, opt, not, 0);
+
+#if SUPPORTED_PERSONALITIES >= 2
+				if (sysent1[i].sys_flags & n)
+					qualify_one(i, opt, not, 1);
+#endif /* SUPPORTED_PERSONALITIES >= 2 */
+
+#if SUPPORTED_PERSONALITIES >= 3
+				if (sysent2[i].sys_flags & n)
+					qualify_one(i, opt, not, 2);
+#endif /* SUPPORTED_PERSONALITIES >= 3 */
 			}
 			continue;
 		}
@@ -428,23 +499,43 @@ struct tcb *tcp;
 		return;
 	if (tcp->u_arg[0] < 0 || tcp->u_arg[0] >= MAX_QUALS)
 		return;
-	switch (tcp->scno + NR_SYSCALL_BASE) {
+	switch (known_scno(tcp)) {
 	case SYS_read:
+#ifdef SYS_pread64
+	case SYS_pread64:
+#endif
+#if defined SYS_pread && SYS_pread64 != SYS_pread
+	case SYS_pread:
+#endif
 #ifdef SYS_recv
 	case SYS_recv:
+#elif defined SYS_sub_recv
+	case SYS_sub_recv:
 #endif
 #ifdef SYS_recvfrom
 	case SYS_recvfrom:
+#elif defined SYS_sub_recvfrom
+	case SYS_sub_recvfrom:
 #endif
 		if (qual_flags[tcp->u_arg[0]] & QUAL_READ)
 			dumpstr(tcp, tcp->u_arg[1], tcp->u_rval);
 		break;
 	case SYS_write:
+#ifdef SYS_pwrite64
+	case SYS_pwrite64:
+#endif
+#if defined SYS_pwrite && SYS_pwrite64 != SYS_pwrite
+	case SYS_pwrite:
+#endif
 #ifdef SYS_send
 	case SYS_send:
+#elif defined SYS_sub_send
+	case SYS_sub_send:
 #endif
 #ifdef SYS_sendto
 	case SYS_sendto:
+#elif defined SYS_sub_sendto
+	case SYS_sub_sendto:
 #endif
 		if (qual_flags[tcp->u_arg[0]] & QUAL_WRITE)
 			dumpstr(tcp, tcp->u_arg[1], tcp->u_arg[2]);
@@ -476,7 +567,7 @@ struct subcall {
   int subcalls[5];
 };
 
-const struct subcall subcalls_table[] = {
+static const struct subcall subcalls_table[] = {
   { SYS_shmsys, 5, { SYS_shmat, SYS_shmctl, SYS_shmdt, SYS_shmget, SYS_shmctl } },
 #ifdef SYS_semconfig
   { SYS_semsys, 4, { SYS___semctl, SYS_semget, SYS_semop, SYS_semconfig } },
@@ -489,7 +580,7 @@ const struct subcall subcalls_table[] = {
 
 #if !(defined(LINUX) && ( defined(ALPHA) || defined(MIPS) ))
 
-const int socket_map [] = {
+static const int socket_map [] = {
 	       /* SYS_SOCKET      */ 97,
 	       /* SYS_BIND        */ 104,
 	       /* SYS_CONNECT     */ 98,
@@ -509,7 +600,8 @@ const int socket_map [] = {
 	       /* SYS_RECVMSG     */ 113
 };
 
-void
+#if defined (SPARC) || defined (SPARC64)
+static void
 sparc_socket_decode (tcp)
 struct tcb *tcp;
 {
@@ -530,16 +622,18 @@ struct tcb *tcp;
 		addr += sizeof (arg);
 	}
 }
+#endif
 
-void
+static void
 decode_subcall(tcp, subcall, nsubcalls, style)
 struct tcb *tcp;
 int subcall;
 int nsubcalls;
 enum subcall_style style;
 {
-	long addr, mask, arg;
+	unsigned long addr, mask;
 	int i;
+	int size = personality_wordsize[current_personality];
 
 	switch (style) {
 	case shift_style:
@@ -559,10 +653,21 @@ enum subcall_style style;
 		tcp->scno = subcall + tcp->u_arg[0];
 		addr = tcp->u_arg[1];
 		for (i = 0; i < sysent[tcp->scno].nargs; i++) {
-			if (umove(tcp, addr, &arg) < 0)
-				arg = 0;
-			tcp->u_arg[i] = arg;
-			addr += sizeof(arg);
+			if (size == sizeof(int)) {
+				unsigned int arg;
+				if (umove(tcp, addr, &arg) < 0)
+					arg = 0;
+				tcp->u_arg[i] = arg;
+			}
+			else if (size == sizeof(long)) {
+				unsigned long arg;
+				if (umove(tcp, addr, &arg) < 0)
+					arg = 0;
+				tcp->u_arg[i] = arg;
+			}
+			else
+				abort();
+			addr += size;
 		}
 		tcp->u_nargs = sysent[tcp->scno].nargs;
 		break;
@@ -609,93 +714,64 @@ enum subcall_style style;
 struct tcb *tcp_last = NULL;
 
 static int
-internal_syscall(tcp)
-struct tcb *tcp;
+internal_syscall(struct tcb *tcp)
 {
 	/*
 	 * We must always trace a few critical system calls in order to
 	 * correctly support following forks in the presence of tracing
 	 * qualifiers.
 	 */
-	switch (tcp->scno + NR_SYSCALL_BASE) {
-#ifdef SYS_fork
-	case SYS_fork:
-#endif
-#ifdef SYS_vfork
-	case SYS_vfork:
-#endif
-#ifdef SYS_fork1
-	case SYS_fork1:
-#endif
-#ifdef SYS_forkall
-	case SYS_forkall:
-#endif
-#ifdef SYS_rfork1
-	case SYS_rfork1:
-#endif
-#ifdef SYS_rforkall
-	case SYS_rforkall:
-#endif
-#ifdef SYS_rfork
-	case SYS_rfork:
-#endif
-		internal_fork(tcp);
-		break;
-#ifdef SYS_clone
-	case SYS_clone:
-		internal_clone(tcp);
-		break;
-#endif
-#ifdef SYS_clone2
-	case SYS_clone2:
-		internal_clone(tcp);
-		break;
-#endif
-#ifdef SYS_execv
-	case SYS_execv:
-#endif
-#ifdef SYS_execve
-	case SYS_execve:
-#endif
-#ifdef SYS_rexecve
-	case SYS_rexecve:
-#endif
-		internal_exec(tcp);
-		break;
+	int	(*func)();
 
-#ifdef SYS_wait
-	case SYS_wait:
-#endif
-#ifdef SYS_wait4
-	case SYS_wait4:
-#endif
-#ifdef SYS32_wait4
-	case SYS32_wait4:
-#endif
-#ifdef SYS_waitpid
-	case SYS_waitpid:
-#endif
-#ifdef SYS_waitsys
-	case SYS_waitsys:
-#endif
-		internal_wait(tcp);
-		break;
+	if (tcp->scno < 0 || tcp->scno >= nsyscalls)
+		return 0;
 
-#ifdef SYS_exit
-	case SYS_exit:
+	func = sysent[tcp->scno].sys_func;
+
+	if (sys_exit == func)
+		return internal_exit(tcp);
+
+	if (   sys_fork == func
+#if defined(FREEBSD) || defined(LINUX) || defined(SUNOS4)
+	    || sys_vfork == func
 #endif
-#ifdef SYS32_exit
-	case SYS32_exit:
+#if UNIXWARE > 2
+	    || sys_rfork == func
 #endif
-#ifdef __NR_exit_group
-	case __NR_exit_group:
+	   )
+		return internal_fork(tcp);
+
+#if defined(LINUX) && (defined SYS_clone || defined SYS_clone2)
+	if (sys_clone == func)
+		return internal_clone(tcp);
 #endif
-#ifdef IA64
-	case 252: /* IA-32 __NR_exit_group */
+
+	if (   sys_execve == func
+#if defined(SPARC) || defined(SPARC64) || defined(SUNOS4)
+	    || sys_execv == func
 #endif
-		internal_exit(tcp);
-		break;
-	}
+#if UNIXWARE > 2
+	    || sys_rexecve == func
+#endif
+	   )
+		return internal_exec(tcp);
+
+	if (   sys_waitpid == func
+	    || sys_wait4 == func
+#if defined(SVR4) || defined(FREEBSD) || defined(SUNOS4)
+	    || sys_wait == func
+#endif
+#ifdef ALPHA
+	    || sys_osf_wait4 == func
+#endif
+	   )
+		return internal_wait(tcp, 2);
+
+#if defined(LINUX) || defined(SVR4)
+	if (sys_waitid == func)
+		return internal_wait(tcp, 3);
+#endif
+
 	return 0;
 }
 
@@ -715,7 +791,7 @@ struct tcb *tcp;
 #elif defined (ALPHA)
 	static long r0;
 	static long a3;
-#elif defined (SPARC)
+#elif defined (SPARC) || defined (SPARC64)
 	static struct regs regs;
 	static unsigned long trap;
 #elif defined(MIPS)
@@ -988,16 +1064,25 @@ struct tcb *tcp;
 				return 0;
 			}
 
-			if ((scno & 0x0ff00000) != 0x0f900000) {
-				fprintf(stderr, "syscall: unknown syscall trap 0x%08lx\n",
-					scno);
-				return -1;
-			}
+			/* Handle the EABI syscall convention.  We do not
+			   bother converting structures between the two
+			   ABIs, but basic functionality should work even
+			   if strace and the traced program have different
+			   ABIs.  */
+			if (scno == 0xef000000) {
+				scno = regs.ARM_r7;
+			} else {
+				if ((scno & 0x0ff00000) != 0x0f900000) {
+					fprintf(stderr, "syscall: unknown syscall trap 0x%08lx\n",
+						scno);
+					return -1;
+				}
 
-			/*
-			 * Fixup the syscall number
-			 */
-			scno &= 0x000fffff;
+				/*
+				 * Fixup the syscall number
+				 */
+				scno &= 0x000fffff;
+			}
 		}
 
 		if (tcp->flags & TCB_INSYSCALL) {
@@ -1062,7 +1147,7 @@ struct tcb *tcp;
 		if (upeek(pid, REG_R0, &r0) < 0)
 			return -1;
 	}
-#elif defined (SPARC)
+#elif defined (SPARC) || defined (SPARC64)
 	/* Everything we need is in the current register set. */
 	if (ptrace(PTRACE_GETREGS,pid,(char *)&regs,0) < 0)
 		return -1;
@@ -1072,6 +1157,9 @@ struct tcb *tcp;
 		/* Retrieve the syscall trap instruction. */
 		errno = 0;
 		trap = ptrace(PTRACE_PEEKTEXT,pid,(char *)regs.r_pc,0);
+#if defined(SPARC64)
+		trap >>= 32;
+#endif
 		if (errno)
 			return -1;
 
@@ -1083,8 +1171,8 @@ struct tcb *tcp;
 			break;
 		case 0x91d0206d:
 			/* Linux/SPARC64 syscall trap. */
-			fprintf(stderr,"syscall: Linux/SPARC64 not supported yet\n");
-			return -1;
+			set_personality(2);
+			break;
 		case 0x91d02000:
 			/* SunOS syscall trap. (pers 1) */
 			fprintf(stderr,"syscall: SunOS no support\n");
@@ -1107,7 +1195,11 @@ struct tcb *tcp;
 				tcp->flags &= ~TCB_WAITEXECVE;
 				return 0;
 			}
+#if defined (SPARC64)
+			fprintf(stderr,"syscall: unknown syscall trap %08lx %016lx\n", trap, regs.r_tpc);
+#else
 			fprintf(stderr,"syscall: unknown syscall trap %08x %08x\n", trap, regs.r_pc);
+#endif
 			return -1;
 		}
 
@@ -1216,14 +1308,26 @@ struct tcb *tcp;
 }
 
 
-int
+long
+known_scno(tcp)
+struct tcb *tcp;
+{
+	long scno = tcp->scno;
+	if (scno >= 0 && scno < nsyscalls && sysent[scno].native_scno != 0)
+		scno = sysent[scno].native_scno;
+	else
+		scno += NR_SYSCALL_BASE;
+	return scno;
+}
+
+static int
 syscall_fixup(tcp)
 struct tcb *tcp;
 {
 #ifndef USE_PROCFS
 	int pid = tcp->pid;
 #else /* USE_PROCFS */
-	int scno = tcp->scno;
+	int scno = known_scno(tcp);
 
 	if (!(tcp->flags & TCB_INSYSCALL)) {
 		if (tcp->status.PR_WHY != PR_SYSENTRY) {
@@ -1296,6 +1400,8 @@ struct tcb *tcp;
 #elif defined (X86_64)
 	if (upeek(pid, 8*RAX, &rax) < 0)
 		return -1;
+	if (current_personality == 1)
+		rax = (long int)(int)rax; /* sign extend from 32 bits */
 	if (rax != -ENOSYS && !(tcp->flags & TCB_INSYSCALL)) {
 		if (debug)
 			fprintf(stderr, "stray syscall exit: rax = %ld\n", rax);
@@ -1358,7 +1464,7 @@ struct tcb *tcp;
 	return 1;
 }
 
-int
+static int
 get_error(tcp)
 struct tcb *tcp;
 {
@@ -1476,6 +1582,16 @@ struct tcb *tcp;
 			u_error = 0;
 		}
 #else /* !SPARC */
+#ifdef SPARC64
+		if (regs.r_tstate & 0x1100000000UL) {
+			tcp->u_rval = -1;
+			u_error = regs.r_o0;
+		}
+		else {
+			tcp->u_rval = regs.r_o0;
+			u_error = 0;
+		}
+#else /* !SPARC64 */
 #ifdef HPPA
 		if (r28 && (unsigned) -r28 < nerrnos) {
 			tcp->u_rval = -1;
@@ -1511,6 +1627,7 @@ struct tcb *tcp;
 #endif /* SH */
 #endif /* HPPA */
 #endif /* SPARC */
+#endif /* SPARC64 */
 #endif /* ALPHA */
 #endif /* ARM */
 #endif /* M68K */
@@ -1615,7 +1732,7 @@ force_result(tcp, error, rval)
 #else /* !I386 */
 #ifdef X86_64
 	rax = error ? -error : rval;
-	if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(RAX * 4), rax) < 0)
+	if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(RAX * 8), rax) < 0)
 		return -1;
 #else
 #ifdef IA64
@@ -1703,6 +1820,20 @@ force_result(tcp, error, rval)
 	if (ptrace(PTRACE_SETREGS, tcp->pid, (char *)&regs, 0) < 0)
 		return -1;
 #else /* !SPARC */
+#ifdef SPARC64
+	if (ptrace(PTRACE_GETREGS, tcp->pid, (char *)&regs, 0) < 0)
+		return -1;
+	if (error) {
+		regs.r_tstate |= 0x1100000000UL;
+		regs.r_o0 = error;
+	}
+	else {
+		regs.r_tstate &= ~0x1100000000UL;
+		regs.r_o0 = rval;
+	}
+	if (ptrace(PTRACE_SETREGS, tcp->pid, (char *)&regs, 0) < 0)
+		return -1;
+#else /* !SPARC64 */
 #ifdef HPPA
 	r28 = error ? -error : rval;
 	if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(PT_GR28), r28) < 0)
@@ -1721,6 +1852,7 @@ force_result(tcp, error, rval)
 #endif /* SH */
 #endif /* HPPA */
 #endif /* SPARC */
+#endif /* SPARC64 */
 #endif /* ALPHA */
 #endif /* ARM */
 #endif /* M68K */
@@ -1766,7 +1898,8 @@ force_result(tcp, error, rval)
 	return 0;
 }
 
-int syscall_enter(tcp)
+static int
+syscall_enter(tcp)
 struct tcb *tcp;
 {
 #ifndef USE_PROCFS
@@ -1899,7 +2032,7 @@ struct tcb *tcp;
 				return -1;
 		}
 	}
-#elif defined (SPARC)
+#elif defined (SPARC) || defined (SPARC64)
 	{
 		int i;
 
@@ -1975,7 +2108,7 @@ struct tcb *tcp;
 		int i;
 		static int argreg[SUPPORTED_PERSONALITIES][MAX_ARGS] = {
 			{RDI,RSI,RDX,R10,R8,R9},	/* x86-64 ABI */
-			{RBX,RCX,RDX,RDX,RSI,RDI,RBP}	/* i386 ABI */
+			{RBX,RCX,RDX,RSI,RDI,RBP}	/* i386 ABI */
 		};
 
 		if (tcp->scno >= 0 && tcp->scno < nsyscalls && sysent[tcp->scno].nargs != -1)
@@ -2097,8 +2230,7 @@ struct tcb *tcp;
 }
 
 int
-trace_syscall(tcp)
-struct tcb *tcp;
+trace_syscall(struct tcb *tcp)
 {
 	int sys_res;
 	struct timeval tv;
@@ -2139,41 +2271,8 @@ struct tcb *tcp;
 			tprintf(" resumed> ");
 		}
 
-		if (cflag && tcp->scno < nsyscalls && tcp->scno >= 0) {
-			call_count[tcp->scno]++;
-			if (tcp->u_error)
-				error_count[tcp->scno]++;
-			tv_sub(&tv, &tv, &tcp->etime);
-#ifdef LINUX
-			if (tv_cmp(&tv, &tcp->dtime) > 0) {
-				static struct timeval one_tick;
-				if (one_tick.tv_usec == 0) {
-					/* Initialize it.  */
-					struct itimerval it;
-					memset(&it, 0, sizeof it);
-					it.it_interval.tv_usec = 1;
-					setitimer(ITIMER_REAL, &it, NULL);
-					getitimer(ITIMER_REAL, &it);
-					one_tick = it.it_interval;
-				}
-
-				if (tv_nz(&tcp->dtime))
-					tv = tcp->dtime;
-				else if (tv_cmp(&tv, &one_tick) > 0) {
-					if (tv_cmp(&shortest, &one_tick) < 0)
-						tv = shortest;
-					else
-						tv = one_tick;
-				}
-			}
-#endif /* LINUX */
-			if (tv_cmp(&tv, &shortest) < 0)
-				shortest = tv;
-			tv_add(&tv_count[tcp->scno],
-				&tv_count[tcp->scno], &tv);
-			tcp->flags &= ~TCB_INSYSCALL;
-			return 0;
-		}
+		if (cflag)
+			return count_syscall(tcp, &tv);
 
 		if (tcp->scno >= nsyscalls || tcp->scno < 0
 		    || (qual_flags[tcp->scno] & QUAL_RAW))
@@ -2281,9 +2380,9 @@ struct tcb *tcp;
 	if (res != 1)
 		return res;
 
-	switch (tcp->scno + NR_SYSCALL_BASE) {
+	switch (known_scno(tcp)) {
 #ifdef LINUX
-#if !defined (ALPHA) && !defined(SPARC) && !defined(MIPS) && !defined(HPPA) && !defined(X86_64)
+#if !defined (ALPHA) && !defined(SPARC) && !defined(SPARC64) && !defined(MIPS) && !defined(HPPA)
 	case SYS_socketcall:
 		decode_subcall(tcp, SYS_socket_subcall,
 			SYS_socket_nsubcalls, deref_style);
@@ -2292,8 +2391,8 @@ struct tcb *tcp;
 		decode_subcall(tcp, SYS_ipc_subcall,
 			SYS_ipc_nsubcalls, shift_style);
 		break;
-#endif /* !ALPHA && !MIPS && !SPARC && !HPPA && !X86_64 */
-#ifdef SPARC
+#endif /* !ALPHA && !MIPS && !SPARC && !SPARC64 && !HPPA */
+#if defined (SPARC) || defined (SPARC64)
 	case SYS_socketcall:
 		sparc_socket_decode (tcp);
 		break;
@@ -2433,7 +2532,7 @@ struct tcb *tcp;
 	long val = -1;
 
 #ifdef LINUX
-#ifdef SPARC
+#if defined (SPARC) || defined (SPARC64)
 	struct regs regs;
 	if (ptrace(PTRACE_GETREGS,tcp->pid,(char *)&regs,0) < 0)
 		return -1;
@@ -2441,10 +2540,10 @@ struct tcb *tcp;
 #elif defined(SH)
 	if (upeek(tcp->pid, 4*(REG_REG0+1), &val) < 0)
 		return -1;
-#endif /* SPARC */
 #elif defined(IA64)
 	if (upeek(tcp->pid, PT_R9, &val) < 0)
 		return -1;
+#endif /* SPARC || SPARC64 */
 #endif /* LINUX */
 
 #ifdef SUNOS4
@@ -2474,6 +2573,7 @@ struct tcb *tcp;
 	return val;
 }
 
+#ifdef SUNOS4
 /*
  * Apparently, indirect system calls have already be converted by ptrace(2),
  * so if you see "indir" this program has gone astray.
@@ -2496,118 +2596,4 @@ struct tcb *tcp;
 	}
 	return 0;
 }
-
-static int
-time_cmp(a, b)
-void *a;
-void *b;
-{
-	return -tv_cmp(&tv_count[*((int *) a)], &tv_count[*((int *) b)]);
-}
-
-static int
-syscall_cmp(a, b)
-void *a;
-void *b;
-{
-	return strcmp(sysent[*((int *) a)].sys_name,
-		sysent[*((int *) b)].sys_name);
-}
-
-static int
-count_cmp(a, b)
-void *a;
-void *b;
-{
-	int m = call_count[*((int *) a)], n = call_count[*((int *) b)];
-
-	return (m < n) ? 1 : (m > n) ? -1 : 0;
-}
-
-static int (*sortfun)();
-static struct timeval overhead = { -1, -1 };
-
-void
-set_sortby(sortby)
-char *sortby;
-{
-	if (strcmp(sortby, "time") == 0)
-		sortfun = time_cmp;
-	else if (strcmp(sortby, "calls") == 0)
-		sortfun = count_cmp;
-	else if (strcmp(sortby, "name") == 0)
-		sortfun = syscall_cmp;
-	else if (strcmp(sortby, "nothing") == 0)
-		sortfun = NULL;
-	else {
-		fprintf(stderr, "invalid sortby: `%s'\n", sortby);
-		exit(1);
-	}
-}
-
-void set_overhead(n)
-int n;
-{
-	overhead.tv_sec = n / 1000000;
-	overhead.tv_usec = n % 1000000;
-}
-
-void
-call_summary(outf)
-FILE *outf;
-{
-	int i, j;
-	int call_cum, error_cum;
-	struct timeval tv_cum, dtv;
-	double percent;
-	char *dashes = "-------------------------";
-	char error_str[16];
-
-	call_cum = error_cum = tv_cum.tv_sec = tv_cum.tv_usec = 0;
-	if (overhead.tv_sec == -1) {
-		tv_mul(&overhead, &shortest, 8);
-		tv_div(&overhead, &overhead, 10);
-	}
-	for (i = 0; i < nsyscalls; i++) {
-		sorted_count[i] = i;
-		if (call_count[i] == 0)
-			continue;
-		tv_mul(&dtv, &overhead, call_count[i]);
-		tv_sub(&tv_count[i], &tv_count[i], &dtv);
-		call_cum += call_count[i];
-		error_cum += error_count[i];
-		tv_add(&tv_cum, &tv_cum, &tv_count[i]);
-	}
-	if (sortfun)
-		qsort((void *) sorted_count, nsyscalls, sizeof(int), sortfun);
-	fprintf(outf, "%6.6s %11.11s %11.11s %9.9s %9.9s %s\n",
-		"% time", "seconds", "usecs/call",
-		"calls", "errors", "syscall");
-	fprintf(outf, "%6.6s %11.11s %11.11s %9.9s %9.9s %-16.16s\n",
-		dashes, dashes, dashes, dashes, dashes, dashes);
-	for (i = 0; i < nsyscalls; i++) {
-		j = sorted_count[i];
-		if (call_count[j] == 0)
-			continue;
-		tv_div(&dtv, &tv_count[j], call_count[j]);
-		if (error_count[j])
-			sprintf(error_str, "%d", error_count[j]);
-		else
-			error_str[0] = '\0';
-		percent = 100.0*tv_float(&tv_count[j])/tv_float(&tv_cum);
-		fprintf(outf, "%6.2f %4ld.%06ld %11ld %9d %9.9s %s\n",
-			percent, (long) tv_count[j].tv_sec,
-			(long) tv_count[j].tv_usec,
-			(long) 1000000 * dtv.tv_sec + dtv.tv_usec,
-			call_count[j], error_str, sysent[j].sys_name);
-	}
-	fprintf(outf, "%6.6s %11.11s %11.11s %9.9s %9.9s %-16.16s\n",
-		dashes, dashes, dashes, dashes, dashes, dashes);
-	if (error_cum)
-		sprintf(error_str, "%d", error_cum);
-	else
-		error_str[0] = '\0';
-	fprintf(outf, "%6.6s %4ld.%06ld %11.11s %9d %9.9s %s\n",
-		"100.00", (long) tv_cum.tv_sec, (long) tv_cum.tv_usec, "",
-		call_cum, error_str, "total");
-}
+#endif /* SUNOS4 */
