@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: util.c,v 1.50 2004/03/02 08:50:42 roland Exp $
+ *	$Id: util.c,v 1.66 2007/01/11 22:05:06 ldv Exp $
  */
 
 #include "defs.h"
@@ -78,7 +78,7 @@
 #include <sys/utsname.h>
 #endif /* SUNOS4_KERNEL_ARCH_KLUDGE */
 
-#if defined(LINUX) && defined(SPARC)
+#if defined(LINUXSPARC)
 
 # define fpq kernel_fpq
 # define fq kernel_fq
@@ -88,6 +88,14 @@
 # undef fq
 # undef fpu
 
+#if defined (SPARC64)
+# define r_pc r_tpc
+# undef PTRACE_GETREGS
+# define PTRACE_GETREGS PTRACE_GETREGS64
+# undef PTRACE_SETREGS
+# define PTRACE_SETREGS PTRACE_SETREGS64
+#endif /* SPARC64 */
+
 #if !defined(__GLIBC__)
 
 #include <linux/unistd.h>
@@ -104,7 +112,11 @@ __asm__ volatile ("or %%g0, %1, %%o0\n\t" \
                   "or %%g0, %4, %%o3\n\t" \
                   "or %%g0, %5, %%o4\n\t" \
                   "or %%g0, %6, %%g1\n\t" \
+#if defined (SPARC64)
+                  "t 0x6d\n\t" \
+#else
                   "t 0x10\n\t" \
+#endif
                   "bcc 1f\n\t" \
                   "or %%g0, %%o0, %0\n\t" \
                   "sub %%g0, %%o0, %0\n\t" \
@@ -136,6 +148,7 @@ static _hack_syscall5(int,_ptrace,int,__request,int,__pid,int,__addr,int,__data,
 #define MIN(a,b)		(((a) < (b)) ? (a) : (b))
 #endif
 
+#if 0
 void
 tv_tv(tv, a, b)
 struct timeval *tv;
@@ -145,6 +158,7 @@ int b;
 	tv->tv_sec = a;
 	tv->tv_usec = b;
 }
+#endif
 
 int
 tv_nz(a)
@@ -217,10 +231,8 @@ int n;
 	tv->tv_usec %= 1000000;
 }
 
-char *
-xlookup(xlat, val)
-struct xlat *xlat;
-int val;
+const char *
+xlookup(const struct xlat *xlat, int val)
 {
 	for (; xlat->str != NULL; xlat++)
 		if (xlat->val == val)
@@ -232,12 +244,9 @@ int val;
  * Print entry in struct xlat table, if there.
  */
 void
-printxval(xlat, val, dflt)
-struct xlat *xlat;
-int val;
-char *dflt;
+printxval(const struct xlat *xlat, int val, const char *dflt)
 {
-	char *str = xlookup(xlat, val);
+	const char *str = xlookup(xlat, val);
 
 	if (str)
 		tprintf("%s", str);
@@ -252,7 +261,7 @@ char *dflt;
  */
 int
 addflags(xlat, flags)
-struct xlat *xlat;
+const struct xlat *xlat;
 int flags;
 {
 	int n;
@@ -272,9 +281,10 @@ int flags;
 }
 
 int
-printflags(xlat, flags)
-struct xlat *xlat;
+printflags(xlat, flags, dflt)
+const struct xlat *xlat;
 int flags;
+const char *dflt;
 {
 	int n;
 	char *sep;
@@ -293,10 +303,23 @@ int flags;
 			n++;
 		}
 	}
-	if (flags) {
-		tprintf("%s%#x", sep, flags);
-		n++;
+
+	if (n) {
+		if (flags) {
+			tprintf("%s%#x", sep, flags);
+			n++;
+		}
+	} else {
+		if (flags) {
+			tprintf("%#x", flags);
+			if (dflt)
+				tprintf(" /* %s */", dflt);
+		} else {
+			if (dflt)
+				tprintf("0");
+		}
 	}
+
 	return n;
 }
 
@@ -321,6 +344,27 @@ char *fmt;
 	tprintf("]");
 }
 
+void
+printnum_int(tcp, addr, fmt)
+struct tcb *tcp;
+long addr;
+char *fmt;
+{
+	int num;
+
+	if (!addr) {
+		tprintf("NULL");
+		return;
+	}
+	if (umove(tcp, addr, &num) < 0) {
+		tprintf("%#lx", addr);
+		return;
+	}
+	tprintf("[");
+	tprintf(fmt, num);
+	tprintf("]");
+}
+
 void
 printuid(text, uid)
 const char *text;
@@ -332,9 +376,9 @@ unsigned long uid;
 
 static char path[MAXPATHLEN + 1];
 
-void
+static void
 string_quote(str)
-char *str;
+const char *str;
 {
 	char buf[2 * MAXPATHLEN + 1];
 	char *s;
@@ -360,7 +404,9 @@ printpath(tcp, addr)
 struct tcb *tcp;
 long addr;
 {
-	if (umovestr(tcp, addr, MAXPATHLEN, path) < 0)
+	if (addr == 0)
+		tprintf("NULL");
+	else if (umovestr(tcp, addr, MAXPATHLEN, path) < 0)
 		tprintf("%#lx", addr);
 	else
 		string_quote(path);
@@ -373,7 +419,12 @@ struct tcb *tcp;
 long addr;
 int n;
 {
-	if (umovestr(tcp, addr, n, path) < 0)
+	if (n >= sizeof path)
+		n = sizeof path - 1;
+
+	if (addr == 0)
+		tprintf("NULL");
+	else 	if (umovestr(tcp, addr, n, path) < 0)
 		tprintf("%#lx", addr);
 	else {
 		path[n] = '\0';
@@ -399,7 +450,7 @@ int len;
 	if (!str) {
 		if ((str = malloc(max_strlen)) == NULL
 		    || (outstr = malloc(2*max_strlen)) == NULL) {
-			fprintf(stderr, "printstr: no memory\n");
+			fprintf(stderr, "out of memory\n");
 			tprintf("%#lx", addr);
 			return;
 		}
@@ -500,28 +551,51 @@ struct tcb * tcp;
 int len;
 long addr;
 {
+#if defined(LINUX) && SUPPORTED_PERSONALITIES > 1
+	union {
+		struct { u_int32_t base; u_int32_t len; } *iov32;
+		struct { u_int64_t base; u_int64_t len; } *iov64;
+	} iovu;
+#define iov iovu.iov64
+#define sizeof_iov \
+  (personality_wordsize[current_personality] == 4 \
+   ? sizeof(*iovu.iov32) : sizeof(*iovu.iov64))
+#define iov_iov_base(i) \
+  (personality_wordsize[current_personality] == 4 \
+   ? (u_int64_t) iovu.iov32[i].base : iovu.iov64[i].base)
+#define iov_iov_len(i) \
+  (personality_wordsize[current_personality] == 4 \
+   ? (u_int64_t) iovu.iov32[i].len : iovu.iov64[i].len)
+#else
 	struct iovec *iov;
+#define sizeof_iov sizeof(*iov)
+#define iov_iov_base(i) iov[i].iov_base
+#define iov_iov_len(i) iov[i].iov_len
+#endif
 	int i;
+	unsigned long size;
 
-
-	if ((iov = (struct iovec *) malloc(len * sizeof *iov)) == NULL) {
-		fprintf(stderr, "dump: No memory");
+	size = sizeof_iov * (unsigned long) len;
+	if (size / sizeof_iov != len
+	    || (iov = malloc(size)) == NULL) {
+		fprintf(stderr, "out of memory\n");
 		return;
 	}
-	if (umoven(tcp, addr,
-		   len * sizeof *iov, (char *) iov) >= 0) {
-
+	if (umoven(tcp, addr, size, (char *) iov) >= 0) {
 		for (i = 0; i < len; i++) {
                         /* include the buffer number to make it easy to
                          * match up the trace with the source */
                         tprintf(" * %lu bytes in buffer %d\n",
-                                (unsigned long)iov[i].iov_len, i);
-                        dumpstr(tcp, (long) iov[i].iov_base,
-                                iov[i].iov_len);
+                                (unsigned long)iov_iov_len(i), i);
+                        dumpstr(tcp, (long) iov_iov_base(i),
+                                iov_iov_len(i));
                 }
 	}
 	free((char *) iov);
-
+#undef sizeof_iov
+#undef iov_iov_base
+#undef iov_iov_len
+#undef iov
 }
 #endif
 
@@ -541,7 +615,7 @@ int len;
 		if (str)
 			free(str);
 		if ((str = malloc(len)) == NULL) {
-			fprintf(stderr, "dump: no memory\n");
+			fprintf(stderr, "out of memory\n");
 			return;
 		}
 		strsize = len;
@@ -800,10 +874,10 @@ char *laddr;
 }
 
 #ifdef LINUX
-#ifndef SPARC
+#if !defined (SPARC) && !defined(SPARC64)
 #define PTRACE_WRITETEXT	101
 #define PTRACE_WRITEDATA	102
-#endif /* !SPARC */
+#endif /* !SPARC && !SPARC64 */
 #endif /* LINUX */
 
 #ifdef SUNOS4
@@ -921,8 +995,8 @@ long *res;
 			}
 			is_sun4m = strcmp(name.machine, "sun4m") == 0;
 			if (is_sun4m) {
-				extern struct xlat struct_user_offsets[];
-				struct xlat *x;
+				extern const struct xlat struct_user_offsets[];
+				const struct xlat *x;
 
 				for (x = struct_user_offsets; x->str; x++)
 					x->val += 1024;
@@ -946,6 +1020,7 @@ long *res;
 
 #endif /* !USE_PROCFS */
 
+#if 0
 long
 getpc(tcp)
 struct tcb *tcp;
@@ -968,7 +1043,7 @@ struct tcb *tcp;
 #elif defined(POWERPC)
 	if (upeek(tcp->pid, sizeof(unsigned long)*PT_NIP, &pc) < 0)
 		return -1;
-#elif defined(M68k)
+#elif defined(M68K)
 	if (upeek(tcp->pid, 4*PT_PC, &pc) < 0)
 		return -1;
 #elif defined(ALPHA)
@@ -977,7 +1052,7 @@ struct tcb *tcp;
 #elif defined(MIPS)
  	if (upeek(tcp->pid, REG_EPC, &pc) < 0)
  		return -1;
-#elif defined(SPARC)
+#elif defined(SPARC) || defined(SPARC64)
 	struct regs regs;
 	if (ptrace(PTRACE_GETREGS,tcp->pid,(char *)&regs,0) < 0)
 		return -1;
@@ -1023,26 +1098,43 @@ struct tcb *tcp;
 	return regs.r_eip;
 #endif /* FREEBSD */
 }
+#endif
 
 void
 printcall(tcp)
 struct tcb *tcp;
 {
+#define PRINTBADPC tprintf(sizeof(long) == 4 ? "[????????] " : \
+			   sizeof(long) == 8 ? "[????????????????] " : \
+			   NULL /* crash */)
 
 #ifdef LINUX
 #ifdef I386
 	long eip;
 
 	if (upeek(tcp->pid, 4*EIP, &eip) < 0) {
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%08lx] ", eip);
+
+#elif defined(S390) || defined(S390X)
+         long psw;
+         if(upeek(tcp->pid,PT_PSWADDR,&psw) < 0) {
+                 PRINTBADPC;
+                 return;
+         }
+#ifdef S390
+         tprintf("[%08lx] ", psw);
+#elif S390X
+       tprintf("[%16lx] ", psw);
+#endif
+
 #elif defined(X86_64)
 	long rip;
 
 	if (upeek(tcp->pid, 8*RIP, &rip) < 0) {
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%16lx] ", rip);
@@ -1050,7 +1142,7 @@ struct tcb *tcp;
 	long ip;
 
 	if (upeek(tcp->pid, PT_B0, &ip) < 0) {
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%08lx] ", ip);
@@ -1062,7 +1154,7 @@ struct tcb *tcp;
 		return;
 	}
 	tprintf("[%08lx] ", pc);
-#elif defined(M68k)
+#elif defined(M68K)
 	long pc;
 
 	if (upeek(tcp->pid, 4*PT_PC, &pc) < 0) {
@@ -1074,14 +1166,14 @@ struct tcb *tcp;
 	long pc;
 
 	if (upeek(tcp->pid, REG_PC, &pc) < 0) {
-		tprintf ("[????????] ");
+		tprintf ("[????????????????] ");
 		return;
 	}
 	tprintf("[%08lx] ", pc);
-#elif defined(SPARC)
+#elif defined(SPARC) || defined(SPARC64)
 	struct regs regs;
 	if (ptrace(PTRACE_GETREGS,tcp->pid,(char *)&regs,0) < 0) {
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%08lx] ", regs.r_pc);
@@ -1113,7 +1205,7 @@ struct tcb *tcp;
 	long pc;
 
 	if (upeek(tcp->pid, REG_PC, &pc) < 0) {
-		tprintf ("[????????] ");
+		tprintf ("[????????????????] ");
 		return;
 	}
 	tprintf("[%08lx] ", pc);
@@ -1121,7 +1213,7 @@ struct tcb *tcp;
 	long pc;
 
 	if (upeek(tcp->pid, 4*15, &pc) < 0) {
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%08lx] ", pc);
@@ -1133,7 +1225,7 @@ struct tcb *tcp;
 
 	if (ptrace(PTRACE_GETREGS, tcp->pid, (char *) &regs, 0) < 0) {
 		perror("printcall: ptrace(PTRACE_GETREGS, ...)");
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%08x] ", regs.r_o7);
@@ -1141,7 +1233,7 @@ struct tcb *tcp;
 
 #ifdef SVR4
 	/* XXX */
-	tprintf("[????????] ");
+	PRINTBADPC;
 #endif
 
 #ifdef FREEBSD
@@ -1159,6 +1251,9 @@ struct tcb *tcp;
 #ifndef CLONE_PTRACE
 # define CLONE_PTRACE    0x00002000
 #endif
+#ifndef CLONE_STOPPED
+# define CLONE_STOPPED   0x02000000
+#endif
 
 #ifdef IA64
 
@@ -1254,7 +1349,7 @@ set_arg1 (struct tcb *tcp, arg_setup_state *state, long val)
 	return errno ? -1 : 0;
 }
 
-#elif defined (SPARC)
+#elif defined (SPARC) || defined (SPARC64)
 
 typedef struct regs arg_setup_state;
 
@@ -1358,7 +1453,7 @@ struct tcb *tcp;
 		return -1;
 	}
 
-	switch (tcp->scno) {
+	switch (known_scno(tcp)) {
 #ifdef SYS_vfork
 	case SYS_vfork:
 #endif
@@ -1426,10 +1521,11 @@ struct tcb *tcp;
 {
 
 #ifdef LINUX
-#ifdef SPARC
+#if defined (SPARC) || defined (SPARC64)
 	/* We simply use the SunOS breakpoint code. */
 
 	struct regs regs;
+	unsigned long inst;
 #define LOOPA	0x30800000	/* ba,a	0 */
 
 	if (tcp->flags & TCB_BPTSET) {
@@ -1459,14 +1555,19 @@ struct tcb *tcp;
 	 * Of cause, if we evaporate ourselves in the middle of all this...
 	 */
 	errno = 0;
-	ptrace(PTRACE_POKETEXT, tcp->pid, (char *) tcp->baddr, LOOPA);
+	inst = LOOPA;
+#if defined (SPARC64)
+	inst <<= 32;
+	inst |= (tcp->inst[0] & 0xffffffffUL);
+#endif
+	ptrace(PTRACE_POKETEXT, tcp->pid, (char *) tcp->baddr, inst);
 	if(errno) {
 		perror("setbpt: ptrace(PTRACE_POKETEXT, ...)");
 		return -1;
 	}
 	tcp->flags |= TCB_BPTSET;
 
-#else /* !SPARC */
+#else /* !SPARC && !SPARC64 */
 #ifdef IA64
 	if (ia32) {
 #		define LOOP	0x0000feeb
@@ -1615,7 +1716,7 @@ struct tcb *tcp;
 	tcp->flags |= TCB_BPTSET;
 
 #endif /* !IA64 */
-#endif /* SPARC */
+#endif /* SPARC || SPARC64 */
 #endif /* LINUX */
 
 #ifdef SUNOS4
@@ -1690,7 +1791,7 @@ struct tcb *tcp;
        long pc;
 #endif /* architecture */
 
-#ifdef SPARC
+#if defined (SPARC) || defined (SPARC64)
 	/* Again, we borrow the SunOS breakpoint code. */
 	if (!(tcp->flags & TCB_BPTSET)) {
 		fprintf(stderr, "PANIC: TCB not set in pid %u\n", tcp->pid);
@@ -1770,7 +1871,7 @@ struct tcb *tcp;
 			return 0;
 		}
 	}
-#else /* !IA64  && ! SPARC */
+#else /* !IA64  && !SPARC && !SPARC64 */
 
 	if (debug)
 		fprintf(stderr, "[%d] clearing bpt\n", tcp->pid);
@@ -1868,7 +1969,7 @@ struct tcb *tcp;
         }
 
 #endif /* arch */
-#endif /* !SPARC && !IA64 */
+#endif /* !SPARC && !SPARC64 && !IA64 */
 #endif /* LINUX */
 
 #ifdef SUNOS4
@@ -1981,7 +2082,7 @@ struct tcb *tcp;
 		return -1;
 	}
 	if ((strtab = malloc((unsigned)ld.ld_symb_size)) == NULL) {
-		fprintf(stderr, "fixvfork: out of memory\n");
+		fprintf(stderr, "out of memory\n");
 		return -1;
 	}
 	if (umoven(tcp, (int)ld.ld_symbols+(int)N_TXTADDR(hdr),
